#!/bin/sh -e
#
# Trigger handler for /etc/init.d scripts
#
# Christoph Lameter <christoph@lameter.com>, September 1st, 2002
# (C) 2002 Lameter Corporation. http://lameter.com .
#
# This script is called before removal of a script from /etc/init.d
# or when a script is added to /etc/init.d. 
# The script uses rc-update to manage the symlinks that need 
# to be pointed to the scripts. The actual necessary settings
# are extraced from the script itself from a line of the form
#
# #RC <parameters>
#
# If the #RC line is not present then 
# "defaults" are assumed.
#

MODE=$1
shift

while [ "$1" != "" ]; do
  PARAM="`grep "^#RC " /etc/init.d/$1||true`"
  if [ "$PARAM" != "" ]; then
    PARAM=${PARAM#"#RC "}

    if [ "$MODE" = "add" ]; then
        update-rc.d -f $1 remove
	update-rc.d $1 $PARAM
	echo "$0: added $1 $PARAM"
    fi

    if [ "$MODE" = "remove" ]; then
 	update-rc.d -f $1 remove
	echo "$0: removed $1"
    fi
  else
     echo "$0: $1 has no #RC line skipped."
  fi
  shift
done
exit 0
