/***************************************************************************
                          uPM Micro Package Manager
                          -------------------------
                     Created Wed Aug  7 18:17:08 PDT 2002
 (C) Copyright 2002 Lameter International Corporation. http://lameter.com
 			All Rights Reserved.
	
           Created by Christoph Lameter, <christoph@lameter.com>

		License 4F Class D Non-Commercial 1 Year October 26, 2002
		see http://uos.org/4f for license details
****************************************************************************/

#define _GNU_SOURCE
 
#include <stdio.h>
#include <stdlib.h>
#include <getopt.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <ctype.h>
#include <string.h>
#include <stdarg.h>
#include <sys/wait.h>
#include <stdarg.h>
#include <dirent.h>
#include <alloca.h>
#include <errno.h>
#include <time.h>
#include <sys/resource.h>
#include <envz.h>
#include <pwd.h>
#include <grp.h>
#include <fnmatch.h>
#include <regex.h>
#include <malloc.h>

#include "md5.h"

/* The maximum length of the buffer used for line buffering and other temporary storage needs.
   This is also used to compose trigger command lines which can contain a long 
   list of files (like in the case of X fonts)
*/
#define MAXLLENGTH 65536

#define VERSION "0.85"
#define FALSE 0
#define TRUE 1

/* Important fixed paths */
#define INSTALLED mdirs[P_INSTALLED]
#define ETC "usr/upm/"
#define UPM_IN "usr/upm/in/"
#define FROOT "usr/upm/froot"
#define CONFIGFILE "/etc/upm.conf"
/* #define CONFIGFILE "upm.conf" */
#define SCRIPTLOG "/var/log/script.log"
#define TRIGGERLOG "/var/log/trigger.log"

/* Colors */
#define BLACK "0"
#define RED "1"
#define BLUE "4"
#define GREEN "2"
#define YELLOW "3"
#define PINK "5"
#define CYAN "6"
#define WHITE "7"
#define BOLD "1"
#define NORMAL "0"

#define COLOR(intens,fg,bg) "\033[\[" intens ";3" fg ";4" bg "m" 
#define OFF "\0333[\[0m"

/* Extensions and their treatment */
const char *source_extensions[] = { NULL,".tar.gz",".tgz",".tar.bz2",".tbz2",".tar",".zip",".file",".file.gz",".file.bz2",NULL };
const char *patch_extensions[] = { "",".gz",".bz2",NULL };
const char *source_unpack[] = { "cp %s %s","tar xzf %s","tar xzf %s","tar jxf %s","tar jxf %s","tar xf %s","unzip %s","cp %s %s","zcat %s >%s","bunzip2 -c %s >%s" };
const char *binary_unpack[] = { "cp %s %s","tar xpzf %s","tar xpzf %s","tar jpxf %s","tar jpxf %s","tar xpf %s","unzip %s","cp %s %s","zcat %s >%s","bunzip2 -c %s >%s" };
const char *patch_unpack[] = { "cat %s","zcat %s","bunzip2 -c %s" };

const char *retrieve_command="wget -nc --passive-ftp -c %s";
const char *save_binaries;

enum binariestype { B_IFLOCAL,B_IFAVAIL,B_ALWAYS,B_NEVER } binaries;

const char *temp_dir="/var/tmp/upm";
const char *cache_files="/var/upm/cache";
const char *descriptions="/var/upm/descr";
const char *mirror="http://ftp.ibiblio.org/pub/linux/distributions/uos/mirror";
const char *scripts="/usr/upm/scripts";
const char *rsyncloc="ibiblio.org::linux_distros/uos/sputnik";
const char *patch_loc="http://ftp.ibiblio.org/pub/linux/distributions/uos/sputnik/patches";
const char *source_loc="http://ftp.ibiblio.org/pub/linux/distributions/uos/sputnik/sources";

struct passwd *builduser=NULL;	/* ID to use for building */
struct passwd *upmuser=NULL;	/* ID to use for upm database management */

/* Globals */
char *cwd;

char *root="";		/* Where to install to */

int errors=0;
int warnings=0;
int keepreal=FALSE;	/* If set keep real situation rather than trying to adapt it to descriptions */
int deps=FALSE;		/* If set to true try to resolve all dependencies */
int no_depends=FALSE;	/* Ignore dependencies during install and build */
int no_protect=FALSE;	/* Protection off means files can be overwritten in files */
int no_logs=TRUE;	/* If true do not write logs during build stage */
int fakeroot=TRUE;	/* if true do not run fakeroot for build install */
int keepdirs=FALSE;	/* if true do not remove build directories after successful build */
int keeplogs=FALSE;	/* if true do not remove build logs after successful build */
int generate=FALSE;	/* if true invent package description if it does not exist */
int nice_pkg=FALSE;	/* if true do not install files that would overwrite others */
int matching=FALSE;	/* if true do pattern matching instead */
int thorough=FALSE;	/* if true do thourough checking on track */	
int fetchonly=FALSE;	/* only fetch files do not install */
int noinitscript=FALSE;	/* Do not execute init-scripts */

int uid;		/* As what user id is upm running */
int runlevel=0;		/* System state (for running init scripts) */

const char *flog;

FILE *logfile;
enum logtype { L_SWERR,L_FATAL,L_ABORT,L_ERROR,L_WARN,L_INFO,L_PROGRESS,L_SHELLCMD,L_DEBUG,L_TRACE };

char *logtext[] = {"INTERNAL","FATAL","ABORT","ERROR","WARN","INFO","...","Shell","Debug","Trace",NULL };

enum logtype loglevel=L_WARN;
enum logtype viewlevel=L_PROGRESS;

enum conftype { C_DEFAULT,C_KEEP,C_OVERWRITE,C_RENAME } configmode;

/* Buffer for temporary use here and there. Not guaranteed to be valid across
   to any function calls */
char buffer[MAXLLENGTH];

/* Package Statistics */
struct stats {
  off_t size;
  unsigned files;
  unsigned links;
  unsigned dirs;
  unsigned nodes;
  const char*title;
  char*version;
  char flags[10];
};
/*****************************************************
	Termination and Message logging
*****************************************************/

void log(enum logtype level,const char *s,...) {
  char *x;
  struct tm *t;
  time_t tp;
  va_list ap;
  va_start(ap, s);

  if (level>loglevel || logfile==NULL) return;
  vasprintf(&x,s,ap);
  time(&tp);
  t=localtime(&tp);
  fprintf(logfile,"%4d/%02d/%02d %2d:%02d:%02d %s %s\n",t->tm_year+1900,t->tm_mon+1,t->tm_mday,t->tm_hour,t->tm_min,t->tm_sec,logtext[level],x);
  free(x);
}
		      
void error(const char *s,...) {
  char *x;
  va_list ap;
  va_start(ap,s);
  vasprintf(&x,s,ap);
  fprintf(stderr,"[ Error   ] %s\n",x);
  log(L_ERROR,x);
  free(x);
  errors++;
}

void warn(const char *s,...) {
  char *x;
  va_list ap;
  va_start(ap,s);
  vasprintf(&x,s,ap);
  if (L_WARN<=viewlevel) fprintf(stderr,"[ Warning ] %s\n",x);
  log(L_WARN,x);
  free(x);
  warnings++;
}

void progress(const char *s,...) {
  char *x;
  va_list ap;
  va_start(ap,s);
  vasprintf(&x,s,ap);
  if (L_PROGRESS<=viewlevel) printf("[ ....... ] %s\n",x);
  log(L_PROGRESS,x);
  free(x);
  warnings++;
}

void info(const char *s,...) {
  char *x;
  va_list ap;
  va_start(ap,s);
  vasprintf(&x,s,ap);
  if (L_INFO<=viewlevel) printf("[ Info    ] %s\n",x);
  log(L_INFO,x);
  free(x);
  warnings++;
}
 
void shelllog(const char *s,...) {
  char *x;
  va_list ap;
  va_start(ap,s);
  vasprintf(&x,s,ap);
  if (L_SHELLCMD<=viewlevel) printf("[ Shell   ] %s\n",x);
  log(L_SHELLCMD,x);
  free(x);
  warnings++;
}
 
void debug(const char *s,...) {
  char *x;
  va_list ap;
  va_start(ap,s);
  vasprintf(&x,s,ap);
  if (L_DEBUG<=viewlevel) printf("[ Debug   ] %s\n",x);
  log(L_DEBUG,x);
  free(x);
  warnings++;
}

void fatal(const char *s,...) {
  char *x;
  va_list ap;
  va_start(ap, s);
  vasprintf(&x,s,ap);
  fprintf(stderr,"[ PROBLEM ] %s\n",x);
  log(L_FATAL,x);
  free(x);
  exit(2);
}

void swerr(const char *s,...) {
  char *x;
  va_list ap;
  va_start(ap, s);
  vasprintf(&x,s,ap);
  fprintf(stderr,"[ SOFTERR ] %s\n",x);
  log(L_SWERR,x);
  free(x);
  exit(3);
}

/* Abort because of a system error involving entity s */
void sys_abort(const char *s) {
  perror(s);
  log(L_ABORT,"[ SYS-ERR ] %s: %s",s,strerror(errno));
  exit(4);
}


/* Make sure that memory allocation functions never return NULL
   This way we do not have to check and Jon is more convinced about
   the safety of upm */
void *(*old_malloc_hook)(size_t size,const void *caller);
void *(*old_realloc_hook)(void *ptr,size_t size,const void *caller);
void *(*old_memalign_hook)(size_t align,size_t size,const void *caller);

static void *my_malloc_hook (size_t size, const void *caller) {
  void *result;

  __malloc_hook=old_malloc_hook;
  result=malloc(size);
  if (result==NULL) fatal("Out of Memory");
  __malloc_hook=my_malloc_hook;
  return result;
}

static void *my_realloc_hook(void *ptr,size_t size,const void *caller) {
  void *result;
 
  __realloc_hook=old_realloc_hook;
  result=realloc(ptr,size);
  if (result==NULL) fatal("Out of Memory");
  __realloc_hook=my_realloc_hook;
  return result;
}

static void my_init_hook (void) {
  old_malloc_hook = __malloc_hook;
  old_realloc_hook = __realloc_hook;
  __malloc_hook = my_malloc_hook;
  __realloc_hook = my_realloc_hook;
}

/* Override initializing hook from the C library. */
void (*__malloc_initialize_hook) (void) = my_init_hook;

char *catstr(const char *s,...) {
  char *x;
  va_list ap;
  va_start(ap,s);
  strcpy(buffer,s);
  while ((x=va_arg(ap,char *))) {
    strcat(buffer,x);
  };
  va_end(ap);
  return buffer;
}

int is_dir(const char *n) {
  struct stat fbuf;
  if (stat(n,&fbuf)) return FALSE;
  return S_ISDIR(fbuf.st_mode);
}

int is_file(const char *n) {
  struct stat fbuf;
  if (stat(n,&fbuf)) return FALSE;
  return S_ISREG(fbuf.st_mode);
}

int file_indir(const char *file,const char *dir) {
  const char *p=file+strlen(file);
  while (p>file && *--p!='/') ;
  if (strlen(dir)==p-file) {
    if (strncmp(file,dir,p-file)==0) return TRUE;
  }
  return FALSE;
}

/*****************************************************
        Command and script execution
*****************************************************/

void drop_privs(void);

int shell(const char *format,...) {
  char *x;
  int rc;
  int pid;
  int code;
  va_list ap;

  va_start(ap, format);
  vasprintf(&x,format,ap);
  if (L_SHELLCMD<=viewlevel) printf("[ Shell   ] %s\n",x);
  log(L_SHELLCMD,"shell: %s",x);
  if ((pid=fork())==0) {
    /* Child: drop priviledges */
    drop_privs();
    execl("/bin/sh","/bin/sh","-c",x,NULL);
    swerr("Return from exec ?");
  } 
  /* Parent */
  if (waitpid(pid,&code,0)!=pid) sys_abort("waitpid");
  if (WIFEXITED(code)) rc=WEXITSTATUS(code); else rc=-1;
  free(x);
  return rc;
}

/* This here suffers from the old idiocy regarding SETEUID. 
   Even if the run as a user the command will be executed as root */
char *read_shell(const char *cmd,const char *par) {
  int p[2];
  int pid;
  int rc;
  int n;
  int y;
  int code;
  
  log(L_SHELLCMD,"read_shell: %s %s",cmd,par);
  if (pipe(p)) sys_abort("pipe creation");
  if ((pid=fork())==0) {
    /* Child */
    drop_privs();
    close(p[0]);
    dup2(p[1],1);    /* Attach p[1] to stdout */
    dup2(p[1],2);    /* Merge stdout/stderr */
    close(p[1]);
    execl(cmd,cmd,par,NULL);
    swerr("Return from exec ?");
  }
  /* Parent */
  close(p[1]);
  n=read(p[0],buffer,MAXLLENGTH);
  /* Make sure that everything is read until EOF or buffer filled */
  while (n<MAXLLENGTH && ((y=read(p[0],buffer+n,MAXLLENGTH-n)))) n+=y;

  if (waitpid(pid,&code,0)!=pid) sys_abort("waitpid");
  if (WIFEXITED(code)) rc=WEXITSTATUS(code); else rc=-1;
  close(p[0]); 
  if (n>0) { buffer[n]=0;return buffer; }
  
  fatal("Error on read_shell code");
  return NULL;
}

char hex(int x) {
 if (x<10) return x+'0';
 return x-10+'a';
};

char *md5sum(const char *file) {
  md5_state_t m5;
  FILE *f;
  int n;
  char *d;
  unsigned char *s;
  
  md5_init(&m5);
  f=fopen(file,"r");
  if (f==NULL) sys_abort(file);
  while ((n=fread(buffer,1,MAXLLENGTH,f))) {
    md5_append(&m5,buffer,n);
  }
  md5_finish(&m5,buffer+50);
  fclose(f);
  d=buffer;s=buffer+50;
  while (d<buffer+32) {
   *d++= hex(*s / 16);
   *d++= hex(*s % 16);
   s++;
  }
  *d=0;
  return buffer;
}

/* Checks the presence of all path elements and creates missing elements */
void check_path(char *name) {
  char *p=name+1;

  while (*p) {
    if (*p=='/') {
      *p=0;
      mkdir(name,0775);
      *p='/';
    }
    p++;
  }
}

const char *find_version_separator(const char *x) {
  const char *slash=x;
  for(const char *p=x;*p;p++) if (*p=='/') slash=p+1;
  
  for(const char *p=slash;*p;p++) {
    if (*p=='-') {
      if (p[1] && isdigit(p[1])) return p;
    }
  }
  return NULL;
}

char *extract_packagename(const char *x) {
  const char *p=x+strlen(x);
  const char *q=p;
  
  while (p>x && *--p!='/') ;
  if (*p=='/') p++;
  q=find_version_separator(p);
  if (q==NULL) return strdup(p);
  return strndup(p,q-p);
}

char *extract_version(const char *x) {
  const char *p;
  const char **s;
  int l;

  if (x==NULL) return NULL;
  p=find_version_separator(x);
  if (p==NULL) return NULL;
  p++;
  s=source_extensions+1;
  while(*s && strncmp(*s,p+strlen(p)-strlen(*s),strlen(*s))) s++;
  if (*s) l=strlen(p)-strlen(*s); else l=strlen(p);
  return strndup(p,l);
}

/* Extract an upstream version number given a version number */
char *extract_upstream_version(const char *x) {
  if (x==NULL) return NULL;
  for(const char *p=x+strlen(x);p>x;p--) if (p[-1]=='-' && *p=='d') return strndup(x,p-x-1);
  return strdup(x);
}

/* Extract an delta given a version number */
char *extract_delta_version(const char *x) {
  if (x) for(const char *p=x+strlen(x);p>x;p--) if (p[-1]=='-' && *p=='d') return strdup(p+2);
  return NULL;
}

/* Recursively remove a directory */
void removedir(const char *x) {
  DIR *dir;
  struct dirent *dire;

  dir=opendir(x);
  if (dir==NULL) return;
  while ((dire=readdir(dir))) {
    char *y;
    
    if (strcmp(dire->d_name,".")==0 || strcmp(dire->d_name,"..")==0) continue;

    y=strdup(catstr(x,"/",dire->d_name,NULL));
    if (is_dir(y) && readlink(y,buffer,MAXLLENGTH)<=0) removedir(y);      
    else {
      if (unlink(y)) { closedir(dir);return; }
    }
  };
  closedir(dir);
  rmdir(x);
}

/* Find extension type */
int is_tarball(char *filename) {
  int ext=1;
  
  while (source_extensions[ext] && strcmp(source_extensions[ext],filename+strlen(filename)-strlen(source_extensions[ext]))) ext++;
  if (source_extensions[ext]==NULL) return 0;
  return ext;
}

char *generate_tarball(const char *dir,const char *name,...) {
  int rc;
  char *x;
  va_list ap;
  va_start(ap, name);
  vasprintf(&x,name,ap);

  catstr(x,".tgz",NULL);free(x);x=strdup(buffer);
  check_path(x);
  rc=shell("tar cpzf %s -C %s *",x,dir);
  if (rc) sys_abort(x);
  return x;
}

void unpack_tarball(const char *dir,const char *name,...) {
  int rc;
  char *x;
  va_list ap;
  
  va_start(ap, name);
  vasprintf(&x,name,ap);

  rc=shell("tar xpzf %s -C %s",x,dir);
  free(x);
  if (rc) sys_abort(dir);
}

/* Retrieve a file from an URL into the cache */
int retrieve(char *url,char *m5) {
  struct stat fbuf;
  int attempts=0;
  char *filename;
  char *cd;
  
  filename=strdupa(url);
  /* Check for an @ expression */
  for(cd=filename+strlen(filename);cd>url && *--cd!='@';) ;
  if (cd!=url) *cd=0;
  
  filename=basename(filename);
  
  chdir(cache_files);
  if (stat(filename,&fbuf)==0) {
    if (m5==NULL || *m5==0 || *m5==' ' || strcmp(md5sum(filename),m5)==0) { info("Have %s",filename);return 0; }
  corrupted:
    warn("MD5 mismatch! Removing corrupted file %s from cache",filename);
    unlink(filename);
  };

  if (strchr(url,':')==NULL && url[0]=='/') {
    /* This is no URL but a file. We can simply symlink to that one */
    symlink(url,filename);
    info("Found file %s locally in %s",filename,url);
    return 0;
  }
  if (mirror[0] && mirror[0]!=' ' && mirror[0]!=10) {
    info("Attempting to retrieve %s from mirror",filename);
    if (shell(retrieve_command,strdupa(catstr(mirror,"/",filename,NULL)))) {
      warn("Cannot retrieve %s from mirror. Trying source location.");
      info("Retrieving %s from source location %s",filename,url);
      if (shell(retrieve_command,url)) return 1;
    }
  } else {
    info("Retrieveing %s from source location %s",filename,url);
    if (shell(retrieve_command,url)) return 1;
  }
  if (attempts>2) return 2;
  if (m5 && *m5 && *m5!=' ' && strcmp(md5sum(filename),m5)) { attempts++;goto corrupted;}
  
  return 0;
}

/*********************************************************
                   User ID changes 
*********************************************************/

int rootmode=TRUE;

void become_root(void) {
  if (geteuid()==0) return;
  debug("Changing userid back to root");
  if (setegid(0)) sys_abort("SETGID(0)");
  if (seteuid(0)) sys_abort("SETUID(0)");
  rootmode=TRUE;
}

/* Restrict privs to a certain userid. Problem
with this idiocy is that system and spawning a shell 
will result in execution as root */
void become_user(struct passwd *user) {

  if (user==NULL) return;
  debug("Changing userid to %s",user->pw_name);
  if (setegid(user->pw_gid)) sys_abort("SETGID(BUILDGROUP)");    
  if (seteuid(user->pw_uid)) sys_abort("SETUID(BUILDUSER)");
  if (geteuid()!=user->pw_uid) fatal("Operating system cannot switch uid");
  if (getegid()!=user->pw_gid) fatal("Operating system cannot switch gid");
  rootmode=FALSE;
}

/* Irrevocably drop root priviledges. This is used
   before forking a shell so that the shell does not run
   as root... seteuid(user) will still exec shell as
   root... WHY? */
void drop_privs(void) {
  /* If we are not superuser.... then why do this at all??? */
  if (uid) return;
  if (rootmode) return;
  /* if fakeroot is not desired then stay as root */
  if (!fakeroot) return;
  debug("Dropping Priviledges");
  /* You can only drop by first becoming superuser again ... */
  if (seteuid(0)) sys_abort("SETEUID");
  if (setgid(builduser->pw_gid)) sys_abort("SETGID");
  if (setuid(builduser->pw_uid)) sys_abort("SETUID");
}


/*********************************************************
                     Fakeroot
**********************************************************/
int faked_pid=0;	/* !=0 when faked is running */

/* Fakeroot start sets the proper environment and starts faked
   so that all script execution will have a simulated root environment */
void fakeroot_start(void) {
  char *p=read_shell("/usr/bin/faked",NULL);
  char *x=p;
  
  if (p[0]==0) fatal("Cannot start faked");
  while (*p && *p!=':') p++;
  *p++=0;
  setenv("FAKEROOTKEY",x,1);
  faked_pid=atoi(p);
  debug("fakeroot started on pid %d",faked_pid);
  
  x=getenv("LD_LIBRARY_PATH");
  if (x) setenv("LD_LIBRARY_PATH",catstr("/usr/lib/libfakeroot:",x,NULL),1);
  else setenv("LD_LIBRARY_PATH","/usr/lib/libfakeroot",1);
  
  x=getenv("LD_PRELOAD");
  if (x) setenv("LD_PRELOAD",catstr("libfakeroot.so.0 ",x,NULL),1);
  else setenv("LD_PRELOAD","libfakeroot.so.0",1);
}

void fakeroot_end(void) {
  if (faked_pid==0) return;
  if (kill(faked_pid,SIGTERM)) sys_abort("killing faked");
  unsetenv("FAKEROOTKEY");
  unsetenv("LD_LIBRARY_PATH");
  unsetenv("LD_PRELOAD");
  faked_pid=0;
}

void fakeroot_atexit(void) {
  if (faked_pid) fakeroot_end();
}

/**********************************************************
    SUID.CONF routines
**********************************************************/

struct suidrec {
  struct suidrec *next;
  gid_t gid;
  uid_t uid;
  mode_t mode;
  char file[];
} *suidroot=NULL;

void read_suid(void) {
  FILE *f=fopen("/etc/suid.conf","r");
  int lineno=0;
  
  if (f==NULL) return;
  while (fgets(buffer,MAXLLENGTH,f)) {
    struct suidrec *x=malloc(sizeof(struct suidrec) + MAXLLENGTH);
    char user[21];
    char group[21];
    
    lineno++;
    if (buffer[0]=='#') continue;
    if (buffer[0]==0) continue;
    if (buffer[0]==' ') continue;
    if (buffer[0]==10) continue;

    if (4!=sscanf(buffer,"%s %20s %20s %o",x->file,user,group,&x->mode)) fatal("Format error in suid.conf line %d",lineno);
    
    if (isdigit(*user)) { x->uid=atoi(user); } else {
      struct passwd *p=getpwnam(user);
      if (p==NULL) fatal("Unknown userid '%s' in /etc/suid.conf",user);
      x->uid=p->pw_uid;
    }
    if (isdigit(*group)) { x->gid=atoi(group); } else {
      struct group *p=getgrnam(group);
      if (p==NULL) fatal("Unknown groupid '%s' in /etc/suid.conf",group);
      x->gid=p->gr_gid;
    }
    x=realloc(x,sizeof(struct suidrec) + strlen(x->file)+1);
    if (x->file[0]=='/') memmove(x->file,x->file+1,strlen(x->file));
    x->next=suidroot;
    suidroot=x;
  }
  fclose(f);
}

struct suidrec *find_suid(char *s) {
  struct suidrec *p=suidroot;

  while (p && strcmp(s,p->file)) p=p->next;
  return p;
}

/**********************************************************
  RC.D string parsing and set up of SYSV init symlinks 
**********************************************************/

#define START 0
#define STOP 1

#define RUNLEVELS 7

int setlinks(char *pname,char *s) {
  char *target=strdupa(catstr("../init.d/",pname,NULL));
  char *t=strtok(strdupa(s)," \t");
  // Runlevel 7 is S
  char rcd[RUNLEVELS+1][2];

  // First zap the config wanted 
  memset(rcd,0,sizeof(rcd));
  
  // Now look at the string 
  if (strcmp(t,"defaults")==0) {
    int start=20;
    int stop=20;
    t=strtok(NULL," \t");
    if (t) {
      start=atoi(t);
      t=strtok(NULL," \t");
      if (t) {
        stop=atoi(t);
	if (strtok(NULL," \t")) { error("%s: defaults takes one or two parameters",pname);return FALSE; }
      }
    }
    /* Defaults stop in 0 1 6 start in 2 3 4 5 */
    rcd[0][STOP]=rcd[1][STOP]=rcd[6][STOP]=stop;
    rcd[2][START]=rcd[3][START]=rcd[4][START]=rcd[5][START]=start;
  } else
  
  if (strcmp(t,"start")==0 || strcmp(t,"stop")==0) {
    /* Start stop etc processing */
    for(;t;t=strtok(NULL," \t")) {
      int val;
      int mode;
      
      if (strcmp(t,"start")==0) mode=START; else
      if (strcmp(t,"stop")==0) mode=STOP; else { error("%s: Expected 'start' or 'stop'",pname);return FALSE; }
      
      t=strtok(NULL," \t");
      if (t==NULL || (val=atoi(t))<0 || val>99 ) { error("%s: Expected NN after 'start' or 'stop'",pname);return FALSE; }
      t=strtok(NULL," \t");
      if (t==NULL) { error("%s: Expected runlevel after start/stop NN",pname);return FALSE; }
      
      while (strcmp(t,".")) {
        int level;
	if (strcasecmp(t,"S")==0) level=RUNLEVELS; else {
	  level=atoi(t);
	  if (level<0 || level>=RUNLEVELS) { error("%s: Runlevel out of bounds %d",pname,level);return FALSE; }
	}
	rcd[level][mode]=val;
	t=strtok(NULL," \t");
	if (t==NULL) { error("%s: Runlevel list not terminated by .",pname);return FALSE; }
      }
    }
  } else {
    error("%s: Expected 'start' 'stop' or 'defaults' got %s",pname,t);
    return FALSE;
  }
  
  for(int l=0;l<=RUNLEVELS;l++) {
    for(int m=START;m<=STOP;m++) if (rcd[l][m]) {
      char *where;
      if (l==RUNLEVELS) 
        asprintf(&where,"etc/rcS.d/%c%02d%s",m==START? 'S':'K',rcd[l][m],pname);
      else
        asprintf(&where,"etc/rc%d.d/%c%02d%s",l,m==START? 'S':'K',rcd[l][m],pname);
      if (symlink(target,where)) sys_abort(where);
    }
  }
  return TRUE;
}

/* return the current runlevel */
int get_runlevel() {
  if (runlevel==0) {
    char *p=read_shell("/sbin/runlevel",NULL);
    if (isdigit(p[2])) runlevel=p[2]-'0';
    else {
      error("Cannot obtain runlevel %s. init scripts disabled",strdupa(p));
      runlevel=-1;
    }
  }
  return runlevel;
}

/**********************************************************
    Basic Structures for managing files and Dependencies
**********************************************************/

// If this is set then a translation /etc -> /usr/upm/etc is done when processing files
int config_translation=TRUE;

/* The different modes of the package description use
   P_RECIPE 	Initial state pre build
   P_BUILD	Build package (ADD B records)
   P_INSTALLED	Installed package (ADD DFNL and Z records)
   P_UNLISTED	Current condition of the package is undetermined
*/

enum pmode { P_UNLISTED, P_RECIPE,P_BUILD,P_INSTALLED };
const char *mdirs[]={NULL,"/var/upm/recipe","/var/upm/build","usr/upm/installed"};
const char *mtexts[]={"unlisted packages","available recipes","available binaries","installed packages"};
const char *pmodetext[]={"Unlisted","RECIPE","BUILD","installed package"};

/* What has been read in so far ? */
int read_in[4]={FALSE,FALSE,FALSE,FALSE};

// Types of relationships between packages
enum rtype { R_INVALID, R_BUILD,R_DEPEND,R_PROVIDE,R_CONFLICT,R_REPLACE };
const char *reltab[] = { "**","BUILD","DEPEND","PROVIDE","CONFLICT","REPLACE",NULL };

// Events
enum eventtype { E_NONE,E_PREBUILD,E_POSTBUILD,E_PRECONFIGURE,E_POSTCONFIGURE, E_PREINST, E_POSTINST, E_PREMERGE, E_POSTMERGE, E_PRERM, E_POSTRM,E_PERM };
const char *eventtab[] = { "NONE","PREBUILD","POSTBUILD","PRECONFIGURE","POSTCONFIGURE","PREINST","POSTINST","PREMERGE","POSTMERGE","PRERM","POSTRM", "PERM",NULL };
const char *short_eventtab[] = { "-","<B",">B","<C",">C","<I",">I","<M",">M","<R",">R","P",NULL};

// Blacklist Actions
enum xaction_t { X_ABORT,X_WARN,X_IGNORE,X_MINE };
const char *xactiontab[] = { "ABORT","WARN","IGNORE","MINE",NULL };

// Environmental settings
enum env_t { E_ENV,E_PATH,E_SET };
const char *envtab[] = { "ENV","PATH","SET",NULL };

// Package processing options
enum opt_t { O_BASE,O_OVERWRITE,O_REALROOT,O_INSANE,O_NOBINARY,O_NOCACHE,O_HOLD,O_NOAUTODEP };
const char *opttab[]={"BASE","OVERWRITE","REALROOT","INSANE","NOBINARY","NOCACHE","HOLD","NOAUTODEP",NULL};

struct node {
  struct node *next;		/* Next pointer within package */	
  struct node *nindex;		/* Next pointer within index (index depends on record type) */
  struct package *pkg;		/* Pointer to package of this node */
  char *v2;			/* Pointer to second string (or NULL if not needed). */
  	/* FPS=MD5Sum, YL=Link Target T=code to exec R=condition ABIV=value Z=package U=Text Q=rcd parameter*/
  int lineno;			/* The number of the line where this item was defined */
  uid_t uid;			/* DFNU Userid */
  gid_t gid;			/* DFNU Groupid */
  mode_t mode;			/* DFN Permissions */
  union {
    off_t size;			/* F Filesize */
    dev_t dev;			/* N Device */
    char rcd[4];		/* Q handler flags */
  };
  char type;			/* Type of the record */
  union {
    char x;			/* Abstract value */
    enum rtype relation;	/* R Depend / Conflict etc */
    enum eventtype event;	/* E type of event */
    enum xaction_t xaction;	/* X type of action to take */
    enum env_t env;		/* V type of environment variable to set */
    char lpriority;		/* Y Link priority */
    char config;		/* DFLN Configfile marker used generate_dfln_records */
  };
  char v1[];			/* First string. Zero length if not needed */
  	/* TYDFLNX = Filename HPS=URL R=package ABIV=var W=Text M=email GE=code Q=init.d script U=userid */
};

struct package {
  struct package *next;		/* Pointer to next package */
  char *version;		/* Version */
  char *name;			/* Name of package */
  struct node *r[26];		/* Pointer to the beginning of records of each type */
  struct node *ep[26];		/* Pointer to the end of the chains for each type. */
  				/* If set to NULL then it is recalculated when needed */
  enum pmode mode;		/* What kind of state is this in ? */
  int conffiles;		/* Incremented for each configfile in generate_dfln */
  int lines;			/* Number of lines when this package was read */
  char meta;			/* Is this a meta package ? */
  char base;			/* Is this a base package ? */
  char overwrite;		/* Does this package have overwrite set ? */
  char realroot;		/* Package cannot be build using fakeroot */
  char insane;			/* Do not perform sanity checks */
  char changed;			/* Changes that need to be written back */
  char checked;			/* Dependencies of this package have been checked */
  char nobinary;		/* Never produce any binary for this package */
  char nocache;			/* Do not cache this package */
  char noautodep;		/* Do not do automatic dependency determination */
  char hold;			/* Put this package on hold. No upgrades to be performed. */
  char level;			/* How many lower levels depend on this package */
  char location[];		/* Location this information was retrieved from */
};

/* Virtual "linenumbers" for automatically generated lines */
#define G_PACKAGE_READ -1
#define G_SCAN -2
#define G_BUILD -3
#define G_ANALYSIS -4
#define G_MERGE -5
#define G_ATTRIB -6

char *lexpl[]={"Unknown","Package Read","Scanning","Building","Analysis","Merge","Attribute"};

char plinebuf[6];

char *pline(int l) {
  if (l<=0) return lexpl[-l];
  sprintf(plinebuf,"%d",l);
  return plinebuf;
}

/* Important commonly used routines that are defined later */
const char *exp; 
char *expression(struct package *,int);
char *string_expand(struct package *,const char *,int);
const char *getsetting(const char *,const char *);
struct node *addline(struct package *,int,const char *);
struct node *node_b(struct package *,int,const char *,const char *);
int read_packages(enum pmode);
int pkg_install(const char *);


/* Pointer to the installed base package */
struct package*base=NULL;


enum xref_t { X_BLACKLIST,X_TRIGGER,X_PRIORITYLINK,X_ENVIRONMENT,X_VIRTUAL };

/* One xref per mode per xref_t */
struct node* xref[5][4];

/* Hash to find packages */
#define PHASHVAL 511
struct package *package_hash[4][PHASHVAL];

/* Scramble the shift values so that the hash is improved */
int shiftval[24] = { 0,8,16,24,4,12,20,6,10,14,18,22,1,5,9,13,17,21,3,7,9,11,15,19 };

unsigned phash_calc(const char *file) {
  const char *p=file;
  unsigned hash=0;
  int n=0;
  
  while (*p) {
    hash += ((int)*p++) << shiftval[n++];
    if (n==24) n=0;
  };
  return hash % PHASHVAL;
}

/* Print statistics about the hash use */
void phash_stat(void) {
  int maxdepth=0;
  int filled=0;
  int sum=0;
  struct package *x;
  
  for(int i=P_UNLISTED;i<=P_INSTALLED;i++) if (read_in[i]) {
    maxdepth=0;
    filled=0;
    sum=0;
    for(int j=0;j<PHASHVAL;j++) {
      if (package_hash[i][j]) {
        int depth;

	filled++;
	depth=1;
	x=package_hash[i][j];
	while (x->next) { depth++;x=x->next; }
	sum+=depth;
	if (depth>maxdepth) maxdepth=depth;
      }
    }
    if (filled) info("Package Hash for %s: %d of %d used. Maxdepth=%d Average Depth=%d",mtexts[i],filled,PHASHVAL,maxdepth,(sum*100+50)/filled);
  }
}

#define ALL_PACKAGES(m) for(int i4711=0;i4711<PHASHVAL;i4711++) for(struct package *p=package_hash[m][i4711];p;p=p->next)

void xref_add(struct node *n,enum xref_t x) {
  n->nindex=xref[x][n->pkg->mode];
  xref[x][n->pkg->mode]=n;
}

void xref_remove(struct node *n,enum xref_t x) {
  if (n==NULL) return;
  if (xref[x][n->pkg->mode]==n)
    xref[x][n->pkg->mode]=n->nindex;
  else {
    struct node *p;
    for(p=xref[x][n->pkg->mode];p && p->nindex!=n;p=p->nindex) ;
    if (p==NULL) swerr("xref_remove: Cannot find node on delete");
    p->nindex=n->nindex;
  }
  n->nindex=NULL;
}

struct node* xref_find(char *s,enum xref_t x,enum pmode mode) {
  for(struct node *p=xref[x][mode];p;p=p->nindex) {
    if (strncmp(s,p->v1,strlen(p->v1))==0) return p;
  }
  return NULL;
}

struct node* xref_bestmatch(const char *s,enum xref_t x,enum pmode mode) {
  struct node *bm=NULL;
  int bmlen=0;
  
  for(struct node *p=xref[x][mode];p;p=p->nindex) {
    if (strncmp(s,p->v1,strlen(p->v1))==0) {
      if (strlen(p->v1)>bmlen) {
        bmlen=strlen(p->v1);
        bm=p;
      }
    }
  }
  return bm;
}

#define ACTINDEX(ix,m) for(struct node*y=xref[ix][m];y;y=y->nindex)

void package_action(struct package *pkg,char *r,void (*func)(struct node *)) {
  char *p;
  struct node *x;

  for(p=r;*p;p++) for(x=pkg->r[*p-'A'];x;x=x->next) func(x);
}

#define ACT(p,c) for(struct node*x=(p)->r[(c)-'A'];x;x=x->next) if (x->type) 

/* Hash structures for fast file search.
   Pick a good prime near the expected number of files on the system... */
#define HASHVAL 134156

struct node *file_hash[HASHVAL];

unsigned file_hash_calc(const char *file) {
  const char *p=file;
  unsigned hash=0;
  int n=0;
  
  while (*p) {
//    hash += ((int)*p++) << shiftval[n++];
    hash += ((int)*p++) << n++;
    if (n==24) n=0;
  };
  return hash % HASHVAL;
}

/* Print statistics about the hash use */
void file_hash_stat(void) {
  int maxdepth=0;
  int filled=0;
  int sum=0;
  struct node *x;
  
  for(int i=0;i<HASHVAL;i++) if (file_hash[i]) {
    int depth;

    filled++;
    depth=1;
    x=file_hash[i];
    while (x->nindex) { depth++;x=x->nindex; }
    sum+=depth;
    if (depth>maxdepth) maxdepth=depth;
  }
  if (filled) info("File Hash: %d of %d used. Maxdepth=%d Average Depth=%d",filled,HASHVAL,maxdepth,(sum*100+50)/filled);
}


struct node* file_find(const char *file) {
  unsigned hash=file_hash_calc(file);
  struct node *x;
  
  x=file_hash[ hash];
  while (x && (*(x->v1)!=*file || strcmp(x->v1,file))) x=x->nindex;
  return x;
}

int file_add(struct node *n) {
  struct node *x=file_find(n->v1);
  unsigned hash=file_hash_calc(n->v1);
  
  if (x) fatal("Duplicate Reference to %s by package %s(%d) and package %s(%d)",n->v1,n->pkg->name,n->lineno,x->pkg->name,x->lineno);
  n->nindex=file_hash[hash];
  file_hash[hash]=n;
  return 0;
}

void file_remove(struct node *n) {
  unsigned hash=file_hash_calc(n->v1);
  struct node *x;

  x=file_hash[hash];
  if (x==n) { file_hash[hash]=n->nindex;return; }

  while (x && x->nindex!=n) x=x->nindex;
  if (x) x->nindex=x->nindex->nindex;
  else swerr("Internal error: Cannot find file %s in file_hash bucket",n->v1);
}

int package_condition(char *x,struct package *p,int line) {
  int b;
  char *r;
  if (x==NULL) return TRUE;
  exp=x;
  r=expression(p,line);
  b=r!=NULL;
  if (r) free(r);
  return b;
}

#define package_find(n,m) package_find_with_constraint(n,m,NULL,G_BUILD)

struct package *package_find_with_constraint(const char *name,enum pmode m,char *constraint,int line) {
  struct package *cp=NULL;
  
  if (!read_in[m]) read_packages(m);
  
  /* Find the package with the highest version number */
  for(struct package *x=package_hash[m][phash_calc(name)];x;x=x->next) {
    if (x && strcmp(x->name,name)==0) {
      if (constraint==NULL || package_condition(constraint,x,line)) {
        if (cp==NULL || strverscmp(cp->version,x->version)<0) cp=x;
      }
    }
  }
  
  /* If not found try to find a matching virtual package with the highest version number */
  if (cp==NULL) {
    for(struct node *p=xref[X_VIRTUAL][m];p;p=p->nindex) {
      if (strcmp(name,p->v1)==0) {
        if (cp==NULL || strverscmp(cp->version,p->pkg->version)>0) cp=p->pkg;
      }
    }
  }
  return cp;
}

const char *attr_find(struct package *p,char type,char *var) {
  ACT(p,type) {
    if (strcmp(x->v1,var)==0) return x->v2;
  }
  return NULL;
}

#define pkg_version(p) attr_find(p,'B',"VERSION")
#define pkg_name(p) attr_find(p,'B',"PACKAGE")

const char *pkg_description(struct package *p) {
  if (p->r['W'-'A']) return p->r['W'-'A']->v1;
  return NULL;
}

#define OK_DEP ((struct package *)(1))
/* Check the relationship to another package. Return
   that package if found. NULL if the dependency is
   not fulfilled. OK_DEP if the dependency is ok but
   there is no package to relate to. */
struct package* try_resolve_dependency(struct node *n,enum pmode mode) {
  struct package *p;
  char *x=string_expand(n->pkg,n->v1,n->lineno);
  
  if (x==NULL) return OK_DEP;
  p=package_find_with_constraint(x,mode,n->v2,n->lineno);
  free(x);
  return p;
};

struct package *pkg_list(struct package *p,enum pmode m,const char *newloc) {
  if (newloc!=p->location) {
    p=realloc(p,sizeof(struct package)+strlen(newloc)+1);
    strcpy(p->location,newloc);
  }
  p->mode=m;
  if (m!=P_UNLISTED) {
    unsigned hash=phash_calc(p->name);
 
    p->next=package_hash[p->mode][hash];
    package_hash[p->mode][hash]=p;
    
    ACT(p,'R') { if (x->relation==R_PROVIDE) xref_add(x,X_VIRTUAL); }
  }
  if (m==P_INSTALLED) {
    /* Put files into the files index */
    ACT(p,'F') file_add(x);
    ACT(p,'N') file_add(x);
    ACT(p,'D') file_add(x);
    ACT(p,'L') file_add(x);
    ACT(p,'X') xref_add(x,X_BLACKLIST);
    ACT(p,'V') xref_add(x,X_ENVIRONMENT);
    ACT(p,'Y') xref_add(x,X_PRIORITYLINK);
    ACT(p,'T') xref_add(x,X_TRIGGER);
  };
  return p;
}

void node_delink(struct node *n) {
  /* need to remove this from the nindex if DFLN */
  if (n->pkg->mode==P_INSTALLED) {
    if (n->type=='X') xref_remove(n,X_BLACKLIST);
    else if (n->type=='T') xref_remove(n,X_TRIGGER);
    else if (n->type=='Y') xref_remove(n,X_PRIORITYLINK);
    else if (n->type=='V') xref_remove(n,X_ENVIRONMENT);
    else if (strchr("DFLN",n->type)) file_remove(n);
  }
  if (n->pkg->mode!=P_UNLISTED) {
    if (n->type=='R' && n->relation==R_PROVIDE) xref_remove(n,X_VIRTUAL);
  }
}

void node_remove(struct node *n) {
  if (n) {
    node_delink(n);
    
    /* Remove this node from the package hash */
    struct node *x=n->pkg->r[n->type-'A'];

    if (x==n)
      n->pkg->r[n->type-'A']=n->next;
    else {
      while (x && x->next !=n) x=x->next;
      if (x) x->next=n->next;
      else swerr("Internal: node_remove: unable to locate node in package chain");
    }
    /* Cause a refresh of the end pointer */
    n->pkg->ep[n->type-'A']=NULL;
    n->next=NULL;
    n->pkg->changed=TRUE;
    free(n);
  }
}

void pkg_delist(struct package *pkg) {
  unsigned hash=phash_calc(pkg->name);
  struct package *x;

  for(int i='A';i<='Z';i++) ACT(pkg,i) node_delink(x);
  
  x=package_hash[pkg->mode][hash];
  if (x==pkg)
    package_hash[pkg->mode][hash]=pkg->next;
  else {
    while (x && x->next!=pkg) x=x->next;
    if (x) x->next=x->next->next;
    else swerr("Internal error: Cannot find package %s in phash bucket",pkg->name);
  }

  pkg->mode=P_UNLISTED;
}

void pkg_remove(struct package *pkg) {
  int i;
  
  if (pkg->mode!=P_UNLISTED) pkg_delist(pkg);
  /* Call destructors for all components */
  for(i=0;i<26;i++) while (pkg->r[i]) node_remove(pkg->r[i]);
  free(pkg);
}

int pkg_has(struct package *pkg,char *r) {
  char *p;
  
  for(p=r;*p;p++) if (pkg->r[*p-'A']) return TRUE;
  return FALSE;
}

int node_count(const struct node *n) {
  int count=0;
  while (n) { count++;n=n->next; }
  return count;
};

int node_run(struct node *x,int may_fail,char *log) {
  int rc;
  char *s=string_expand(x->pkg,x->type!='T' ? x->v1: x->v2,x->lineno);
  
  if (s && *s) {
/* Add additional shorthand features
   >>file text => append text to file
   >file text  => append text to file zapping it before
   @file file => Sed action on file
*/
    if (s[0]=='@') {
      char *p=s+1;
      while (*p && *p!=' ') p++;
      if (*p=='/') p++;
      if (*p==0) {
        error("%s(%d): Empty string at SED Event",x->pkg->name,x->lineno);
	free(s);
	return 199;
      }
      *p++=0;
      if (shell(log ? "(cp %s %s.tmp) >>%s 2>&1" : "cp %s %s.tmp",s+1,s+1,log)) {
        rc=errno;
	error("%s(%d): Copy Event failed:%s",x->pkg->name,x->lineno,s);
        free(s);
	return rc;
      }
      if (shell(log ? "(sed -e '%s' %s.tmp >%s) >>%s 2>&1":"sed -e '%s' %s.tmp >%s",p,s+1,s+1,s+1,log)) {
        rc=errno;
	error("%s(%d) SED event failed: %s",x->pkg->name,x->lineno,s);
	free(s);
	return rc;
      }
      if (unlink(catstr(s+1,".tmp",NULL))) {
        rc=errno;
        error("%s(%d): unlink failed %s:%s",x->pkg->name,x->lineno,s+1,strerror(errno));
	free(s);
	return rc;
      }
    } else
    if (s[0]=='>') {
      FILE *f;
      char *p=s+1;
      char *mode="w";
      char *name;
      
      if (*p=='>') { p++;mode="a"; }
      name=p;
      while (*p && *p!=' ') p++;
      if (*p) *p++=0;
      f=fopen(name,mode);
      if (f==NULL) {
        error("%s(%d): > action file %s:%s",x->pkg->name,x->lineno,name,strerror(errno));
	free(s);
	return errno;
      }
      fputs(p,f);
      fputc('\n',f);
      fclose(f);
    } else
    if ((rc=shell(log ? "(%s) >>%s 2>&1": "%s",s,log))) {
      error("%s(%d): Event script failed:%s",x->pkg->name,x->lineno,s);
      free(s);
      return rc;
    }
    free(s);
  }
  return 0;
}

int node_retrieve(struct node *x,const char *defaulturl) {
  char *s=string_expand(x->pkg,x->v1,x->lineno);

  if (s==NULL || *s==0) { error("%s(%d): Cannot retrieve %s expands to nothing.",x->pkg->name,x->lineno,x->v1); return FALSE; }
  if (s[0]!='@' && strchr(s,':')==0) {
    catstr(defaulturl,"/",s,NULL);
    free(s);
    s=strdup(buffer);
  }
 
  if (s[0]=='@') { /* Fetch from mirror */
    const char *p;
    const char *mirrors;
    char *name;
    char *q=s+1;
    while (*q && *q!='/') q++;
    *q=0;
    /* Retrieve mirror list */
    mirrors=getsetting("mirror",s+1);
    if (mirrors==NULL) { error("%s(%d): Mirror %s does not exist. Cannot retrieve %s",x->pkg->name,x->lineno,s+1,x->v1);return FALSE; }
    /* loop through mirror list and try to retrieve */
    name=q+1;
    p=mirrors;
    do {
      const char *mirror=p;
      char *source;
      while (*p && *p!=' ') p++;
      source=malloc(p-mirror+2+strlen(name));
      strncpy(source,mirror,p-mirror);
      source[p-mirror]=0;
      strcat(source,"/");
      strcat(source,name);
      if (retrieve(source,x->v2)==0) { free(s);free(source);return TRUE; }
      free(source);
    } while (*p++);
    error("%s(%d): Cannot retrieve %s",x->pkg->name,x->lineno,x->v1);
    free(s);
    return FALSE;
  } else {  
    if (retrieve(s,x->v2)) {
      error("%s(%d): Cannot retrieve %s",x->pkg->name,x->lineno,x->v1);
      free(s);
      return FALSE;
    }
  }
  free(s);
  return TRUE;
}

void node_setmd5(struct node *x) {
  if (x->v2[0]==0 || x->v2[0]==' ') {
    char *s=string_expand(x->pkg,x->v1,x->lineno);
    char *p=s+strlen(s);
    while (p>s && *--p!='@') ;
    if (*p=='@') *p=0;
    strcpy(x->v2,md5sum(catstr(cache_files,"/",basename(s),NULL)));
    free(s);
  }
}

struct node *node_new(struct package *p,int lineno,char type,const char *v1,const char *v2,int xv) {
  struct node *x;
  struct node *e=p->r[type-'A'];
  int l1=v1 ? strlen(v1)+1 : 1;
  int l2=v2 ? strlen(v2)+1 : 0;
 
  if (strchr("DFLNXYTZ",type) && (v1==NULL || *v1==0 || *v1=='/')) fatal("Bad filename '%s'. Cannot be empty or begin with a /",v1);
  /* Avoid duplicates for certain record types */
  if (strchr("BIAR",type)) {
    for(e=p->r[type-'A'];e;e=e->next) if (xv==e->x) {
      if (strcmp(v1,e->v1)==0) {
        /* This basically catches both v2s==NULL */
	if (e->v2==v2) return e;
	
	if (type=='R' && e->v2==NULL && v2) {
	  /* replacing no condition with condition */
	  node_remove(e);
	  goto addit;
	}
	/* Add no condition to an already existing dependency with conditional. Simple keep the old more restrictive
	   setting */
	if (type=='R' && e->v2 && v2==NULL) return e;
	
	/* Now check if the second parameter is the same. If not there is trouble */
	if (e->v2==NULL || v2==NULL || strcmp(e->v2,v2)) {
	  /* R records are possible with multiple conditions */
	  if (type=='R') goto addit;
	  error("%s(%d): %c record value %s=%s attempt to change to %s ignored",p->name,lineno,type,v1,e->v2,v2);
	}
	return e;
      }
    }
  }
 addit:
  x=calloc(1,sizeof(struct node)+l1+l2);
  
  x->pkg=p;
  x->type=type;
  x->v2=x->v1+l1;
  x->lineno=lineno;
  x->x=xv;
  
  if (v1) strcpy(x->v1,v1);
  if (v2) strcpy(x->v2,v2); else x->v2=NULL;
  
  /* Attach this node to the end of the chain. This is necessary to keep the order
     and to allow addition while the chain is already being parsed (G lines) */
  if (p->r[type-'A']) {
    /* Check if we have a valid endpointer. If so use it */
    if (p->ep[type-'A']) {
      e=p->ep[type-'A'];
    } else {
      for(e=p->r[type-'A'];e->next;e=e->next) ;
    }
    e->next=x;
  } else p->r[type-'A']=x;
  /* Update end pointer */
  p->ep[type-'A']=x;

  p->changed=TRUE;
  if (p->mode==P_INSTALLED) {
    if (type=='X') xref_add(x,X_BLACKLIST); else
    if (type=='T') xref_add(x,X_TRIGGER); else
    if (type=='Y') xref_add(x,X_PRIORITYLINK); else
    if (type=='V') xref_add(x,X_ENVIRONMENT); else
    if (strchr("DFLN",type)) file_add(x);
  }
  if (type=='R' && x->relation==R_PROVIDE && p->mode!=P_UNLISTED) xref_add(x,X_VIRTUAL); 
  return x;
}

#define node_a(p,n,a,v) node_new(p,n,'A',a,v,0);

struct node *node_b(struct package *p,int n,const char *a,const char *v) {
  struct node *x=node_new(p,n,'B',a,v,0);
  if (strcmp(a,"PACKAGE")==0) p->name=x->v2;
  if (strcmp(a,"VERSION")==0) p->version=x->v2;
  return x;
}

#define node_c(p,n,s,m5) node_new(p,n,'C',s,m5 ? m5: EMPTY_MD5,0)

struct node *node_dfn(struct package *p,int n,char type,char *f,char *m5,uid_t u,gid_t g,mode_t m,char conf) {
  struct node *x=node_new(p,n,type,f,m5,conf);
  struct suidrec *s;
  if ((s=find_suid(f))) {
    u=s->uid;
    g=s->gid;
    m=s->mode;
  }
  x->uid=u;
  x->gid=g;
  x->mode=m;
  return x;  
}

#define node_d(p,n,f,u,g,m,conf) node_dfn(p,n,'D',f,NULL,u,g,m,conf)
#define node_e(p,n,s,c) node_new(p,n,'E',c,NULL,s)

struct node *node_f(struct package *p,int n,char *f,uid_t u,gid_t g,mode_t m,char *m5,size_t s,char conf) {
  struct node *x=node_dfn(p,n,'F',f,m5,u,g,m,conf);
  x->size=s;
  return x;
}

#define node_g(p,n,h) node_new(p,n,'G',h,NULL,0)
#define node_h(p,n,h) node_new(p,n,'H',h,NULL,0)
#define node_i(p,n,var,val) node_new(p,n,'I',var,val,0)
#define node_l(p,n,f,t,conf) node_new(p,n,'L',f,t,conf)
#define node_m(p,n,m) node_new(p,n,'M',m,NULL,0)

struct node *node_n(struct package *p,int n,char *f,uid_t u,gid_t g,mode_t m,dev_t dev,char conf) {
  struct node *x=node_dfn(p,n,'N',f,NULL,u,g,m,conf);
  x->dev=dev;
  return x;
}

struct node *node_q(struct package *p,int n,char *mode,char *s,char *pa) {
  struct node *x=node_new(p,n,'Q',s,pa,0);
  if (strlen(mode)<4) strcpy(x->rcd,mode); else error("%s(%d): A Maximum of 3 Q flags is allowed",p->name,n);
  return x;
}

#define EMPTY_MD5 "                                   "

struct node* node_o(struct package *p,int n,char *o,int opt) {
  switch (opt) {
    case O_OVERWRITE: p->overwrite=TRUE;break;
    case O_REALROOT:  p->realroot=TRUE;break;
    case O_INSANE:    p->insane=TRUE;break;
    case O_NOBINARY:  p->nobinary=TRUE;break;
    case O_NOCACHE:   p->nocache=TRUE;break;
    case O_HOLD:      p->hold=TRUE;break;
    case O_NOAUTODEP: p->noautodep=TRUE;break;
    case O_BASE:      p->base=TRUE;break;
  }
  return node_new(p,n,'O',o,NULL,0);
}

#define node_p(p,n,patch,m5) node_new(p,n,'P',patch,m5 ? m5: EMPTY_MD5,0)
#define node_r(p,n,r,target,condition) node_new(p,n,'R',target,condition,r)
#define node_s(p,n,s,m5) node_new(p,n,'S',s,m5 ? m5: EMPTY_MD5,0)
#define node_t(p,n,file,target) node_new(p,n,'T',file,target,0)

struct node *node_u(struct package *p,int n,char *user,int u,int g,char *name) {
  struct node *x=node_new(p,n,'U',user,name,0);
  x->uid=u;
  x->gid=g;
  return x;
}

#define node_v(p,n,e,var,val) node_new(p,n,'V',var,val,e)
#define node_w(p,n,text) node_new(p,n,'W',text,NULL,0)
#define node_x(p,n,f,a) node_new(p,n,'X',f,NULL,a)
#define node_y(p,n,f,target,priority) node_new(p,n,'Y',f,target,priority)
#define node_z(p,n,f,pack) node_new(p,n,'Z',f,pack,0)
#define node_comment(p,n,text) node_new(p,n,'K',text,NULL,0)

/********************************************************
            Read Configuration File
********************************************************/

struct sect {
  char *envz;
  size_t envz_len;
  struct sect *next;
  char name[];
} *sect_root=NULL;

struct sect *findsection(const char *section) {
  struct sect *s=sect_root;

  while (s && strcmp(s->name,section)) s=s->next;
  return s;
}

struct sect *needsection(const char *section) {
  struct sect *s=findsection(section);

  if (s) return s;
  s=calloc(1,sizeof(struct sect)+strlen(section)+1);
  s->next=sect_root;
  strcpy(s->name,section);
  sect_root=s;
  return s;
}

const char *getsetting(const char *section,const char *variable) {
  struct sect *s;
  
  s=findsection(section);
  return s ? envz_get(s->envz,s->envz_len,variable): NULL;
}

void putsetting(char *section,char *var,char *val) {
  struct sect *s;
  s=findsection(section);
  if (s) envz_add(&s->envz,&s->envz_len,var,val);
  else fatal("Section %s not found",section);
};

struct passwd * guserinfo(const char *x) {
  struct passwd *p;
  const struct passwd *q;
  p=malloc(sizeof(struct passwd));
  q=getpwnam(x);
  if (!q) fatal("User %s unknown on the system",x);
  memcpy(p,q,sizeof(struct passwd));
  return p;
}

void readconffile(char *file) {
  int lineno=0;
  FILE *f=fopen(file,"r");
  struct sect *sp;
  char *p;
  const char *x;

  /* If this is run as a user and there is no /etc/upm.conf then the user
     might have had to resort to an .upmrc file. Allow that */

  if (f==NULL) return;
  
  sp=needsection("");
    
    while (fgets(buffer,MAXLLENGTH,f)) {
      lineno++;
      if (buffer[0]=='#' || buffer[0]==0 || buffer[0]=='\n') continue;
      buffer[strlen(buffer)-1]=0;
      if (buffer[0]=='[') {
        /* Section start */
        p=buffer+1;
        while (*p && *p!=']') p++;
        if (*p==0) fatal("] missing in configuration file %s line %d",file,lineno);
        x=strndupa(buffer+1,p-buffer-1);
        sp=needsection(x);
      } else {
        p=buffer+1;
        while (*p && (isalpha(*p) || isdigit(*p) || *p=='_')) p++;
        if (*p!='=') fatal("%s(%d): syntax error in config",file,lineno);
        *p++=0;
        envz_add(&sp->envz,&sp->envz_len,buffer,p);
      }
    }
    fclose(f);
    sect_root=sp;

  save_binaries=getsetting("","save_binaries");
  x=getsetting("","binaries");
  if (x) {
    if (strcasecmp(x,"iflocal")==0) binaries=B_IFLOCAL; else
    if (strcasecmp(x,"ifavail")==0) binaries=B_IFAVAIL; else
    if (strcasecmp(x,"always")==0) binaries=B_ALWAYS; else
    if (strcasecmp(x,"never")==0) binaries=B_NEVER; else
    fatal("Binary mode %s not supported",x);
  } else binaries=B_IFLOCAL; 
  x=getsetting("","mirror");
  if (x) mirror=x;
  flog=getsetting("","logfile");
  
  x=getsetting("","loglevel");
  if (x) loglevel=atoi(x);
  
  x=getsetting("","viewlevel");
  if (x) viewlevel=atoi(x);
  
  x=getsetting("","retrieve_command");
  if (x) retrieve_command=x;
  
  x=getsetting("","scripts");
  if (x) scripts=x;
  
  x=getsetting("","temp");
  if (x) temp_dir=x;
  
  x=getsetting("","cache_files");
  if (x) cache_files=x;
  
  x=getsetting("","recipe");
  if (x) mdirs[P_RECIPE]=x;
  
  x=getsetting("","build");
  if (x) mdirs[P_BUILD]=x;
 
  x=getsetting("","descriptions");
  if (x) descriptions=x;

  x=getsetting("","sync");
  if (x) rsyncloc=x;
  
  x=getsetting("","sources");
  if (x) source_loc=x;
  
  x=getsetting("","patches");
  if (x) patch_loc=x;

  x=getsetting("","builduser");
  if (x) builduser=guserinfo(x);
 
  x=getsetting("","upmuser");
  if (x) upmuser=guserinfo(x);
}

void readconfig() {

  /* If this is run as a user and there is no /etc/upm.conf then the user
     might have had to resort to an .upmrc file. Allow that */
  readconffile("/usr/upm/standard.def");
  readconffile("/etc/upm.conf");
  if (uid) readconffile(catstr(getenv("HOME"),"/.upmrc",NULL));
  
  if (uid==0) {
    if (flog)
      logfile=fopen(flog,"a"); 
    else
      logfile=fopen("/var/log/upm.log","a");
    if (logfile==NULL) { perror(flog);exit(5); }
    setvbuf(logfile,NULL,_IOLBF,BUFSIZ);
  } else logfile=NULL;
  
  if (!builduser && uid==0) fakeroot=FALSE;
}

void package_write(struct package *);
struct package *package_read(const char *,enum pmode);

void pkg_hold(char *name) {
  struct package *p;
  p=package_find(name,P_INSTALLED);
  if (p==NULL) fatal("%s not installed in pkg_hold",name);
  node_o(p,G_BUILD,"HOLD",O_HOLD);
  package_write(p);
}

void pkg_unhold(struct package *p) {
  struct node*y;
  p->hold=FALSE;
  y=NULL;
  ACT(p,'O') if (strcmp(x->v1,"HOLD")==0) y=x;
  if (y) node_remove(y); else swerr("unhold: Cannot find O HOLD");
  package_write(p);
}
 
/* Run an init script if the script should be allowed in the current runlevel.
   Allow the disabling of init scripts.
   Return value indicates if the script was actually run.
*/
int init_script(struct package *p,char *iname,int mode) {
  char *match;
  int matchl;
  int inamel;
  int runlevel;
  
  /* Need to verify that script should run in current runlevel */
  if (noinitscript) return FALSE;
  runlevel=get_runlevel();
  if (runlevel<0) return FALSE;
  asprintf(&match,"etc/rc%d.d/S",runlevel);
  matchl=strlen(match);
  inamel=strlen(iname);
  /* Search for link that would indicate permissions to run in this level */
  ACT(p,'L') {
    debug("Checking %s",x->v1);
    if (strncmp(x->v1,match,matchl)==0 && strcmp(x->v1+strlen(x->v1)-inamel,iname)==0) {
       /* We got a matching link */
       if (shell("/etc/init.d/%s %s",iname,mode==START ? "start":"stop")) {
          error("%s: /etc/init.d/%s script failed",p->name,iname);
	  return FALSE;
       }
       return TRUE;
    }
  }
  return FALSE;
}
 

/************************************************************
   Dependency Analysis
************************************************************/

#define MAXDEPTH 20

enum issue_t { I_CONFLICT,I_MISSING,I_INSTALL };

struct mdep {
  struct mdep *next;
  enum issue_t issue;
  int level;
  int count;
  struct package *p1;
  struct package *p2;
  char *condition;
  char pname[];
};

/* Add new element to the list */
struct mdep* new_mdep(struct mdep *root,enum issue_t i,int level,struct package *p1,struct package *p2,char *n,char *c) {
  struct mdep *m=calloc(1,sizeof(struct mdep)+strlen(n)+1);
  /* Make this an ordered list .... */
  m->issue=i;
  m->p1=p1;
  m->p2=p2;
  m->condition=c;
  m->level=level;
  strcpy(m->pname,n);
  if (root) {
    if (strcmp(n,root->pname)<0) {
      m->next=root;
      return m;
    } else {
      struct mdep *p;
      for(p=root;p->next;p=p->next) if (strcmp(n,p->next->pname)<0) break;
      if (strcmp(p->pname,n)==0) {
        if (p1==p->p1 && p2==p->p2 && i==m->issue && c==m->condition) {
	  warn("%s: Same element inserted twice into dependency list. Skipped",p->pname);
	  free(m);
	  return root;
	}
      }
      /* Insert into list */      
      m->next=p->next;
      p->next=m;
      return root;
    }
  } else return m;
}

/* Array used to track dependency nesting and eventual dependency loops */
struct package *depvec[MAXDEPTH];

struct mdep *dep_checking(struct package *pkg,int level,struct mdep *m) {
  struct package *r;

  if (level>0) {
    for(int i=0;i<level;i++) if (depvec[i]==pkg) {
      buffer[0]=0;
      for(int j=0;j<level;j++) { strcat(buffer,depvec[j]->name);strcat(buffer," "); };
      char *x=strdup(buffer);
      debug("%s: Dependency loop with %s",pkg->name,x);
      free(x);
      return m;
    }
  }

  if (pkg->checked) return m;
  
  if (level>MAXDEPTH) fatal("%s: Maximum Dependency depth reached",pkg->name);

  depvec[level]=pkg;
  
  pkg->checked=TRUE;
  
  ACT(pkg,'R') if (x->relation!=R_PROVIDE) {
    /* If relation pointer is not set see if it can be satisfied */
    r=try_resolve_dependency(x,P_INSTALLED);
    if (r==NULL) r=try_resolve_dependency(x,P_RECIPE);
    if (r==OK_DEP) continue;
    
    /* A dependency and no package leads to a failure */
    if (x->relation==R_DEPEND) {
      /* If there is no match at all possible then note that fact */
      if (r==NULL) m=new_mdep(m,I_MISSING,level,pkg,NULL,x->v1,x->v2); else {
         m=dep_checking(r,level+1,m);
	 /* If the package is not already installed then record the need to install/build it */
	 if (r->mode!=P_INSTALLED) m=new_mdep(m,I_INSTALL,level,pkg,r,r->name,x->v2);
	 if (r->level>=pkg->level) pkg->level=r->level+1;
      }
    }
    /* Conflicts with installed packages */
    if (x->relation==R_CONFLICT
        && r
	&& r!=pkg
	&& strcmp(r->name,pkg->name) 
	&& r->mode==P_INSTALLED) m=new_mdep(m,I_CONFLICT,level,pkg,r,x->v1,x->v2);
  }
  return m;
}

struct mdep *dep_check(struct package *pkg) {
  return dep_checking(pkg,0,NULL);
}

void mdep_free(struct mdep *m) {
  if (m) {
    if (m->next) free(m->next);
    free(m);
  }
}

/* Check for unresolvable issues (conflicts and missing) */
int mdep_serious(struct mdep *root) {
  struct mdep *m;
  for(m=root;m;m=m->next) {
    if (m->issue==I_MISSING) {
      return TRUE;
    }
    if (m->issue==I_CONFLICT) {
      return TRUE;
    }
  }
  return FALSE;
}


void mdep_print(struct mdep *root) {
  /* Print dependency information */
  struct mdep *m;
  for (m=root;m;m=m->next) {
    char *c=m->condition;
    if (c==NULL) c="";
    switch (m->issue) {
      case I_MISSING : error("%s: Depends on %s %s which is not available",m->p1->name,m->pname,c);break;
      case I_CONFLICT: error("%s: Conflicts with installed package %s %s",m->p1->name,m->p2->name,c);break;
      case I_INSTALL: warn("%s: Needs %s %s which has not been installed yet",m->p1->name,m->p2->name,c);break;
    }
  }
}

/* Check dependencies of all packages on the system */
int dep_check_all(enum pmode m) {
  int result=TRUE;
  ALL_PACKAGES(m) p->checked=FALSE;
  ALL_PACKAGES(m) {
    if (p->checked==FALSE) {
      struct mdep *m= dep_check(p);
      if (m) { mdep_print(m);result=FALSE;mdep_free(m); }
    }
  }
  return result;
}
/* Package needs another package. Verify that dependency exists
   If it does not then add new dependency */
void package_needs(struct package *p,char *pname,char *cond,char *reason) {
  /* Check if this dep already exists */
  ACT(p,'R') if (x->relation==R_DEPEND && strcmp(x->v1,pname)==0) return;
  node_r(p,G_BUILD,R_DEPEND,pname,cond);
  info("%s: Added dependency on %s because %s",p->name,pname,reason);
}

#define MAXBUILDNESTING 20
struct mdep *build_dep_check(struct package *p,struct mdep *m);

struct mdep *build_dep_item(struct package *p,struct node *z,struct mdep *m,struct package **nest,int level) {
  struct package *r;
   
  r=try_resolve_dependency(z,P_INSTALLED);  
  if (r==NULL) r=try_resolve_dependency(z,P_RECIPE);
 
  /* Just to be able to trace what is going on */
  buffer[0]=0;
  for(int j=0;j<level;j++) { strcat(buffer,nest[j]->name);strcat(buffer," "); } 
  debug("build_dep_item: nest=%s p=%s z=%s level=%d",strdupa(buffer),p->name,z->v1,level);
  
  if (r) {
    if (r!=OK_DEP) {
      char *n=strdupa(catstr("BUILD_",r->name,NULL));
      
      for(int i=0;i<level;i++) if (nest[i]==r) {
        buffer[0]=0;
	for(int j=i;j<level;j++) { strcat(buffer,nest[j]->name);strcat(buffer," "); }
	debug("%s: Build dependency loop involving %s",p->name,strdupa(buffer));
	return m;
      }
      if (level>MAXBUILDNESTING) fatal("Too deep build dependency nesting");
      nest[level++]=r;

      /* Has the build attribute already been calculated ? */
      if (attr_find(p,'B',n)) return m;
      
      node_b(p,G_BUILD,n,r->version);
      m=dep_checking(r,0,m);
      /* If the package is not already installed then record the need to install/build it */
      if (r->mode!=P_INSTALLED) m=new_mdep(m,I_INSTALL,1,p,r,r->name,z->v2);
      
      /* Process any G lines */
      ACT(r,'G') {
        struct node *y=addline(p,G_BUILD,x->v1);
	
	if (y==NULL) fatal("%s(%d): G Line syntax error",r->name,x->lineno);
        debug("%s: Added G Line (%s(%d):%s)",p->name,r->name,x->lineno,x->v1);
	if (y->type=='R' && x->relation==R_BUILD) m=build_dep_item(p,x,m,nest,level);
      }
      /* If the package needed for building is not yet installed then we also need
         all build dependencies of that package .... */
      if (r->mode!=P_INSTALLED) {
        ACT(r,'R') {
	  if (x->relation==R_BUILD) m=build_dep_item(r,x,m,nest,level);
	  if (x->relation==R_DEPEND) m=dep_checking(r,0,m);
	}
      }
    }
  } else m=new_mdep(m,I_MISSING,1,p,NULL,z->v1,z->v2);
  return m;
}

struct mdep *build_dep_check(struct package *p,struct mdep *m) {
  struct package * nest[MAXBUILDNESTING];

  nest[0]=p; 
  ACT(p,'R') { 
    if (x->relation==R_BUILD) m=build_dep_item(p,x,m,nest,1);
    /* Rnntime dependencies are needed too.... Not sure if this is right */ 
    if (x->relation==R_DEPEND) m=dep_checking(p,0,m);
  }
  return m;
}

struct builditem {
  char *name;
  int deps;	/* This package depends on how many others in the list */
  int rdeps; 	/* How many other packages depend on this one */
  int installed;	/* Is the package actually installed */
};

struct buildlist {
 int maxl;	/* Maximum elements on the list */
 int elements;	/* Current elements on the list */
 struct builditem *list;	/* Pointers to the names of the packages to be build */
};

struct buildlist *buildlist_new(void) {
  struct buildlist *b=calloc(1,sizeof(struct buildlist));
  b->maxl=64;
  b->list=calloc(b->maxl,sizeof(struct builditem));
  return b;
}

void buildlist_free(struct buildlist *b) {
  /* Also need to unalloc strings */
  for(struct builditem *bp=b->list;bp<b->list+b->maxl;bp++) if (bp->name) free(bp->name);
  free(b->list);
  free(b);
};

struct builditem *buildlist_add(struct buildlist *b,char *name) {
  struct builditem *empty=NULL;
  
  if (name==NULL) swerr("buildlist add: name=NULL");
  
  for(struct builditem *bp=b->list;bp<b->list+b->maxl;bp++) {
    if (bp->name==NULL) {
      if (empty==NULL) empty=bp;
    } else {
     if (strcmp(name,bp->name)==0) return bp;
    }
  }

  if (empty==NULL) {
    /* Extend storage */
    int i=b->maxl;
    b->maxl *=2;
    b->list=realloc(b->list,2*i*sizeof(struct builditem));
    memset(b->list+i,0,i*sizeof(struct builditem));
    empty=b->list+i;
  }
  empty->name=strdup(name);
  b->elements++;
  return empty;
};

void buildlist_clear(struct buildlist *b,struct builditem *bp) {
  if (bp->name) {
    free(bp->name);
    bp->name=NULL;
    b->elements--;
  } else swerr("Trying to erase element from buildlist that is not present");
}

struct builditem *buildlist_in(struct buildlist *b,char *n) {
  for(struct builditem *p=b->list;p<b->list+b->maxl;p++) if (p->name && strcmp(n,p->name)==0) return p;
  return NULL;
}

/* Essential packages in the necessary build order */
char *buildprioritylist[] = { "upm","base","gcc","glibc","gzip","bzip2","tar","diffutils","bash","fileutils","findutils","gawk","grep","sed","sh-utils","textutils",NULL};

/* Does the building and removes list then */
int buildlist_process(struct buildlist *b,int action) {
  int count=0;
  /* Verify list and check if all missing builds are on the list */
  for(int i=0;i<b->maxl;i++) {
    /* Need to recalculate address on each loop because buildlist_add might move list */
    struct builditem *bp=b->list+i;
    if (bp->name) {
      struct package *p=package_find(bp->name,P_RECIPE);
      struct mdep *m=build_dep_check(p,NULL);
      bp->installed=package_find(bp->name,P_INSTALLED)!=NULL;
      if (mdep_serious(m)) {
        mdep_print(m);
        error("Cannot build package %s",bp->name);
        buildlist_clear(b,bp);
      } else {
        struct mdep *x=m;
        while(x) {
 	  if (!buildlist_in(b,x->pname)) buildlist_add(b,x->pname);
          x=x->next;
        }
      }
      mdep_free(m);
    }
  }

  /* Build packages until nothing left to build */
  while(b->elements) {
    int deps;
    int rdeps;
    struct builditem *candidate=NULL;
    struct package *p;
   
    
     /* Search for build essential packages. If so take the one with the highest priority */
    for(char **p=buildprioritylist;*p;p++) {
      for(struct builditem *bp=b->list;bp<b->list+b->maxl;bp++) if (bp->name) {
        if (strcmp(bp->name,*p)==0) {
	  candidate=bp;
	  goto buildit;
	}
      }
    } 
    
    /* Now we actually have to do something complex. Therefore we need some statistics */
    if (candidate==NULL) {
      /* Zero statistics */
      for(struct builditem *bp=b->list;bp<b->list+b->maxl;bp++) { bp->deps=0;bp->rdeps=0; };

      for(struct builditem *bp=b->list;bp<b->list+b->maxl;bp++) if (bp->name) {
        struct package *p=package_find(bp->name,P_RECIPE);
        struct builditem *bi;

        ACT(p,'R') { 
	  if (x->relation==R_BUILD && (bi=buildlist_in(b,x->v1))) {
	    if (bi->installed) {
	      bp->deps++;
	      bi->rdeps++;
	    } else { /* Package depends on not installed package and is unbuildable now */
	      deps=2000000000;
            }
	  }
	}
      }
      /* Find the best canditate with rdeps but minimal deps */
      deps=2000000000;
      rdeps=0;
      for(struct builditem *bp=b->list;bp<b->list+b->maxl;bp++) if (bp->name) {
        if (bp->rdeps) {
          if (bp->deps < deps || (bp->deps==deps && bp->rdeps > rdeps)) {
  	    candidate=bp;
	    deps=bp->deps;
	    rdeps=bp->rdeps;
	  }
        }
      }
    }
    if (candidate==NULL) {
      /* There is no candidate with rdeps>0. So pick the one with the lowest deps */
      for(struct builditem *bp=b->list;bp<b->list+b->maxl;bp++) if (bp->name) {
        if (bp->deps<deps) { candidate=bp;deps=candidate->deps; }
      }
    }
   buildit:
    if (candidate==NULL) swerr("buildlist_process candidate=NULL");
    p=package_find(candidate->name,P_RECIPE);
    if (action) {
      if (pkg_install(p->location)) {
        count++;
	candidate->installed=TRUE;
      } else {
	if (package_find(candidate->name,P_INSTALLED)) {
	  pkg_hold(p->name);
	  info("%s: Put on hold",p->name);
	} else warn("%s: Not installed cannot hold",p->name);
      }
    } else info("Would build %s",p->location);
    buildlist_clear(b,candidate);
  }
  buildlist_free(b);
  return count;
}

/* Returns true if all needed packages were successfully installed */
int mdep_install(struct mdep *root) {
  struct mdep *m;
  int nr;
  struct buildlist *b=buildlist_new();
  
  for(m=root;m;m=m->next) if (m->issue==I_INSTALL) buildlist_add(b,m->p2->name);
  mdep_free(root);
  nr=b->elements;
  return nr==buildlist_process(b,TRUE);
}


/************************************************************
    Reading of metadata 
************************************************************/

/* Fast way to read octals */
unsigned inline moct(char *s) {
  unsigned int x=0;
  while (isdigit(*s)) x=x*8+*s++-'0';
  return x;
}

/* Fast way to read ints */
unsigned inline mint(char *s) {
  unsigned int x=0;
  while (isdigit(*s)) x=x*10+*s++-'0';
  return x;
}

/* Fast way to read long ints */
unsigned long long inline mlong(char *s) {
  unsigned long long x=0;
  while (isdigit(*s)) x=x*10+*s++-'0';
  return x;
}


/* This array determines how the parameters are split off in pars */
char parlength[26] = { 1,1,2,4,1,6,0,1,1,-1,-1,2,1,6,1,1,2,2,1,1,3,2,0,2,3,2 };

// Can appear in recipe and all other formats */
#define MRECIPE ((1 << P_RECIPE) + (1 << P_BUILD) + (1<<P_INSTALLED) + (1<<P_UNLISTED))
// Generated during build cannot show up in recipe
#define MBUILD ((1<<P_BUILD) + (1<<P_INSTALLED) + (1<<P_UNLISTED))
// generated during install cannot show up in build or recipe
#define MINST ((1<<P_INSTALLED) + (1<<P_UNLISTED))

/* Permissions: In which types of metadata can which record type appear */
char mallow[26] = { MRECIPE,MBUILD,MBUILD,MINST,MRECIPE,MINST,MRECIPE,MRECIPE,MINST,0,0,MINST,MRECIPE,
  MINST,MRECIPE,MRECIPE,MRECIPE,MRECIPE,MRECIPE,MRECIPE,MRECIPE,MRECIPE,MRECIPE,MRECIPE,MRECIPE,MINST };

struct node *addline(struct package *pkg,int lineno,const char *line) {
  int maxpar;
  char **pp;
  char *p;
  char *l;
  char *par[7];
 
  if (line[0]=='#') maxpar=0; else {
    maxpar=parlength[line[0] -'A'];
    if ((mallow[line[0]-'A'] & ((char)1 << pkg->mode))==0) {
      error("%s(%d): Record type %c not allowed in %s package. Skipped",pkg->name,lineno,line[0],pmodetext[pkg->mode]);
      return NULL;
    }	
  }
  if (maxpar<0) {
    error("%s(%d): Undefined record type '%c' encountered and ignored.",pkg->name,lineno,line[0]);
    return NULL;
  }
   
  l=strdupa(line);
  p=l+1;
  if (*p==' ') p++;
   
  pp=par;
  while (pp<par+maxpar && *p && *p!=10) {
     /* A field may begin with a ". then its delimited by " */
     if (*p=='"') {
       *pp++=++p;
       while (*p && *p!=10 && *p!='"') p++;
       *p++=0;
       if (*p++ !=' ') {
         error("%s(%d): Blank must follow closing \"",pkg->name,lineno);
	 return NULL;
       }
       p++;
     } else {
       *pp++=p;
       while (*p && *p!=10 && *p!=' ') p++;
       if (*p) *p++=0;
     }
  }
   
  /* Allow for an additional free form parameter at the end */
  if (*p && *p!=10) {
    *pp++=p;
    while (*p && *p!=10) p++;
    *p=0;
  }
   
  *pp=NULL;
  if (pp>=par+maxpar) {
    switch (*l) {
       /* Characters still available: JK */
       case '#' : return node_comment(pkg,lineno,par[0]);
       case 'A' : return node_a(pkg,lineno,par[0],par[1]);
       case 'B' : return node_b(pkg,lineno,par[0],par[1]);
       case 'C' : return node_c(pkg,lineno,par[0],par[1]);
       case 'D' : return node_d(pkg,lineno,par[0],mint(par[2]),mint(par[3]),moct(par[1]),0);
       case 'E' : 
             for(const char **p=eventtab+1;*p;p++)
	       if (strcmp(*p,par[0])==0 || strcmp(short_eventtab[p-eventtab],par[0])==0)
	         return node_e(pkg,lineno,p-eventtab,par[1]);
             error("%s(%d): Type of event '%s' not recognized",pkg->name,lineno,par[0]);
	     return NULL;
       case 'F' : return node_f(pkg,lineno,par[0],mint(par[2]),mint(par[3]),moct(par[1]),par[4],mlong(par[5]),0);
       case 'G' : return node_g(pkg,lineno,par[0]);
       case 'H' : return node_h(pkg,lineno,par[0]);
       case 'I' : return node_i(pkg,lineno,par[0],par[1]);
       case 'L' : return node_l(pkg,lineno,par[0],par[1],0);
       case 'M' : return node_m(pkg,lineno,par[0]);
       case 'N' : return node_n(pkg,lineno,par[0],mint(par[2]),mint(par[3]),moct(par[1]),mlong(par[4]),0);
       case 'O' : 
           for(const char **p=opttab;*p;p++) if (strcmp(*p,par[0])==0) return node_o(pkg,lineno,par[0],p-opttab);
	   error("%s(%d): Option '%s' not recognized",pkg->name,lineno,par[0]);
           return NULL;
       case 'P' : return node_p(pkg,lineno,par[0],par[1]);
       case 'Q' : return node_q(pkg,lineno,par[0],par[1],par[2]);
       case 'R' :
             for(const char **p=reltab+1;*p;p++) if (strcmp(*p,par[0])==0) return node_r(pkg,lineno,p-reltab,par[1],par[2]);
	     error("%s(%d): Type of relationship '%s' not recognized",pkg->name,lineno,par[0]);
	     return NULL;
       case 'S' : return node_s(pkg,lineno,par[0],par[1]);
       case 'T' : return node_t(pkg,lineno,par[0],par[1]);
       case 'U' : return node_u(pkg,lineno,par[0],mint(par[1]),mint(par[2]),par[3]);
       case 'V' :
             for(const char **p=envtab;*p;p++) if (strcmp(*p,par[0])==0) return node_v(pkg,lineno,p-envtab,par[1],par[2]);
             error("%s(%d): Type of environment '%s' not recognized",pkg->name,lineno,par[0]);
	     return NULL;
       case 'W' : return node_w(pkg,lineno,par[0]);
       case 'X' :
             for(const char **p=xactiontab;*p;p++) if (strcmp(*p,par[1])==0) return node_x(pkg,lineno,par[0],p-xactiontab);
	     error("%s(%d): Type of Blacklist action '%s' not recognized",pkg->name,lineno,par[0]);
	     return NULL;
       case 'Y' : return node_y(pkg,lineno,par[0],par[1],mint(par[2]));
       case 'Z' : return node_z(pkg,lineno,par[0],par[1]);
       default : error("%s(%d): Unrecognized record type '%c'",pkg->name,lineno,*l);return NULL;
     }
  } else {
    error("%s(%d): Not enough parameters for record type '%c'. Skipped and ignored.",pkg->name,lineno,*l);
    return NULL;
  }
  return NULL;
}

/* Quote a string if it has blanks in it */
char *quotestr(char *s) {
  if (strchr(s,' ')) {
    buffer[0]='"';
    strcpy(buffer+1,s);
    strcat(buffer,"\"");
    return buffer;
  }
  return s;
}

struct package *package_read(const char *file,enum pmode mode) {
  int lineno;
  struct package *pkg;
  FILE *f;

  f=fopen(file,"r");
  if (f==NULL) return NULL;
 
  pkg=calloc(1,sizeof(struct package)+strlen(file)+1);
  pkg->mode=P_UNLISTED;
  strcpy(pkg->location,file);
 
  if (mode==P_RECIPE || mode==P_UNLISTED) {
    char *x;
    node_b(pkg,G_PACKAGE_READ,"PACKAGE",x=extract_packagename(pkg->location));
    free(x);
    node_b(pkg,G_PACKAGE_READ,"VERSION",x=extract_version(pkg->location));
    free(x);
  } else if (pkg->name==NULL) pkg->name=pkg->location;
  
  errors=0;
  warnings=0;
 
  for(lineno=1;fgets(buffer,MAXLLENGTH,f);lineno++) {
    if (strlen(buffer)==MAXLLENGTH) {
      error("%s(%d): Maximum line length exceeded",pkg->location,lineno);
      fclose(f);return NULL;
    }
    if (buffer[0]==0 || buffer[0]==' ' || buffer[0]==0xa) continue;
    if ((buffer[0]!='#' && buffer[1]!=' ') || (buffer[0]!='#' && (buffer[0]<'A' || buffer[0]>'Z'))) {
      error("%s(%d): Format violation",pkg->location,lineno);
      fclose(f);return NULL;
    }
    addline(pkg,lineno,buffer); 
  }
  fclose(f);
  if (pkg->name==pkg->location) pkg->name=extract_packagename(pkg->location);
  if (pkg->version==NULL) pkg->version=extract_version(pkg->location);
  if (!pkg_has(pkg,"SC")) {
    pkg->meta=TRUE;
    if (pkg_has(pkg,"TCSPVYZEXNDL")) {
      error("%s: metapackage with incompatible records",pkg->location);
      pkg_remove(pkg);
      return NULL;
    }
  }
  if (mode!=P_UNLISTED) pkg_list(pkg,mode,pkg->location); 
  if (mode==P_INSTALLED && pkg->base) base=pkg;
  pkg->changed=FALSE;
  pkg->lines=lineno;
  debug("Read package %s %d lines",file,lineno);
  return pkg;
};

void package_write(struct package *pkg) {
   FILE *f;
   struct node **lines;

   check_path(pkg->location);
   f=fopen(pkg->location,"w");
   if (f==NULL) sys_abort(pkg->location);
   /* Number all the new lines in the file */
   for(char i='A';i<='Z';i++) ACT(pkg,i) {
     if (x->lineno<0) x->lineno=pkg->lines++;
   }
   /* Now build array so that we can print them later in order */
   lines=calloc(pkg->lines+1,sizeof(struct node **));
   for(char i='A';i<='Z';i++) ACT(pkg,i) { lines[x->lineno]=x; }
   for(int i=0;i<=pkg->lines;i++) if (lines[i]) {
     struct node *x=lines[i];
     switch(x->type) {
       case 'K' : fprintf(f,"# %s\n",x->v1);break;
       case 'O' : fprintf(f,"O %s\n",x->v1);break;
       case 'W' : fprintf(f,"W %s\n",x->v1);break;
       case 'G' : fprintf(f,"G %s\n",x->v1);break;
       case 'T' : fprintf(f,"T %s %s\n",quotestr(x->v1),x->v2);break;
       case 'H' : fprintf(f,"H %s\n",x->v1);break;
       case 'M' : fprintf(f,"M %s\n",x->v1);break;
       case 'C' : fprintf(f,x->v2 ? "C %s %s\n": "C %s\n",x->v1,x->v2);break;
       case 'S' : fprintf(f,x->v2 ? "S %s %s\n": "S %s\n",x->v1,x->v2);break;
       case 'P' : fprintf(f,x->v2 ? "P %s %s\n": "P %s\n",x->v1,x->v2);break;
       case 'R' : fprintf(f,x->v2 ? "R %s %s %s\n" : "R %s %s\n",reltab[x->relation],x->v1,x->v2);break;
       case 'V' : fprintf(f,x->v2 ? "V %s %s %s\n" : "V %s %s\n",envtab[x->relation],x->v1,x->v2);break;
       case 'A' : fprintf(f,x->v2 ? "A %s %s\n": "A %s\n" ,x->v1,x->v2);break;
       case 'U' : fprintf(f,x->v2 ? "U %s %u %u %s\n": "U %s %u %u\n",x->v1,x->uid,x->gid,x->v2);break;
       case 'Q' : fprintf(f,x->v2 ? "Q %s %s %s\n": "Q %s %s\n",x->rcd, x->v1,x->v2);break;
       case 'B' : fprintf(f,x->v2 ? "B %s %s\n": "B %s\n" ,x->v1,x->v2);break;
       case 'J' : fprintf(f,"J %s %u %u %o\n",x->v1,x->uid,x->gid,x->mode);break;
       case 'I' : fprintf(f,"I %s %s\n",x->v1,x->v2);break;
       case 'Y' : fprintf(f,"Y %s %s %d\n",x->v1,x->v2,x->lpriority);break;
       case 'Z' : fprintf(f,"Z %s %s\n",x->v1,x->v2);break;
       case 'E' : fprintf(f,"E %s %s\n",eventtab[x->event],x->v1);break;
       case 'X' : fprintf(f,"X %s %s\n",x->v1,xactiontab[x->xaction]);break;
       case 'N' : fprintf(f,"N %s %o %u %u %llo\n",quotestr(x->v1),x->mode,x->uid,x->gid,x->dev);break;
       case 'D' : fprintf(f,"D %s %o %u %u\n",quotestr(x->v1),x->mode,x->uid,x->gid);break;
       case 'L' : fprintf(f,"L %s %s\n",quotestr(x->v1),x->v2);break;
       case 'F' : fprintf(f,"F %s %o %u %u %s %lu\n",quotestr(x->v1),x->mode,x->uid,x->gid,x->v2,x->size);break;
     }
   }
   free(lines);
   fclose(f);
}

int read_package_dir(const char *name,enum pmode mode) {
  DIR *dh;
  struct dirent *dire;
  int count=0;
  
  dh=opendir(name);
  if (dh==NULL) sys_abort(name);
  while ((dire=readdir(dh))!=NULL) {
    char *filename;
    if (dire->d_name[0]=='.') continue;
    filename=strdup(catstr(name,"/",dire->d_name,NULL));

    if (is_dir(filename)) count+=read_package_dir(filename,mode); else {
      if (mode==P_INSTALLED || strchr(dire->d_name,'-')) {
        if (package_read(filename,mode)==NULL) sys_abort(buffer);
        if (errors) {
	  error("%s: %d errors while reading metadata. Please repair metadata",dire->d_name,errors);
	  errors=0;
	  warnings=0;
	}
	count++;
      }
    }
    free(filename);
  }
  closedir(dh);
  return count;
};

/* I have tried putting all the files into one to increase the speed but that
   actually DECREASES the speed of reading the information.
   Tried also to use zlib and reading from a compressed file which is even worse. */
int read_packages(enum pmode mode) {
  int count;
  debug("Reading list of %s ",mtexts[mode]);
  count=read_package_dir(mdirs[mode],mode);
  read_in[mode]=TRUE;
  return count;
}

/* Write all changed metadata back .... */
void update_metadata(enum pmode m) {
  
  ALL_PACKAGES(m) {
    if (p->changed) package_write(p);
    p->changed=FALSE;
  }
}

/*****************************************************
   Deal with environmental strings
******************************************************/

struct list {
  struct list *next;
  char *var;
  char *val;
  int priority;
};

void add_list(struct list **l,struct node *x) {
  struct list *new=calloc(1,sizeof(struct list));

  new->var=x->v1;
  new->val=x->v2 ? string_expand(x->pkg,x->v2,x->lineno): NULL;
  new->priority=x->pkg->level;
  new->next=*l;
  *l=new;
}

void free_list(struct list *l) {
  if (l==NULL) return;
  if (l->next) free_list(l->next);
  if (l->val) free(l->val);
  free(l);
}

struct list * find_list(struct list *l,char *x) {
  struct list *y;

  for(y=l;y;y=y->next) if (strcmp(x,y->var)==0) return y;
  return NULL;  
}

struct list *paths=NULL;
struct list *envs=NULL;
struct list *sets=NULL;

void environment_setup(void) {
 struct list *p;
 ACTINDEX(X_ENVIRONMENT,P_INSTALLED) switch (y->env) {
    case E_PATH: /* Stuff this at the end of the path mentioned */
      p=find_list(paths,y->v1);
      if (p) {
        char *x;
        strcpy(buffer,p->val);
	strcat(buffer,":");
	strcat(buffer,y->v2);
	free(p->val);
        x=strdup(buffer);
	p->val=string_expand(y->pkg,x,y->lineno);
	free(x);
      } else add_list(&paths,y);
      break;
    case E_ENV:  /* Replace or set environment variable */
      p=find_list(envs,y->v1);
      if (p) {
	if (p->val) free(p->val);
	p->val=y->v2 ? string_expand(y->pkg,y->v2,y->lineno): NULL;
	p->priority=y->pkg->level;
      } else add_list(&envs,y);
      break;
    case E_SET:   /* Set environment and complain if conflict */
      p=find_list(sets,y->v1);
      if (p) fatal("Environment conflict for %s",y->v1);
      add_list(&sets,y);
      break;
    default: swerr("Internal: Unrecognized V format");
  }
}

void environment_free(void) {
  /* Free up variables */
  free_list(paths);paths=NULL;
  free_list(envs);envs=NULL;
  free_list(sets);sets=NULL;
}

void environment_update(void) {
  /*   pathlist[LDPATH] is put into /usr/upm/ld.so.conf /etc ld.so.conf points to /usr/upm
     rest of paths is put into /usr/upm/profile.env in bash format /usr/upm/csh.env and
     (csh format) and in /usr/upm/environment in raw format
  */

  struct list *p;
  FILE *f;
  
  progress("Updating Environment Variables");

  environment_setup();
  /* Writeout contents */
  /* First generate /usr/upm/ld.so.conf and remove it from path chain */
  p=find_list(paths,"LDPATH");
  if (p) {
    char *x;
    char *y;
    
    f=fopen("/usr/upm/env/ld.so.conf","w");
    if (f==NULL) sys_abort("/usr/upm/env/ld.so.conf");
    fprintf(f,"# Generated by UPM. Will be overwritten by any change.\n");
    x=p->val;
    for(y=x;*y;y++) if (*y==':') {
      *y=0;
      fprintf(f,"%s\n",x);
      x=y+1;
    }
    fprintf(f,"%s\n",x);
    fclose(f);
  }
  
  f=fopen("/usr/upm/env/environment","w");
  if (f==NULL) sys_abort("/usr/upm/env/environment");
  for(p=paths;p;p=p->next) fprintf(f,"%s \"%s\"\n",p->var,p->val);
  for(p=envs;p;p=p->next) fprintf(f,"%s \"%s\"\n",p->var,p->val);
  for(p=sets;p;p=p->next) fprintf(f,"%s \"%s\"\n",p->var,p->val);
  fclose(f);
  
  f=fopen("/usr/upm/env/profile.env","w");
  if (f==NULL) sys_abort("/usr/upm/env/profile.env");
  for(p=paths;p;p=p->next) fprintf(f,"export %s=\"%s\"\n",p->var,p->val);
  for(p=envs;p;p=p->next) fprintf(f,"export %s=\"%s\"\n",p->var,p->val);
  for(p=sets;p;p=p->next) fprintf(f,"export %s=\"%s\"\n",p->var,p->val);
  fclose(f);
  
  f=fopen("/usr/upm/env/csh.env","w");
  if (f==NULL) sys_abort("/usr/upm/env/csh.env");
  for(p=paths;p;p=p->next) fprintf(f,"setenv %s \"%s\"\n",p->var,p->val);
  for(p=envs;p;p=p->next) fprintf(f,"setenv %s \"%s\"\n",p->var,p->val);
  for(p=sets;p;p=p->next) fprintf(f,"setenv %s \"%s\"\n",p->var,p->val);
  fclose(f);
  
  environment_free();
}

void environment_for_build(void) {
  struct list *p;
  char *v;
  
  environment_setup();
  p=find_list(paths,"ROOTPATH");
  if (p==NULL) {
    warn("No paths set in environment table! Using default path");
    v="/usr/bin:/usr/sbin:/bin:/sbin:/usr/local/bin:/usr/local/sbin";
  } else v=p->val;
  setenv("PATH",catstr("/usr/upm/scripts:",v,NULL),1);
  setenv("UPM_VERSION",VERSION,1);
  environment_free();
}

void trigger_run(struct package *pkg,const char *mode) {
  ACTINDEX(X_TRIGGER,P_INSTALLED) {
    int run=FALSE;
    buffer[0]=0;
    ACT(pkg,'F') if (file_indir(x->v1,y->v1)) {
      run=TRUE;
      strcat(buffer," ");
      if (strlen(buffer)>=MAXLLENGTH-200) {
        warn("%s: Trigger buffer overflow. Buffer Zapped",pkg->name);
	buffer[0]=0;
      }
      strcat(buffer,x->v1+strlen(y->v1)+1);
    };
    ACT(pkg,'L') if (file_indir(x->v1,y->v1)) {
      run=TRUE;
      strcat(buffer," ");
      if (strlen(buffer)>=MAXLLENGTH-200) {
        warn("%s: Trigger buffer overflow. Buffer Zapped",pkg->name);
	buffer[0]=0;
      }
      strcat(buffer,x->v1+strlen(y->v1)+1);
    };
    if (run) {
      char *x=strdup(buffer);
      if (shell(no_logs ? "%s %s%s" : "%s %s%s >>%s",y->v2,mode,x,TRIGGERLOG))
        error("%s(%d): Trigger '%s' failed on %s",pkg->name,y->lineno,y->v2,x);
      free(x);
    }
  }
}    

/*****************************************************
              Removal of packages 
*****************************************************/
 
void purge_unlink(struct node *x) {
  
  info("%s(%d): Remove %s",x->pkg->name,x->lineno,x->v1);
  if (unlink(x->v1)) warn("%s(%d): %s %s",x->pkg->name,x->lineno,x->v1,strerror(errno));
}

/* Remove directory in reverse fashion of creation by using a recursive call.
   Ignore all errors since this is also used by the build function to
   remove a base husk. */
void dirs_remove(struct node *x) {
  if (x==NULL) return;
  if (x->next) dirs_remove(x->next);
  rmdir(x->v1);
}

void purge_package(struct package *pkg) {
  
  ACT(pkg,'E') if (x->event==E_PRERM) node_run(x,TRUE,SCRIPTLOG);
  
  package_action(pkg,"FNL",purge_unlink);
  dirs_remove(pkg->r['D'-'A']);
  ACT(pkg,'Y') { 
    int l;
    if ((l=readlink(x->v1,buffer,MAXLLENGTH))>0) {
      buffer[l]=0;
      if (strcmp(buffer,x->v1)==0) {
        int cprio;

        /* Ok. This link is ours. Remove it */
        unlink(x->v1);
	cprio=100;
	/* And elect another if exists to take our place */
	ACTINDEX(X_PRIORITYLINK,P_INSTALLED) if (strcmp(y->v1,x->v1)==0 && y->lpriority<cprio) {
	  cprio=y->lpriority;
	  unlink(x->v1);
	  if (symlink(catstr("/",x->v2,NULL),x->v1)) sys_abort(x->v1);
	}
      }
    } else
    error("%s(%d): Priority Link at %s was not present!",pkg->name,x->lineno,x->v1);
  }
  
  trigger_run(pkg,"remove");
  ACT(pkg,'E') if (x->event==E_POSTRM) node_run(x,TRUE,SCRIPTLOG);
 
//  ACT(pkg,'U') {
//  /* Remove user information */
//    shell("if grep -v \"^\%s:\" etc/passwd >etc/passwd.new; then mv etc/passwd.new etc/passwd;fi",x->v1);
//   shell("if grep -v \"^\%s:\" etc/group >etc/group.new; then mv etc/group.new etc/group;fi",x->v1);
//  }
  if (unlink(catstr(INSTALLED,"/",pkg->name,NULL))) sys_abort(buffer);							  
  pkg_remove(pkg);
}

/***************************************************************************
   Listing functions
***************************************************************************/

void calc_stats(struct package *p,struct stats *s) {
   char *fp;
   
   s->dirs=node_count(p->r['D'-'A']);
   s->links=node_count(p->r['L'-'A']);
   s->nodes=node_count(p->r['N'-'A']);
   s->files=node_count(p->r['F'-'A']);
   
   { struct node *n=p->r['F'-'A'];
     s->size=0;
     while (n) {
       s->size+=n->size;
       n=n->next;
     }
   }
   s->version=p->version;
   s->title=pkg_description(p);
   fp=s->flags;
   memset(s->flags,0,sizeof(s->flags));
   if (p->hold) *fp++='H';
   if (p->base) *fp++='B';
   if (p->overwrite) *fp++='*';
   if (p->nocache) *fp++='x';
   if (p->nobinary) *fp++='X';
}

char sfbuf[10];

char *sizeformat(off_t size) {
  if (size<1000L) sprintf(sfbuf,"%4luB ",size); else
  if (size<10L*1024L) sprintf(sfbuf,"%3.1fKB ",size/1024.0); else
  if (size<1000L*1024L) sprintf(sfbuf,"%3luKB ",(size+512)/1024); else
  if (size<10L*1024L*1024L) sprintf(sfbuf,"%3.1fMB ",size/(1024.0*1024.0)); else
  if (size<1000L*1024L*1024L) sprintf(sfbuf,"%3luMB ",size/(1024*1024L)); else 
  if (size/10*1024<1024L*1024L) sprintf(sfbuf,"%3.1fGB ",size/(1024.0*1024.0*1024.0)); else
    sprintf(sfbuf,"%3luGB ",size/(1024L*1024L*1024L));
  return sfbuf;
}

char fdbuf[20];

char *fdlnformat(struct stats *s) {
  sprintf(fdbuf,"%uf",s->files);
  if (s->dirs) sprintf(fdbuf+strlen(fdbuf),"/%ud",s->dirs);
  if (s->links) sprintf(fdbuf+strlen(fdbuf),"/%ul",s->links);
  if (s->nodes) sprintf(fdbuf+strlen(fdbuf),"/%un",s->nodes);
  if (s->flags[0]) sprintf(fdbuf+strlen(fdbuf)," %s",s->flags);
  return fdbuf;
}

void liststatline(const char *package,struct stats *p) {
  printf("%-25s %5s%s (%s)\n",catstr(package,"-",p->version,NULL),sizeformat(p->size),p->title,fdlnformat(p));
}

/***************************************************
         Information about a package 
***************************************************/

void info_package(struct package *pkg) {
  struct stats s;
  
  calc_stats(pkg,&s);
  printf("\nPackage: %s\n",pkg->name);
  if (pkg_description(pkg)) printf("Description: %s\n",pkg_description(pkg));
  printf("Size of all files: %s\n",sizeformat(s.size));
  printf("Lines of metadata: %d\n",pkg->lines);
  if (s.dirs) printf("Directories: %d\n",s.dirs);
  /* One file is used for the storage of the metadata as package was deployed */
  if (s.files>1) printf("Files: %d\n",s.files-1);
  if (s.links) printf("Links: %d\n",s.links);
  if (s.nodes) printf("Nodes: %d\n",s.nodes);
  if (pkg->hold) printf("HOLD: package will not be automatically upgraded.\n");
  if (pkg->base) printf("Base package: Package used for generating the binary husk used for package building.\n");
  if (pkg->meta) printf("Meta package: No files, directories or symlinks and no build action).\n");
  if (pkg->overwrite) printf("Overwrite mode: Package will tolerate file replacements and not provide files already installed.\n");
  if (pkg->realroot) printf("Real Root: Pacakge cannot be build by a user or in a fakeroot environment.\n");
  if (pkg->insane) printf("INSANE: Violates rules of file placement.\n");
  if (pkg->nobinary) printf("No Binary: Generation of binaries not permitted.\n");
  if (pkg->nocache) printf("No Caching: Caching of sources not permitted.\n");
  printf("Metadata-Location: /%s\n",pkg->location);
  ALL_PACKAGES(P_INSTALLED) {
    if (p!=pkg) {
      ACT(p,'R') {
        if (strcmp(x->v1,pkg->name)==0) {
          printf(x->v2 ? "Needed by package %s %s condition=%s\n":"Needed by package %s %s\n",p->name,reltab[x->relation],x->v2);
        }
      }
    }
  }
}

/*****************************************************************
    Check package
*****************************************************************/

int permcheck(const struct node *x,struct stat *fbuf) {

  if (stat(x->v1,fbuf)) { error("%s(%d): %s does not exist anymore.",x->pkg->name,x->lineno,x->v1);return FALSE; }
  
  if ((fbuf->st_mode & 07777) != (x->mode & 07777)) {
    error("%s(%d): %s permission changed. Should be %o but is %o now.",x->pkg->name,x->lineno,x->v1,x->mode,fbuf->st_mode & 07777);
    return FALSE;
  }
  if (fbuf->st_gid != x->gid) {
    error("%s(%d): %s gid changed. Should be %d but is %d now.",x->pkg->name,x->lineno,x->v1,x->gid,fbuf->st_gid);
    return FALSE;
  }
  if (fbuf->st_uid != x->uid) { 
    error("%s(%d): %s uid changed. Should be %d but is %d now.",x->pkg->name,x->lineno,x->v1,x->uid,fbuf->st_uid);
    return FALSE;
  }
  return TRUE;
}

int check_dir(struct node *x) {
  struct stat fbuf;
  if (!permcheck(x,&fbuf)) return FALSE;
  if (!S_ISDIR(fbuf.st_mode)) {
    error("%s(%d): %s is not a directory",x->pkg->name,x->lineno,x->v1);
    return FALSE;
  }
  return TRUE;
}

int check_link(struct node *x) {
  int y;
  if ((y=readlink(x->v1,buffer,MAXLLENGTH))>0) {
    buffer[y]=0;
    if (strcmp(buffer,x->v2)) {
      error("%s(%d): Symlink %s should be pointing to %s but is pointing to %s",x->pkg->name,x->lineno,x->v1,x->v2,buffer);
    }
  } else {
    error("%s(%d): %s is not a symlink.",x->pkg->name,x->lineno,x->v1);
    return FALSE;
  }
  return TRUE;
}

int check_node(struct node *x) {
  struct stat fbuf;
  if (!permcheck(x,&fbuf)) return FALSE;
  if (S_ISDIR(fbuf.st_mode) || S_ISREG(fbuf.st_mode)) {
    error("%s(%d): %s is a directory or file and not a node",x->pkg->name,x->lineno,x->v1);
    return FALSE;
  }
  if (fbuf.st_mode != x->mode) {
    error("%s(%d): %s mode changed. Should be %o but is %o now.",x->pkg->name,x->lineno,x->v1,x->mode,fbuf.st_mode & 07777);
    return FALSE;
  }
  return TRUE;
}

int check_file(struct node *x) {
  struct stat fbuf;
  if (!permcheck(x,&fbuf)) return FALSE;
  if (!S_ISREG(fbuf.st_mode)) {
    error("%s(%d): %s is not a file",x->pkg->name,x->lineno,x->v1);
    return FALSE;
  }
  if (fbuf.st_size != x->size) {
    error("%s(%d): %s file size changed. Should be %d but is %d now.",x->pkg->name,x->lineno,x->v1,x->size,fbuf.st_size);
    return FALSE;
  }
  if (strcmp(x->v2,md5sum(x->v1))) {
    error("%s(%d): %s md5sum mismatch",x->pkg->name,x->lineno,x->v1);
  }
  return TRUE;
}

void check_package(struct package *pkg) {
  
  ACT(pkg,'D') check_dir(x);
  ACT(pkg,'L') check_link(x);
  ACT(pkg,'N') check_node(x);
  ACT(pkg,'F') check_file(x);

  /* There needs to be checking done for other metadata in the future */
  printf("\n%s: %d Errors %d Warnings\n",pkg->name,errors,warnings);  
}

/*************************************************
           Repair function
*************************************************/

int permfix(struct node *x,struct stat *fbuf) {

  if (stat(x->v1,fbuf)) { error("%s(%d): %s does not exist anymore.",x->pkg->name,x->lineno,x->v1);return FALSE; }
  
  if ((fbuf->st_mode & 07777) != (x->mode & 07777)) {
    error("%s permission changed. Should be %o but is %o now.",x->v1,x->mode,fbuf->st_mode & 07777);
    if (keepreal) {
      printf("Storing file permissions for %s\n",x->v1);
      x->mode=fbuf->st_mode & 07777;
      x->pkg->changed=TRUE;
    } else {
      printf("Resetting file permissions for %s\n",x->v1);
      if (chmod(x->v1,x->mode)) sys_abort(x->v1);
    }
  }
  if (fbuf->st_gid != x->gid || fbuf->st_uid != x->uid) {
    error("%s uid/gid changed. Should be %d.%d but is %d.%d now.",x->v1,x->uid,x->gid,fbuf->st_uid,fbuf->st_gid);
    if (keepreal) {
      printf("Storing gid/uid information for %s\n",x->v1);
      x->gid=fbuf->st_gid;
      x->uid=fbuf->st_uid;
      x->pkg->changed=TRUE;
    } else {
      printf("Resetting uid/gid for %s\n",x->v1);
      if (chown(x->v1,x->uid,x->gid)) sys_abort(x->v1);
      /* Any chown might cause loss of perm bits... so set it again ...*/
      chmod(x->v1,x->mode);
    }
  }
  return TRUE;
}

int fix_dir(struct node *x) {
  struct stat fbuf;
  if (!permfix(x,&fbuf)) {
    if (keepreal) {
      printf("Removing directory %s from package %s\n",x->v1,x->pkg->name);
      x->type=0;
      x->pkg->changed=TRUE;
    } else {
      printf("%s: Creating directory %s\n",x->pkg->name,x->v1);
      if (mkdir(x->v1,x->mode)) sys_abort(x->v1);
      if (chown(x->v1,x->uid,x->gid)) sys_abort(x->v1);
      /* We might have lost perms.... */
      chmod(x->v1,x->mode);
    }
  }
  if (!S_ISDIR(fbuf.st_mode)) {
    error("%s is not a directory",x->v1);
    printf("%s: Remove %s",x->pkg->name,x->v1);
  }
  return TRUE;
}

int fix_link(struct node *x) {
  int y;
  if ((y=readlink(x->v1,buffer,MAXLLENGTH))>0) {
    buffer[y]=0;
    if (strcmp(buffer,x->v2)) {
       warn("%s(%d): Symlink %s should be pointing to %s but is pointing to %s",x->pkg->name,x->lineno,x->v1,x->v2,buffer);
       if (keepreal) {
          printf("Getting symlink target information from %s\n",x->v1);
	  if (strlen(buffer)<=strlen(x->v2))
	    strcpy(x->v2,buffer); 
	  else 
	    x->v2=strdup(buffer); /* Leak it.... what can I do... */
	  x->pkg->changed=TRUE;
       } else {
         printf("Setting symlink target for %s",x->v1);
	 if (symlink(x->v1,x->v2)) sys_abort(x->v1);
       }
    }
  } else {
    warn("%s(%d): %s is not a symlink.",x->pkg->name,x->lineno,x->v1);
    if (keepreal) {
      x->type=0;	/* Delete information about this node deleted */
      x->pkg->changed=TRUE;
      printf("Remove %s from package %s\n",x->v1,x->pkg->name);
    } else {
      if (unlink(x->v1)) sys_abort(x->v1);
      if (symlink(x->v2,x->v1)) sys_abort(x->v1);
    }
  }
  return TRUE;
}

int fix_node(struct node *x) {
  struct stat fbuf;
  if (!permfix(x,&fbuf)) return FALSE;
  if (S_ISDIR(fbuf.st_mode) || S_ISREG(fbuf.st_mode)) {
    error("%s is a directory or file and not a node",x->v1);
    printf("Remove %s from package %s\n",x->v1,x->pkg->name);
  }
  if (fbuf.st_mode != x->mode) {
    error("%s mode changed. Should be %o but is %o now.",x->v1,x->mode,fbuf.st_mode & 07777);
    printf("Setting mode for %s.\n",x->v1);
    if (chmod(x->v1,x->mode)) sys_abort(x->v1);
  }
  return TRUE;
}

int fix_file(struct node *x) {
  struct stat fbuf;
  char *s;
  
  if (!permfix(x,&fbuf)) return FALSE;
  if (!S_ISREG(fbuf.st_mode)) {
    error("%s is not a file",x->v1);
    x->type=0;
    x->pkg->changed=TRUE;
    printf("%s removed from package %s",x->v1,x->pkg->name);
    return FALSE;
  }
  if (fbuf.st_size != x->size) {
    error("%s file size changed. Should be %d but is %d now.",x->v1,x->size,fbuf.st_size);
    if (keepreal) {
      x->size=fbuf.st_size;
      x->pkg->changed=TRUE;
      printf("File size of %s stored.\n",x->v1);
    } else {
      error("**** Cannot fix file size mismatch for %s ****",x->v1);
      return FALSE;
    }
  }
  if (strcmp(x->v2,s=md5sum(x->v1))) {
    error("%s md5sum mismatch. ",x->v1);
    if (keepreal) {
      strcpy(x->v2,s);
      x->pkg->changed=TRUE;
      printf("MD5Sum of %s stored.\n",x->v1);
    } else {
      error("**** Cannot fix md5sum mismatch for %s ****",x->v1);
    }
    free(s);
    return FALSE;
  }
  return TRUE;
};

void fix_package(struct package *pkg) {
  
  ACT(pkg,'D') fix_dir(x);
  ACT(pkg,'L') fix_link(x);
  ACT(pkg,'N') fix_node(x);
  ACT(pkg,'F') fix_file(x);

  if (pkg->changed) package_write(pkg);
  /* There needs to be fixing done for other metadata in the future */
  printf("\n%s: %d Errors %d Warnings\n",pkg->name,errors,warnings);  
}


/*********************************************************
   Specific routines for adding a new package
*********************************************************/

void install_node(struct node *f) {
  struct stat fbuf;
  char *file=f->v1;
  int etcfile=strncmp(f->v1,"etc/",4)==0 || strcmp(f->v1,"etc")==0;;

  if (config_translation && etcfile) {
    file=strdup(catstr(ETC,f->v1,NULL));
    check_path(file);
  }
  
  if (f->type=='F') {
     char *target=strdupa(catstr(FROOT "/",f->v1,NULL));
     
     /* try hardlinking first if that does not work copy.
        etcfiles need to be copied twice. A link would make the second copy fail. */
    if (etcfile || rename(target,file)) {
      FILE *out,*in;
      size_t bytesread;

      out=fopen(catstr(file,"-upm.tmp",NULL),"w");
      if (out==NULL) sys_abort(buffer);
      
      in=fopen(target,"r");
      if (in==NULL) sys_abort(target);
  
      while((bytesread=fread(buffer,1,MAXLLENGTH,in))>0) {
	if (fwrite(buffer,1,bytesread,out)!=bytesread) sys_abort(file);
      }
      if (!feof(in)) sys_abort(file);
      fclose(in);
      fclose(out);
      if (rename(catstr(file,"-upm.tmp",NULL),file)) sys_abort(file);
    }
  }
  /* Now check if we need to create a directory */
  if (f->type == 'D') {
    /* If nothing is there yet simply create the directory */
    if (stat(file,&fbuf)) mkdir(file,f->mode);
    else if (!S_ISDIR(fbuf.st_mode)) {
      /* There is something there that is not a directory. Remove that first. */
      info("%s: Replacing file %s with directory",f->pkg->name,f->v1);
      unlink(file);
      if (mkdir(file,f->mode)) sys_abort(file);
    }
  }
  
  if (f->type=='L') {
    unlink(file);	/* If somethings there get it out of the way */
    if (symlink(f->v2,file)) sys_abort(file);
    return;
  }
  
  if (chown(file,f->uid,f->gid)) sys_abort(file);
  if (f->type=='N') {
     if (mknod(file,f->mode,f->dev)) sys_abort(file);
  } else {
    if (chmod(file,f->mode)) sys_abort(file);
  } 
  
  if (file!=f->v1) free(file); 
}

/* Check for upgradability and generate diff to use for new config file */
int config_upgrade_check(struct node *f) {
  
  if (shell("diff -u usr/upm/%s %s >%s.diff",f->v1,f->v1,f->v1)==0) {
    /* No changes ... and therefore no need to keep a diff */
    unlink(catstr(f->v1,".diff",NULL));
    return TRUE;
  } else {
    if (configmode==C_DEFAULT) {
       if (shell("patch --dry-run " FROOT "/%s <%s.diff >/dev/null 2>&1",f->v1,f->v1)==0) {
       /* User modified configuration file but the patch works on the new config file */
         return TRUE;
       }
    } else {
      /* The other modes never fail */
      return TRUE;
    }
  }
  return FALSE;
}

/* Actually perform the configuration file upgrade. Use the diff potentially generated
   during config_upgrade_check */
void config_upgrade_do(struct node *f) {
  struct stat fbuf;
  
  if (configmode==C_DEFAULT) {
    /* Deploy new config file */
    install_node(f);
    if (stat(catstr(f->v1,".diff",NULL),&fbuf)==0) {
      /* Patch exists. Apply it */
      if (shell("patch /%s </%s.diff",f->v1,f->v1)) fatal("Patch for %s does not work anymore. Dazzled and confused.",f->v1);
      unlink(catstr(f->v1,".diff",NULL));
    }
  } else if (configmode==C_KEEP) return;
  else if (configmode==C_OVERWRITE) install_node(f);
  else if (configmode==C_RENAME) {
    if (rename(f->v1,catstr(f->v1,".upm-old",NULL))) sys_abort(f->v1);
    install_node(f);
  }
}

int generate_dfln_records(const char *path,struct package *pkg,struct package **old) {
  DIR *dir;
  struct dirent *dire;
  int result=TRUE;
  
  dir=opendir(catstr(FROOT "/",path,NULL));
  if (dir==NULL) sys_abort(buffer);
  while ((dire=readdir(dir))!=NULL) {
    struct stat fbuf;
    struct node *oldnode;
    struct node *black;
    int directory_of_other_package=FALSE;
    int directory=FALSE;
    int recurse=FALSE;
    char conffile=0;
    int x;
    char *file;
    char *fullfilename;
    struct package **oldpackage=old;
   
    if (dire->d_name[0]=='.') continue;
    
    if (strlen(path))
      fullfilename=strdup(catstr(path,"/",dire->d_name,NULL));
    else
      fullfilename=strdup(dire->d_name);
    
    if (strncmp(fullfilename,"etc",3)==0) {
      conffile='R';
      pkg->conffiles++;
    }

    oldnode=file_find(fullfilename);
    black=xref_bestmatch(fullfilename,X_BLACKLIST,P_INSTALLED);
    file=strdup(catstr(FROOT "/",fullfilename,NULL));
    /* Check if this is a file of the old package(s) that are being replaced.
       If so then we need to remove the entry first otherwise there will be
       a name clash of the file index */
    if (oldnode) while (*oldpackage && *oldpackage!=oldnode->pkg) oldpackage++;
    
    if (*oldpackage && oldnode) {
      /* Replacing existing entity */
      directory=oldnode->type=='D';
      if (conffile) {
        switch (oldnode->type) {
	 case 'F' :
	   if (stat(fullfilename,&fbuf)==0) {
	     if (strcmp(md5sum(file),oldnode->v2)==0) { conffile='K';pkg->conffiles--; }
	     else {
	       if (config_upgrade_check(oldnode)) conffile='U';
	       else {
	         error("%s: Upgrade of configuration file %s would fail",pkg->name,fullfilename);
	         result=FALSE;
	       }
	     }
	   };
	   break;
	 case 'D' : case 'L' : conffile='R';break;
	 default: error("%s: File type '%c' not supported in /etc",pkg->name,oldnode->type);result=FALSE;
	}
      }
      node_remove(oldnode);
      oldnode=NULL;
    } else {
      if (black && black->pkg!=pkg) {
        if (black->xaction==X_ABORT) {
	  error("%s: File %s is blacklisted by %s",pkg->name,fullfilename,black->pkg->name);
	  result=FALSE;
	  continue;
	}
	if (black->xaction==X_WARN) warn("%s: File %s is blacklisted by %s and will be skipped.",pkg->name,fullfilename,black->pkg->name);
	if (black->xaction!=X_MINE) {
	  if (oldnode) node_z(pkg,G_ANALYSIS,fullfilename,oldnode->pkg->name);
	  continue;
	}
      }
      /* If this is a config file then its new */
      if (conffile) conffile='N';
      
      /* There could be trouble if there is something where we are going to put this
         but the *** following check will NOT discover symlinks pointing nowhere.
	 What do we do in the situation where we have a oldnode record but
	 nothing is there ?? */
      if (oldnode) {
        directory=oldnode->type=='D';
	/* If this is a symlink to a directory then it is still a directory for our purposes here */
	if (oldnode->type=='L') {
	  if (oldnode->v2[0]=='/' && is_dir(oldnode->v2+1)) directory=TRUE; else
	  if (is_dir(catstr(path,"/",oldnode->v2,NULL))) directory=TRUE;
	}
        if (directory) {
          /* We are using a directory owned by another package */
	  directory_of_other_package=TRUE;
	} else {
	  /* Same symlink being installed ? */
	  if (oldnode->type=='L' && (x=readlink(file,buffer,MAXLLENGTH))>0) {
	    buffer[x]=0;
	    if (strcmp(buffer,oldnode->v2)==0) {
	      warn("%s: Link %s will be skipped. Same link already installed by %s.",pkg->name,fullfilename,oldnode->pkg->name);
	      node_z(pkg,G_ANALYSIS,fullfilename,oldnode->pkg->name);
	      continue;
	    }
	  }
	  if (no_protect || oldnode->pkg->overwrite || pkg->base) {
	    warn("%s: File %s will be removed from package %s",pkg->name,fullfilename,oldnode->pkg->name);
	    node_z(oldnode->pkg,G_ANALYSIS,fullfilename,pkg->name);
	    node_remove(oldnode);
	    oldnode=NULL;
	    if (no_protect) node_i(pkg,G_ANALYSIS,"NO_PROTECT",fullfilename);
	  } else
	  if (pkg->overwrite ||nice_pkg) {
	    warn("%s: File %s is already provided by package %s and will be skipped.",pkg->name,fullfilename,oldnode->pkg->name);
	    node_z(pkg,G_ANALYSIS,fullfilename,oldnode->pkg->name);
	    if (nice_pkg) node_i(pkg,G_ANALYSIS,"NICE",fullfilename);
	    continue;
	  } else{
            /* We do not allow overwriting of files owned by other packages */
            error("%s: Will overwrite '%s' by package %s",pkg->name,fullfilename,oldnode->pkg->name);
	    result=FALSE;
	    continue;
	  }
        }
      } else {
        if (stat(fullfilename,&fbuf)==0) {
	  if (S_ISDIR(fbuf.st_mode))
	    directory=TRUE;
	  else
	    warn("%s: Will overwrite '%s' (not belonging to any package)",pkg->name,fullfilename);
        }
      }
    }    
    /* Symlinks pointing to nowhere lead to stat signaling not found . Need to do symlinks first. */
    if ((x=readlink(file,buffer,MAXLLENGTH))>0) {
      buffer[x]=0;
      if (stat(file,&fbuf)==0 && directory && !S_ISDIR(fbuf.st_mode)) { 
        error("%s: Would overwrite directory '%s' with symlink",pkg->name,fullfilename);
	result=FALSE;
      } else
        node_l(pkg,G_SCAN,fullfilename,buffer,conffile);
    } else {  
      if (stat(file,&fbuf)) sys_abort(file);
      if (S_ISDIR(fbuf.st_mode)) {
        recurse=TRUE;
	if (directory_of_other_package && oldnode) {
	  if (pkg->base) {
	    if (oldnode) node_remove(oldnode);
	    oldnode=NULL;
	    node_d(pkg,G_SCAN,fullfilename,fbuf.st_uid,fbuf.st_gid,fbuf.st_mode & 07777,conffile);
	  } else if (black && black->pkg!=oldnode->pkg && black->xaction==X_MINE) {
	    if (oldnode) {
	      /* X_MINE directories must be owned by the blacklister not by another package. Fix this */
	      warn("%s: Directory %s will be owned by %s",pkg->name,fullfilename,oldnode->pkg->name);
	      node_remove(oldnode);
	      oldnode=NULL;
	    }
	    debug("Directory %s will be added to %s because of blacklist information",fullfilename,black->pkg->name);
	    node_d(black->pkg,G_SCAN,fullfilename,fbuf.st_uid,fbuf.st_gid,fbuf.st_mode & 07777,conffile);
          } else {
	    int done=FALSE;
	    ACT(pkg,'R') if (try_resolve_dependency(x,P_INSTALLED)==oldnode->pkg) done=TRUE;
	    if (strcmp(oldnode->pkg->name,"upm") && oldnode->pkg != base && !done) {
	      struct node *y;
	      info("%s: Generating dependency on %s since it uses directory %s provided by %s",pkg->name,oldnode->pkg->name,fullfilename,oldnode->pkg->name);
	      /* Generate dependency of this package on n */
	      y=node_r(pkg,G_ANALYSIS,R_DEPEND,oldnode->pkg->name,NULL);
	    }
	  }
	} else {
	  node_d(pkg,G_SCAN,fullfilename,fbuf.st_uid,fbuf.st_gid,fbuf.st_mode & 07777,conffile);
	}
      }
      else
      if (S_ISREG(fbuf.st_mode))
        if (directory) {
	  error("%s: Would overwrite directory '%s' with file",pkg->name,fullfilename);
	  result=FALSE;
	} else {
	  /* Might want to check if this is an executable and then calculate dependencies off that */
	  node_f(pkg,G_SCAN,fullfilename,fbuf.st_uid,fbuf.st_gid,fbuf.st_mode & 07777,md5sum(file),fbuf.st_size,conffile);
	}
      else
        if (directory) {
	  error("%s: Would overwrite directory '%s' with node",pkg->name,fullfilename);
	  result=FALSE;
	}
	else
	  node_n(pkg,G_SCAN,fullfilename,fbuf.st_uid,fbuf.st_gid,fbuf.st_mode,fbuf.st_dev,conffile);
    };
    free(file);
    if (recurse) result &=generate_dfln_records(fullfilename,pkg,old);
    free(fullfilename);
  }
  closedir(dir);
  return result;
}

void depends_on_file(struct package *p,char *file,char *binary) {
  struct node *n;
  char *x;
  int l;
  char *msg;

  /* Standard Shell dependencies are irrelevant*/
  if (strcmp(file,"/bin/sh")==0) return;
  
  /* Resolve possible symbolic link */
  strcpy(buffer,file);
  for(x=buffer+strlen(buffer);x>buffer && x[-1]!='/';x--) ;
  l=readlink(buffer,x,MAXLLENGTH-(x-buffer));
  if (l>0) x[l]=0;
  
  file=strdupa(buffer);
  if (*file=='/') file++;
  n=file_find(file);
  if (n) {
    /* do not generate dependencies generated by the fakeroot environment */
    if (strcmp(n->pkg->name,"fakeroot")==0) return;

    /* And depending on ourselves is also a bad idea */
    if (n->pkg==p || strcmp(n->pkg->name,p->name)==0) return;

    asprintf(&msg,"reference to library from %s",binary);
    package_needs(p,n->pkg->name,NULL,msg);
  } else error("%s: Executable %s uses /%s but file is not known to uPM",p->name,binary,file);
}

/* Check if the filename is a sharable object */
int is_library(char *x) {
  char *y=basename(x);
  if (strncmp(y,"lib",3)==0) {
    /* .so at the end is a good indicator for a sharable object */
    if (strcmp(y+strlen(y)-3,".so")==0) return TRUE;
     /* There could be a .so. in the middle too.... */
    if (strstr(y,".so.")) return TRUE;
  }
  return FALSE;
}

void generate_executable_dependencies(struct package *pkg,char *loc) {
  /* Do a run over executables in a tree to analyze library dependencies */
  DIR *dir;
  struct dirent *dire;

  dir=opendir(loc);
  if (dir==NULL) return;
  while ((dire=readdir(dir))) {
    char *filename;
    struct stat fbuf;

    if (strcmp(dire->d_name,".")==0 || strcmp(dire->d_name,"..")==0) continue;

    filename=strdup(catstr(loc,"/",dire->d_name,NULL));
    
    if (stat(filename,&fbuf)) warn("%s: Bad symlink(?) (unreadable) file %s",pkg->name,filename);
    else { 
      /* If its a directory and that dir is no symlink then recurse */
      if (is_dir(filename) && readlink(filename,buffer,MAXLLENGTH)<=0) generate_executable_dependencies(pkg,filename);
      else if (S_ISREG(fbuf.st_mode) && ((fbuf.st_mode & 0111) || is_library(filename))) {
        FILE *f=fopen(filename,"r");
        char *file;  
  
        fread(buffer,1,100,f);
        fclose(f);
        if (buffer[0]=='#' && buffer[1]=='!') {
          char *p=buffer+2;
          while (*p==' ') p++;
          file=p;
          while (*p && *p!='\n' && *p!=' ') p++;
          p[0]=0;
          depends_on_file(pkg,file,dire->d_name);
        } else {
          /* Must be a binary executable */
          char *lddoutput=strdup(read_shell("/usr/bin/ldd",filename));
          char *p;

	  for(p=lddoutput;*p;) {
            if (*p=='\t') {
	      p++;
	      // while (*p==' ') p++;
              file=p;
              while (*p && *p!='\n' && *p++!=' ');
  	      p[-1]=0;
	      if (file[0]=='/') depends_on_file(pkg,file,dire->d_name);
	      /* Ignore messages from ldd having to do with libfakeroot, statically builds and not dynamically linked objects */
	      if (strcmp(file,"not") && strncmp("libfakeroot",file,11) && strcmp(file,"statically")) {
	        /* If there is an arrow continue */
	        if (*p) {
	          while (*p && *p!='\n' && *p++!=' ') ;
	          file=p;
	          while (*p && *p!='\n' && *p++!=' ') ;
	          p[-1]=0;
	          if (file[0]=='/') depends_on_file(pkg,file,filename);
	          else {
		    p[-1]=' ';
		    warn("%s: Skipped analysis of file %s. Strange ldd output: %s",pkg->name,filename,file);
		    printf("%s\n",lddoutput);
		    break;
		  }
		}
	      }
	    }
	    /* Skip to next line */
	    while (*p && *p++!='\n') ;
          }
	  free(lddoutput);
        }
      }
    }
    free(filename);
  }
  closedir(dir);
}  


/* This function takes a directory with binaries and merges it into the / tree.
   Need to rewrite this into a general package_changes(additional trees, removed packages) thing... */
int merge_root(const char *tarball) {
  char *file;
  struct package *new_package;
  struct package *old_package[10]={NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL};
  struct package **old_pp=old_package;
  int envupdate=FALSE;
  struct mdep *missing;
  int rc;

  errors=0;
  warnings=0;
  debug("Start installation from %s",tarball);
  if (is_dir(FROOT)) {
    info("Removing junk from prior aborted installation");
    removedir(FROOT);
  }
  if (mkdir(FROOT,0755)) sys_abort(FROOT);
  info("Unpacking tarball in %s",tarball);
  unpack_tarball(FROOT,tarball);
 
  /* Locate the package description file in the /usr/upm/in directory */
  { DIR *dir;struct dirent *dire;
    dir=opendir(FROOT "/" UPM_IN);
    if (dir==NULL) sys_abort(FROOT "/" UPM_IN);
    do {
      dire=readdir(dir);
      if (dire==NULL) fatal("%s: No file in " UPM_IN,tarball);
    } while (dire->d_name[0]=='.');
    file=strdupa(dire->d_name);
    dire=readdir(dir);
    if (dire!=NULL) { error("%s: More than one file in " UPM_IN,tarball);return 1; }
    closedir(dir);
  }
  
  if ((new_package=package_read(catstr(FROOT "/" UPM_IN,file, NULL),P_UNLISTED))==NULL) sys_abort(buffer);
  if (new_package->version==NULL || new_package->name==NULL) {
    error("%s: no name or version information",new_package->name);
    goto instfail;
  }

  if (suidroot==NULL) read_suid();
  
  /* First dependency check not considering the changes to metadata because of this package.
     This is done in order to be able to build components before we have to make major
     changes to the internal state.
     Unresolved deps should really not happen too frequently here.
     The checking when building from source should build most packages */
  if (!no_depends && (missing=dep_check(new_package))) {
    /* Move FROOT into a temp location. Other binaries might overwrite this */
    char *temploc=strdupa(catstr("usr/upm/staging-",new_package->name,NULL));
    int result;
    
    /* install missing packages */
    mdep_print(missing);
    if (mdep_serious(missing)) {
      mdep_print(missing);
      error("%s : Unresolvable dependency issues",new_package->name);
      goto instfail;
    }
    removedir(temploc);
    rename(FROOT,temploc);
    result=mdep_install(missing);
    /* get froot back */
    rename(temploc,FROOT);
    if (!result) {
      error("%s: Cannot build all necessary packages",new_package->name);
      goto instfail;
    }
  }
  putsetting("attributes","UPM_VERSION",VERSION);
  *old_pp=package_find(new_package->name,P_INSTALLED);
  if (*old_pp) {
    info("%s: Upgrading from version %s",new_package->name,(*old_pp)->version);
    node_i(new_package,G_MERGE,"UPGRADE",(*old_pp)->version);
    if ((*old_pp)->r['V'-'A']) envupdate=TRUE;
    old_pp++;
  }
  
  /* Collect all the information about packages that this package will replace */
  ACT(new_package,'R') {
    struct package *r=try_resolve_dependency(x,P_INSTALLED);
    if (r==OK_DEP) continue;
    if (x->relation==R_REPLACE && r) {
      *old_pp++=r;
      info("%s: Replacing package %s-%s",new_package->name,r->name,r->version);
      node_i(new_package,G_MERGE,catstr("REPLACED_",r->name,NULL),r->version);
      ACT(new_package,'E') if (x->event==E_PRERM) if (node_run(x,TRUE,SCRIPTLOG)) {
        error("%s(%d):PRERM script failure. Installation aborted",new_package->name,x->lineno);
	goto instfail;
      }
      if (r->r['V'-'A']) envupdate=TRUE;
    }
  };
  
  /* Package was read a P_BUILD package but it will now become a P_INSTALLED package.
     Unlink it and put it back in as P_INSTALLED */
  new_package=pkg_list(new_package,P_INSTALLED,catstr(INSTALLED,"/",new_package->name,NULL));

 /* Walk the target tree and extract metainformation as needed.
     Build up metadata on situation after install and return errors for any file conflicts.
     Remove nodes from old_packages that will be replaced.
     Also checks if configuration files can be upgraded and provides a count of those.
  */
  progress("%s: Information gathering and checking files.",new_package->name);
  rc=generate_dfln_records("",new_package,old_package);
  
  /* Remove remaining old package references from metadata. This has to be
     done before eventually aborting. Otherwise a package with just the remaining
     files will be written back to disk on failure!
  */
  for(old_pp=old_package;*old_pp;old_pp++) pkg_delist(*old_pp);
  
  if (!rc) {
    error("%s: Cannot install. Errors during analysis.",new_package->name);
    goto instfail;
  }
 
  
  /* At this point the metadata is in its future state. Check if that would work */
  if (dep_check_all(P_INSTALLED)==0) {
    error("%s: Dependency check failed",new_package->name);
    if (!no_depends) { 
      error("%s: Cannot continue (use -D to override)",new_package->name);
      goto instfail;
    }
  }
  
  if (no_depends && errors) node_i(new_package,G_MERGE,"NO_DEPENDS","USED");

  info("%s: All checks passed beginning installation.",new_package->name);
  ACT(new_package,'E') if (x->event==E_PREMERGE) if (node_run(x,TRUE,SCRIPTLOG)) {
    error("%s: PREMERGE script failed. Installation aborted.",new_package->name);
    goto instfail;
  }
  
  if (new_package->r['D'-'A']) {
    progress("%s: Installing directories",new_package->name);
    ACT(new_package,'D') install_node(x);
  }
  if (new_package->r['N'-'A']) {
    progress("%s: Installing nodes",new_package->name);
    ACT(new_package,'N') install_node(x);
  }
  if (new_package->r['F'-'A']) {
    progress("%s: Installing files",new_package->name);
    ACT(new_package,'F') install_node(x);
  } 
  if (new_package->r['L'-'A']) {
    progress("%s: Installing symbolic links",new_package->name);
    ACT(new_package,'L') install_node(x);
  }
  
  /* The installation did not cover the /etc files. Deal with those in a special way */
  if (new_package->conffiles) {
    progress("%s: Processing Configuration Files",new_package->name);
    config_translation=FALSE;
    ACT(new_package,'D') if (x->config) install_node(x);
    ACT(new_package,'L') if (x->config) install_node(x);
  
    ACT(new_package,'F') if (x->config) {
      if (x->config=='U') {
        info("%s: Upgrading configuration file %s",new_package->name,x->v1);
	config_upgrade_do(x);
      } else 
      if (x->config=='N') { 
	info("%s: New configuration file %s",new_package->name,x->v1);
        install_node(x);
      } else {
        if (x->config=='R') {
	  info("%s: Replacing configuration file %s",new_package->name,x->v1);
	  install_node(x);
	}
      }
    }
    config_translation=TRUE;
  }
  
  /* Remove whatever is left of the old packages */
  for(struct package **pp=old_package;*pp;pp++) {
    ACT(new_package,'Q') if (strchr(x->rcd,'U')) init_script(new_package,x->v1,STOP);
   purge_package(*pp);
  }
  
  /* If there is a crash at this point make sure that everything survives. Otherwise
     metadata is out of sync with the actual situation if something
     goes wrong with the numerous scripts that are still to be run */
  update_metadata(P_INSTALLED);
   
  ACT(new_package,'E') if (x->event==E_POSTMERGE) node_run(x,TRUE,SCRIPTLOG);
 
  /* Priority Link processing */
  ACT(new_package,'Y') {
    struct node *candidate=x;
    struct node *old=file_find(x->v1);
    
    if (old) {
      struct package *op=old->pkg;
      error("%s(%d): Y steals %s from %s",new_package->name,x->lineno,x->v1,op->name);
      node_remove(old);
      node_z(op,x->lineno,x->v1,new_package->name);
    }
    
    ACTINDEX(X_PRIORITYLINK,P_INSTALLED) if (strcmp(y->v1,x->v1)==0 && y->lpriority<x->lpriority) {
      candidate=NULL;
      break;
    }
    
    if (candidate) {
      char *x=string_expand(new_package,candidate->v2,candidate->lineno);
      if (x==NULL) { error("%s: Y with NULL parameter",new_package->name,candidate->lineno);goto instfail; }
      unlink(candidate->v1);
      symlink(x,candidate->v1);
    }
  }
  
  if (new_package->r['V'-'A'] || envupdate) environment_update();
  trigger_run(new_package,"add");
  update_metadata(P_INSTALLED);
  sync();
  /* Register new users */
  ACT(new_package,'U') {
    { struct passwd *z;
      struct passwd p;
      z=getpwnam(x->v1);
      if (z) warn("%s(%d): User %s already exists in /etc/passwd. New user entry skipped.",new_package->name,x->lineno,x->v1);
      else {
        FILE *f=fopen("/etc/passwd","a");
        p.pw_name=x->v1;
        p.pw_passwd="!";
        p.pw_uid=x->uid;
        p.pw_gid=x->gid;
        p.pw_gecos=x->v2;
        p.pw_dir=NULL;
        p.pw_shell="/bin/false";
        putpwent(&p,f);
        fclose(f);
      }
    }
    if (getgrgid(x->gid)==NULL)
    { struct group *z;
      struct group p;
      z=getgrnam(x->v1);
      if (z) error("%s(%d): Group %s already exists with a different gid",new_package->name,x->lineno);
      else {
        FILE *f=fopen("/etc/group","a");
	p.gr_name=x->v1;
	p.gr_gid=x->gid;
	p.gr_mem=NULL;
	putgrent(&p,f);
	fclose(f);
      }
    }
  }
  ACT(new_package,'Q') if (strchr(x->rcd,*old_package ? 'U':'B')) init_script(new_package,x->v1,START);
  progress("%s: Installation of %s-%s complete",new_package->name,new_package->name,new_package->version);
  removedir(FROOT);
  if (strcmp(new_package->name,"upm")==0) { info("Stopping since upm was upgraded. Please restart the command."); exit(0); }
  return 0;
 instfail:
  error("%s: Install failed",new_package->name);
  pkg_remove(new_package);
  removedir(FROOT);
  return 1;
}

/******************************************************************
                       Expression Parser
******************************************************************/

const char *exp;	/* Pointer into the currently evaluated expression */

char skipblank() {
 while (*exp==' ') exp++;
 return *exp;
}

char *getid() {
  char *d=buffer;
  while (isalpha(*exp) || isdigit(*exp) || *exp=='_') *d++=*exp++;
  *d++=0;
  return buffer;
}


char *identifier(struct package *p,int line) {
  const char *var;
  char *r;
  const char *z;
  
  getid();
  /* Package override ? */
  if (skipblank()=='.') {
    char *pa=strdupa(buffer);
    struct package *q=package_find(pa,P_INSTALLED);
    exp++;
    if (q==NULL) { error("%s(%d): package %s not installed.",p->name,line,pa);return NULL; }
    p=q;
    skipblank();
    getid();
  }
  /* Now we just need to search for the identifier and return the result
     search path
     1. Overrides for this package
     2. B records of this package
     2. A records of this package
     3. attributes 
     Any use must generate a new B record if such a record does not already exists.
  */
  if (strcmp(buffer,"V")==0) return extract_upstream_version(pkg_version(p));
  if (strcmp(buffer,"D")==0) return extract_delta_version(pkg_version(p));
  if (strcmp(buffer,"P")==0) return strdup(pkg_name(p));
  
  var=strdupa(buffer);
  if (p->name) { 
    z=getsetting(p->name,var);
    line=G_ATTRIB;
    if (z) goto gotit;
  }
  
  ACT(p,'I') if (strcmp(x->v1,var)==0) return x->v2 ? strdup(x->v2):NULL;
  ACT(p,'B') if (strcmp(x->v1,var)==0) return x->v2 ? strdup(x->v2):NULL;
  ACT(p,'A') if (strcmp(x->v1,var)==0) { z=x->v2;line=x->lineno;goto gotit; }
  z=getsetting("attributes",var);
  line=G_ATTRIB;
 gotit:
  if (z) r=string_expand(p,z,line); else r=NULL;

  /* Generate B records if not P V B or S */
  if (strlen(var)>1 || strchr("PVBS",var[0])==NULL) {
    debug("saving build information: %s=%s",var,r);
    node_b(p,G_BUILD,var,r);
  }
  return r;
}

char *literal(struct package *p,int line) {
  char *d=buffer;

  while (isalpha(*exp) || isdigit(*exp) || *exp=='_' || *exp=='.') *d++=*exp++;
  *d++=0;
  return strdup(buffer);
}

char *quote(struct package *p,int line) {
  char *d=buffer;
  int c;

  c=*exp++;
  while (*exp && *exp!=c) *d++=*exp++;
  *d++=0;
  if (*exp++==0) { error("%s(%d): Unterminated string",p->name,line);return NULL; }
  if (c=='\"') {
    char *x=strdup(buffer);
    char *y=string_expand(p,buffer,line);
    free(x);
    return y;
  } else return strdup(buffer);
}

char *simpexp(struct package *p,int line) {
  char *r;

  if (isalpha(skipblank())) return identifier(p,line); else
  if (isdigit(*exp)) return literal(p,line); else
  if (*exp=='"' || *exp=='\'') return quote(p,line); else
  if (*exp=='(') {
     exp++;
     r=expression(p,line);
     if (skipblank()!=')') { error("%s(%d): Syntax Error: Missing )",p->name,line);return NULL; }
     exp++;
     return r;
  } else
  if (*exp=='!') {
    exp++;
    r=expression(p,line);
    if (r) { free(r);return NULL; }
    else return strdup("TRUE");
  } else error("%s(%d): Syntax Error '%c'",p->name,line,*exp);
  return NULL;
}

char *arithexp(struct package *p,int line) {
  char *r,*r2;
  r=simpexp(p,line);
  while (skipblank()=='+') {
    exp++;
    r2=simpexp(p,line);
    if (r==NULL) r=r2; else
    if (r2!=NULL) {
      char *x;
      x=malloc(strlen(r)+strlen(r2)+1);
      strcpy(x,r);strcat(x,r2);
      free(r);free(r2);
      r=x;
    }
  }
  return r;
}

char *compexp(struct package *p,int line) {
  char *r,*r2;

  r=arithexp(p,line);

  skipblank();
  if (*exp && strchr("=!<>",*exp)) {
    char c1;
    char c2;
    int b,cmp;
    
    c1=*exp++;c2=0;
    if (*exp && strchr("!=<>",*exp)) c2=*exp++;

    r2=arithexp(p,line);
    if (r2==NULL) r2=strdup("");
    if (r==NULL) r=strdup("");
    cmp=strverscmp(r,r2);
    if (c2>c1) { b=c2;c2=c1;c1=b; }
    if (r) free(r);
    if (r2) free(r2);
    b=-1;
    switch (c1) {
      case '<' : switch (c2) {
                   case 0  : b=cmp<0;break;
                   case '=': b=cmp<=0;break;
		 }
		 break;
      case '=' : switch (c2) {
                   case '>' : b=cmp>=0;break;
		   case 0 : b=cmp==0;break;
		   case '!' : b= cmp!=0;break;
		 }
		 break;
      case '>' : switch (c2) {
                   case 0: b=cmp>0;break;
		   case '=' : b=cmp>=0;break;
		   case '<' : b=cmp!=0;break;
		 }
		 break;
    }
    if (b<0) fatal("%s(%d): Bad comparison %c%c",p->name,line,c1,c2);
    if (b) return strdup("TRUE"); else return NULL;
  }
  return r;
}

char *orboolexp(struct package *p,int line) {
  char *r,*r2;

  r=compexp(p,line);
  while (skipblank()== '|') {
     char c;
     int b;
     
     c=*exp++;
     if (*exp==c) exp++;
     r2=compexp(p,line);
     /* do and or or */
     b=r || r2;
     if (r) free(r);
     if (r2) free(r2);
     if (b) r=strdup("TRUE"); else r=NULL;
  }
  return r;
}

char *boolexp(struct package *p,int line) {
  char *r,*r2;

  r=orboolexp(p,line);
  while (skipblank()=='&') {
     char c;
     int b;
     
     c=*exp++;
     if (*exp==c) exp++;
     r2=orboolexp(p,line);
     b=r && r2;
     if (r) free(r);
     if (r2) free(r2);
     if (b) r=strdup("TRUE"); else r=NULL;
  }
  return r;
}

char *expression(struct package *p,int line) {	/* Evaluate expression and return result */
 char *r,*r2,*r1;

 r=boolexp(p,line);
 if (skipblank()=='?') {
   exp++;
   if (*exp!=':') {
      r1=boolexp(p,line);
      skipblank();
   } else r1=NULL;
   if (*exp==':') {
     exp++;
     r2=boolexp(p,line);
   } else r2=NULL;
   if (r) {
     free(r);
     if (r2) free(r2);
     return r1;
   }
   if (r1) free(r1);
   return r2;
 } else if (*exp==':') { /* Regular expression matching */
   exp++;
   r2=boolexp(p,line);
   if (r) {
     if (r2) {
       regex_t compiled;
       regmatch_t match[2];
       if (regcomp(&compiled,r2,REG_EXTENDED)) {
         error("%s(%d): Error in regex pattern '%s'",p->name,line,r2);
	 free(r);free(r2);
	 return NULL;
       }
       if (compiled.re_nsub>1) error("%s(%d): More than one parenthetical subexpression.");
       if (regexec(&compiled,r,2,match,0)==0) { /* Successful match */
         int n;
	 if (compiled.re_nsub) {
	   /* Return what matched the subexpression */
	   n=match[1].rm_eo-match[1].rm_so;
	   r1=malloc(n+1);
	   if (n>0) {
	     strncpy(r1,r+match[1].rm_so,n);
	   }
	 } else {
	   /* Return what matched the expression */
	   n=match[0].rm_eo-match[0].rm_so;
	   r1=malloc(n+1);
	   strncpy(r1,r+match[0].rm_so,n);
	 }
	 r1[n]=0;
	 free(r);free(r2);
	 return r1;
       } else { /* Pattern did not match */
         free(r);free(r2);
	 return NULL;
       }
     } else {
       error("%s(%d): No string to match specified",p->name,line);
       return NULL;
     }
   } else { /* No string to match specified */
     if (r2) free(r2);
     return r;
   }
 }
 return r;
}

char *string_expand(struct package *pkg,const char *source,int line) {
  const char *s;
  char *d;
  char buf[MAXLLENGTH];

  if (source==NULL) return NULL;
  d=buf;
  for(s=source;*s;) {
    if (*s=='$' && s[1]=='{') {	// Escape for ${ } style shell variable references
      *d++=*s++;
      *d++=*s++;
    } else
    if (*s=='\\' && (s[1]=='}' || s[1]=='{')) {
      s++;		// Skip escape character
      *d++=*s++;	// Copy the braces
    } else {
      if (*s=='{') {
	char *x;
        const char *saveexp=exp;
	
	exp=s+1;
	x=expression(pkg,line);
	if (x) {
	  if (d+strlen(x)>buf+MAXLLENGTH) swerr("string_expand: Buffer Overrun at result insert");
	  strcpy(d,x);
	  d+=strlen(x);
	  free(x);
	}
	s=exp;
	if (skipblank()!='}') { error("%s(%d): Syntax Error: Closing } missing",pkg->name,line);return NULL; }
	s++;
	exp=saveexp;
      } else *d++=*s++;
    }
    if (d>buf+MAXLLENGTH) swerr("string_expand: Buffer Overrun at character copy");
  }
  if (d==buf) return NULL;
  *d++=0;
  return strdup(buf);
}

/*************************************************************************
    BUILDING PACKAGES 
*************************************************************************/

char *package_setup_tempdir(struct package *pkg,const char *dir,const char *prefix) {
  char *tempdir;

  tempdir=strdup(catstr(dir,"/",prefix,pkg->name,"-",pkg->version,NULL));
  check_path(tempdir);
  removedir(tempdir);
  if (mkdir(tempdir,0755)) sys_abort(tempdir);
  return tempdir;
}

/* Setup a tempary directory for building the binary tree for a package
   This routine takes care to generate different build directories for
   different users */
char *package_setup_binary_directory(struct package *p) {
  const char *z;
  
  z=temp_dir;
  if (uid) z=strdupa(catstr(temp_dir,"-",getenv("LOGNAME"),NULL));
  return package_setup_tempdir(p,z,"build-");
}  

int unpack_source(struct node *x) {
  char *url=string_expand(x->pkg,x->v1,x->lineno);
  int ext;
  char *filename,*path;
  char *p=url+strlen(url);
  int rc;
  
  /* Separate Path off */
  while (p>url && *--p!='/') ;
  if (p==url) path=NULL; else {
    *p++=0;
    path=url;
  }
 
  filename=p;
  ext=is_tarball(filename);
  if (ext==0) return -1;
  rc=shell(source_unpack[ext],strdupa(catstr(cache_files,"/",filename,NULL)));
  free(url);
  return rc;
}

void print_to_file(char *file,char *s,...) {
  char *x;
  FILE *f;
  va_list ap;
  va_start(ap,s);
  vasprintf(&x,s,ap);
  
  if (file==NULL) return;
  f=fopen(file,"a");
  if (f==NULL) sys_abort(file);
  fputs(x,f);
  fputc('\n',f);
  fclose(f);
  free(x);
}

int apply_patch(struct node *x,char *log) {
  char *url=string_expand(x->pkg,x->v1,x->lineno);
  int ext;
  char *filename,*path;
  char *p;
  char *cmd;
  char *cd;
  int rc;
  int pfactor=-1;
  char *ffname;
  char *src_file;
  
  /* Check for an @ expression */
  for(cd=url+strlen(url);cd>url && *cd!='@';cd--) ;
  if (cd!=url) *cd++=0; else cd=NULL;
  
  /* Separate Path off */
  for(p=url+strlen(url);p>url && *p!='/';p--) ;
  if (p==url) path=NULL; else {
    *p++=0;
    path=url;
  }
 
  filename=p;
  /* Check if this is a tarball. A tarball simply is untarred over the other files */
  ext=1;
  while (source_extensions[ext] && strcmp(source_extensions[ext],filename+strlen(filename)-strlen(source_extensions[ext]))) ext++;
  if (source_extensions[ext]) { 
    if (cd) {
      if (chdir(cd)) { if (mkdir(cd,0755)) sys_abort(cd); else chdir(cd); }
    }
    src_file=strdupa(catstr(cache_files,"/",filename,NULL));
    ffname=strndupa(filename,strlen(filename)-strlen(source_extensions[ext]));
    if (strncmp(ffname,pkg_name(x->pkg),strlen(pkg_name(x->pkg)))==0) {
      ffname+=strlen(x->pkg->name);
      if (*ffname=='-') {
        ffname++;
        if (strncmp(ffname,pkg_version(x->pkg),strlen(pkg_version(x->pkg)))==0) {
	  ffname+=strlen(pkg_version(x->pkg));
	  if (*ffname=='-') ffname++;
	}
      }
    }
    rc=shell(source_unpack[ext],src_file,ffname);
    free(url);
    return rc;
  }
  /* Find extension type */
  ext=1;
  while (patch_extensions[ext] && strcmp(patch_extensions[ext],filename+strlen(filename)-strlen(patch_extensions[ext]))) ext++;
  if (patch_extensions[ext]==NULL) ext=0;
 
  /* Compose command to get the stream of diffs */
  sprintf(buffer,patch_unpack[ext],strdupa(catstr(cache_files,"/",filename,NULL)));
  cmd=strdup(buffer);

  if (cd) {
    if (*cd<'3' && *cd >='0') pfactor=*cd++ -'0'; else pfactor=0;
    if (*cd) {
      mkdir(cd,0775);
      if (chdir(cd)) sys_abort(cd);
      /* else pfactor=0;*/
    }
  }
 
  /* Try a dry run to see if this would fit */
  if (pfactor<0) {
    if (shell("%s | patch --dry-run -ltp1 >/dev/null 2>&1",cmd) ) pfactor=0;
    else pfactor=1;
    debug("Using -p%d for patch %s\n",pfactor,x->v1);
  }
  
  printf("___________ Patch %s\n",filename);
  
  rc=shell(log ? "%s | patch -ltp%d >>%s 2>&1" : "%s | patch -ltp%d",cmd,pfactor,log);
  
  printf("~~~~~~~~~~~ End Patch\n");
  free(url);
  free(cmd);
  return rc;
}

const char *goodfiles[] = {"Makefile","Makefile.in","configure","configure.in",
   "INSTALL","Makefile.am","ChangeLog","debian/rules","makefile",NULL};

int good_build_dir(char *directory) {
  struct stat fbuf;
  const char **p;

  for(p=goodfiles;*p;p++) if (stat(catstr(directory,"/",*p,NULL),&fbuf)==0 && S_ISREG(fbuf.st_mode)) return TRUE;
  return FALSE;
}

char *pkg_save(struct package *pkg,const char *dir,const char *tdir) {
  char *arch;
  char *x;
  
  exp="ARCH";
  arch=expression(pkg,G_BUILD);
  if (arch==NULL) arch="all";
  
  x=generate_tarball(tdir,"%s/%s-%s_%s",dir,pkg->name,pkg->version,arch);
  info("%s: Package Tarball %s generated",pkg->name,x);
  return x;
}

/* Returns error code or -1 for no action required */
int run_stage(struct package *p,char *exec,char *phase,char *dir,char *log) {
  char *x;
  int rc;
  
  if (chdir(dir)) sys_abort(dir);
  exp=exec;
  x=expression(p,G_BUILD);
  if (x==NULL || x[0]==0) return -1;

  buffer[0]=0;
  strcat(buffer,"(%s)");
  if (log) {
    strcat(buffer," >>");
    strcat(buffer,log);
    strcat(buffer," 2>&1");
  }
  printf("___________ %s phase: %s\n",phase,x);

  rc=shell(buffer,x);

  if (rc) {
    error("%s: %s phase failed",p->name,phase);
    return rc;
  }
  printf("~~~~~~~~~~~ %s phase end\n",phase);
  return 0;
}

int retrieve_sources(struct package *p) {
  /* retrieve sources */
  int gotsource=FALSE;
  ACT(p,'S') if (node_retrieve(x,source_loc)==TRUE) { gotsource=TRUE;break; };
  if (!gotsource) return FALSE;
  ACT(p,'P') if (!node_retrieve(x,patch_loc)) return FALSE;
  return TRUE;
}

/* Unpack all the tarballs and patchfiles for a package into the
   current working directory. Find build files in the directory or
   in some subdirectory (directory is changed then ...)
   Construct a proper source archive for building */
char *package_unpack(struct package *p,char *tdir,char *log,int stage) {
  int patchdone=FALSE;
  char *builddir;
  
  if (chdir(tdir)) sys_abort(tdir);
  ACT(p,'S') {
    if (unpack_source(x)) fatal("%s(%d): Error while unpacking source from %s",p->name,x->lineno,x->v1);
     node_setmd5(x);
  }
  /* Find a directory that has all the typical files that indicate buildable sourcecode */
  if (attr_find(p,'A',"BUILDDIR")) {
    char *x=string_expand(p,"{BUILDDIR}",G_BUILD);
    if (chdir(x)) sys_abort(x);
    free(x);
  } else {
    int descent=TRUE;
    
    /* Descent into the tree until a directory is found that has more than just one subdir */
    while (descent) {
      DIR *dir;
      struct dirent *dire;
      char *nextdir=NULL;
    
      dir=opendir(".");
      if (dir==NULL) sys_abort(".");
      while ((dire=readdir(dir))) {
        if (dire->d_name[0]=='.') continue;
        if (!is_dir(dire->d_name)) { descent=FALSE; break; }	// something not dir... bad
        if (nextdir) { descent=FALSE; break; }			// Second directory ... bad
        nextdir=strdupa(dire->d_name);      
      }
      closedir(dir);
      if (descent) {
        if (nextdir==NULL) fatal("%s: Empty directory",p->name);
	else chdir(nextdir);
      }
    }
  
    if (!good_build_dir(".")) {
      DIR *dir;
      struct dirent *dire;
  
      dir=opendir(".");
      if (dir==NULL) sys_abort(tdir);
      while ((dire=readdir(dir))) {
    
        if (dire->d_name[0]=='.') continue;
        if (is_dir(dire->d_name) && good_build_dir(dire->d_name)) {
          chdir(dire->d_name);
  	  info("%s: build files found in subdirectory %s",p->name,dire->d_name);
	  node_b(p,G_BUILD,"BUILDDIR",dire->d_name);
	  goto patches;
        }
      }
      warn("%s: Cannot find typical build files in sourcetree. Assuming '.'",p->name);
    patches:
      closedir(dir);
    }
  } 

  builddir=getcwd(NULL,0);
  progress("%s: Source unpacked in %s.",p->name,builddir);
  /* Retrieve and apply patches */
  ACT(p,'P') {
    stage--;
    if (stage<=1) return builddir;
    /* Apply patch has the capability of changing the sourcedir. Go back for every patch */
    if (chdir(builddir)) sys_abort(builddir);
    if (apply_patch(x,log)) fatal("%s(%d): Patch from %s failed to apply cleanly",p->name,x->lineno,x->v1);
    node_setmd5(x);
    patchdone=TRUE;
  }
  if (patchdone) progress("%s: Patches applied in %s.",p->name,builddir);
  return builddir;
}

int run_events(struct package *p,enum eventtype e,char *dir,char *log) {
  int rc;
  if (chdir(dir)) sys_abort(dir);
  ACT(p,'E') if (x->event==e) { rc=node_run(x,FALSE,log); if (rc) return rc; }
  return 0;
}

void deploy_husk(struct package *p,char *dir) {
  if (chdir(dir)) sys_abort(dir);
  /* Deploy the base husk so that the install routines
   will not abort because of missing basic directories
   and so that we wont get files in duplicate locations
   that are made the same by bases symlinks */
  if (base && p->base==FALSE) {
    ACT(base,'D') mkdir(x->v1,x->mode);
    ACT(base,'L') symlink(x->v2,x->v1);
  }
}
 
void remove_husk(struct package *p,char *dir) {
  if (chdir(dir)) sys_abort(dir);
  if (base && p->base==FALSE) { 
    /* Remove Husk */
    ACT(base,'L') unlink(x->v1);
/* It would be good to find out why unlink always returns an error code when 
   a symlink is removed
 if (!unlink(x->v1)) warn("Unable to remove %s while removing husk",x->v1); */
    dirs_remove(base->r['D'-'A']);
  }
}

/* Build a binary tarball given the filename of a recipe
   name is the filename of a recipe from which to build
   where is the directory where to place the resulting binary tarball
   source is the directory where to unpack the source to. If NULL then a temp directory is generated.
   stage is the limit on how far the build should proceed
*/
char *package_build(const char *name,const char *where,char *source,int stage) {
  struct package *p;
  char *targetdir=NULL;
  char *sourcedir=NULL;
  char *builddir=NULL;
  char *buildlog=NULL;
  char *olddir=getcwd(NULL,0);
  char *x;
  int rc;

  /* Need husk from installed packages */
  if (!read_in[P_INSTALLED]) read_packages(P_INSTALLED);
  
  p=package_read(name,P_UNLISTED);
  if (p==NULL) fatal("%s: No such package",name);

  node_comment(p,p->lines++,"The following information was added during build/install");

  if (p->r['C'-'A']) {
    if (stage!=99) fatal("%s: Cannot build from binary package",p->name);
    /* Should check for arch compatibility here */
    targetdir=strdup(p->r['C'-'A']->v2);
    if (*targetdir!='/') {
      retrieve(targetdir,NULL);
      x=strdup(catstr(cache_files,"/",basename(targetdir),NULL));
      free(targetdir);
      x=targetdir;
    }
    symlink(targetdir,where);
    return targetdir;    
  }
  if (stage>45) {
    struct mdep *m;
    m=build_dep_check(p,NULL);
    if (m) {
      if (no_depends || root[0]) {
        mdep_free(m);
        warn("%s: Skipping build dependencies.",p->name,root);
        node_b(p,G_BUILD,"WARN","Dependency check skipped");
      } else {
        mdep_print(m);
	if (!deps) fatal("%s: Build dependencies unresolved",p->name);
	if (mdep_serious(m)) {
	  mdep_print(m);
	  mdep_free(m);
	  error("%s: Unresolvable dependency issues.",p->name);
	  goto buildfail;
	}
        if (!mdep_install(m)) { error("%s: Failed to build necessary components",p->name);goto buildfail; }
      }
    }
    if (base==NULL && p->base==FALSE) { error("%s: Cannot build without a base package.",p->name);goto buildfail; }
  }

  /* set key environment variables describing locations and names */
  node_b(p,G_BUILD,"BUILD_upm",VERSION);
  /* Setup path */
  environment_for_build();

  if (!p->meta) {
    const char *s=source;
    
    if (p->r['S'-'A']==NULL) { error("%s: Cannot build without source specification.",p->name);goto buildfail; }
    
    if (!retrieve_sources(p)) { error("%s: files missing",p->name);goto buildfail; }

    if (stage==0) return NULL;

    if (source==NULL) {
      if (uid) {
        s=strdupa(catstr(temp_dir,"-",getenv("LOGNAME"),NULL));
      }
      else s=temp_dir;
    }
    sourcedir=package_setup_tempdir(p,s,"");

    progress("%s: Found all files needed for building.",p->name);
    if (!no_logs) {
      buildlog=strdupa(catstr(s,"/",p->name,"-",p->version,".log",NULL));
      check_path(buildlog);
      debug("Logging build output to %s",buildlog);
    }
    if (buildlog) {
      unlink(buildlog);
      print_to_file(buildlog,"UPM %s starting to build\n",VERSION);
    }

    debug("%s: Directores and build environment setup",p->name);
 
    if (stage>=45) {
      targetdir=package_setup_binary_directory(p);
      putsetting("attributes","B",targetdir);
      node_b(p,G_BUILD,"B",targetdir);
    }

    if (uid==0 && builduser && p->realroot==FALSE) { 
      /* Make sure that we have permission on the files that we need to modify */
      if (chown(targetdir,builduser->pw_uid,builduser->pw_gid)) sys_abort(targetdir);
      if (chown(sourcedir,builduser->pw_uid,builduser->pw_gid)) sys_abort(sourcedir);
      if (buildlog && chown(buildlog,builduser->pw_uid,builduser->pw_gid)) sys_abort(buildlog);
      if (chown(where,builduser->pw_uid,builduser->pw_gid)) sys_abort(where);
      become_user(builduser); 
    }
    builddir=package_unpack(p,sourcedir,buildlog,stage);
    if (stage<=45) return NULL;
    if (p->realroot && uid) { error("%s: Needs real root for building",p->name);goto buildfail; }
    putsetting("attributes","S",builddir);
    node_b(p,G_BUILD,"S",builddir);

    { struct sect *s=findsection("env");
      if (s)
        for(x=s->envz;x<s->envz+s->envz_len;x+=strlen(x)+1)
          putenv(string_expand(p,x,G_BUILD));
    }
    
    if (run_events(p,E_PRECONFIGURE,builddir,buildlog)) goto buildfailu;
    if (stage<=49) return NULL;
    if (run_stage(p,"CONFIGURE","Configure",builddir,buildlog)>0) goto buildfailu;
    if (stage<=50) return NULL;
    if (run_events(p,E_POSTCONFIGURE,builddir,buildlog)) goto buildfailu;
    if (stage<=51) return NULL;
    if (run_events(p,E_PREBUILD,builddir,buildlog)) goto buildfailu;
    if (stage<=59) return NULL;
    if (run_stage(p,"BUILD","Build",builddir,buildlog)>0) goto buildfailu;
    if (stage<=60) return NULL;
    if (run_events(p,E_POSTBUILD,builddir,buildlog)) goto buildfailu;
    if (stage<=61) return NULL;
    if (run_stage(p,"CHECK","Testing",builddir,buildlog)>0) goto buildfailu;
    if (stage<=70) return NULL;

    if (p->realroot==FALSE) {
      if (fakeroot)
        fakeroot_start();
      else
        become_root();
    }
 
    deploy_husk(p,targetdir);
    if (stage<=78) return NULL;
    if (run_events(p,E_PREINST,targetdir,buildlog)) goto buildfailf;
    if (stage<=79) return NULL;
    
    /* Do the installation */
    rc=run_stage(p,"INSTALL","Installation",builddir,buildlog);
    if (rc>0) goto buildfailf;
    if (rc<0) { error("%s: no INSTALL attribute. Cannot install software.",p->name);goto buildfailf; }
 
    if (stage<=80) return NULL;

    if (run_stage(p,"MAN_HANDLER","Handling manpages",builddir,buildlog)>0) goto buildfailf;
    if (stage<=81) return NULL;
    if (run_stage(p,"DOC_HANDLER","Handling documentation",builddir,buildlog)>0) goto buildfailf;
    if (stage<=82) return NULL;
    if (run_stage(p,"INFO_HANDLER","Handling Infofiles",builddir,buildlog)>0) goto buildfailf;
    if (stage<=83) return NULL;
    if (run_events(p,E_POSTINST,targetdir,buildlog)) goto buildfailf;
    if (stage<=84) return NULL;
    /* Generate SYSV style symlinks to init script */
    ACT(p,'Q') if (!setlinks(x->v1,x->v2)) goto buildfailf;
    remove_husk(p,targetdir);
    if (stage<=85) return NULL;
   /* Sanity check .... did this install do anything? */
    if (!p->insane) {
      DIR *dir;
      struct dirent *dire;

      int files=0;
      int dirs=0;
    
      dir=opendir(targetdir);
      if (dir==NULL) sys_abort(targetdir);
      while ((dire=readdir(dir))) {
        if (dire->d_name[0]=='.') continue;
        catstr(targetdir,"/",dire->d_name,NULL);
        if (is_dir(buffer)) dirs++;
        if (is_file(buffer)) files++;
      }
      closedir(dir);
      if (dirs==0) { error("%s: Sanity check failed. No directories in /",p->name);goto buildfailf; }
      if (files>0) { error("%s: Sanity check failed. Files in /",p->name);goto buildfailf; }
      if (is_dir(catstr(targetdir,"var/tmp/upm-binary",NULL))) {
        error("%s: Sanity check failed. /var/tmp/upm-binary exists in target",p->name);
	goto buildfailf;
      }
    } 
  
    if (run_stage(p,"FINAL_HANDLER","Finalizer",targetdir,buildlog)>0) goto buildfailf;
    if (stage<=86) return NULL;
    if (run_events(p,E_PERM,targetdir,buildlog)) goto buildfailf;
    if (stage<=90) return NULL;
    progress("%s: Install to temp directory ok.",p->name);
  
    if (!keepdirs) removedir(sourcedir);
    free(sourcedir);free(builddir);

    if (!p->noautodep) generate_executable_dependencies(p,targetdir);

  } else {
    /* Metapackage */
    targetdir=package_setup_binary_directory(p);
    if (chdir(targetdir)) sys_abort(targetdir);
  }
  
  /* Relist package now as having been build */
  p=pkg_list(p,P_BUILD,catstr(UPM_IN,p->name,"-",p->version,NULL));
  package_write(p);
  /* The save action needs to be done BEFORE fakeroot ends.
     Otherwise the permissions and ownerships are gone for good. */
  x=pkg_save(p,where,targetdir);
  if (p->realroot==FALSE && p->meta==FALSE) {
    if (fakeroot) fakeroot_end();
    if (uid==0) become_root();
  }

  info("%s: Build of %s-%s complete.",p->name,p->name,p->version);
 endit:
  if (!keepdirs && targetdir) removedir(targetdir);
  if (targetdir) free(targetdir);
  chdir(olddir);
  free(olddir);
  return x;

  /* Failure in the section where we have fakeroot active */
buildfailf:
  if (p->realroot==FALSE && p->meta==FALSE) {
    if (fakeroot) fakeroot_end();
  }

  /* Failure in the section where we are another user */
buildfailu:
   if (p->realroot==FALSE && p->meta==FALSE) {
     if (uid==0) become_root();
  }
  
  /* Failure before any userid changes */
buildfail:
  if (!keepdirs && sourcedir) removedir(sourcedir);
  error("%s: Build failed.",p->name);
  pkg_remove(p);
  x=NULL;
  goto endit;
}

/*********************************************************
    Command line invoked routines
*********************************************************/

int pkg_install(const char *x) {
  const char *z=save_binaries ? save_binaries : temp_dir;
  char *y;
  
  if (fetchonly) {
    return NULL!=package_build(x,z,NULL,0);
  }
  y=package_build(x,z,NULL,99);
  if (y==NULL) return FALSE;
  if (save_binaries && uid==0) shell("/usr/upm/scripts/reg_binary %s %s",y,mdirs[P_BUILD]);
  if (merge_root(y)) return FALSE;
  if (!keepdirs && z==temp_dir) unlink(z);
  return TRUE;
}

int newerthan(struct package *x,struct package *y) {
  int r=strverscmp(x->version,y->version);

  if (r>0) return TRUE;
  if (r<0) return FALSE;
  return FALSE;
}

int install(int count,char **v,char **e) {
  char **p;
  
  for(p=v;p<e;p++) {
    char *name=*p;
    
    if (strchr(name,';')) {
      /* URL: need to retrieve the contents to be able to further look at the situation */
      if (retrieve(*p,NULL)) fatal("Cannot retrieve file from %s",*p);
      name=strdup(catstr(cache_files,"/",basename(*p),NULL));
    } else if (strchr(name,'/')) {
      /* PATH: need to make sure that it is absolute */
      if (name[0]!='/') name=strdup(catstr(cwd,"/",name,NULL));
    } else if (strchr(name,'-') && is_file(catstr(cwd,"/",name,NULL))) {
      /* File relative to current directory. Make it absolute */
      name=strdup(catstr(cwd,"/",name,NULL));
    } else {
      /* This must now be a reference to a recipe or a build */
      struct package *x=NULL;
      if (binaries == B_IFAVAIL || binaries==B_IFLOCAL || binaries == B_ALWAYS) x=package_find(name,P_BUILD);
      if (x==NULL && (binaries == B_IFAVAIL || binaries==B_IFLOCAL || binaries == B_NEVER)) x=package_find(name,P_RECIPE);
      if ((binaries == B_IFAVAIL || binaries==B_IFLOCAL) && x) {
        /* Check if there is a more recent source package. If so take source instead */
        struct package *y=package_find(name,P_RECIPE);
	if (y && newerthan(y,x)) x=y;
      }
      if (x==NULL) fatal("Cannot locate a way to install using '%s'",name);
      name=x->location;
    }

    /* At this point we have name pointing to an absolute filename.
       We need to determine what type it is */
    if (is_file(name)) {
      if (is_tarball(name)) merge_root(name); else pkg_install(name);
    } else fatal("Cannot find anything to do with %s",name);
  }
  return 0;
}

int remove_cmd(int count,char **v,char **e) {
  char **p;
  
  for(p=v;p<e;p++) {
    struct package *pkg=package_find(*p,P_INSTALLED);
    if (pkg==NULL) fatal("%s: not installed.",*p);
    pkg_delist(pkg);
    if (!dep_check_all(P_INSTALLED)) fatal("Dependency problem. Cannot remove package");
    ACT(pkg,'Q') if (strchr(x->rcd,'E')) init_script(pkg,x->v1,STOP);
    purge_package(pkg);
  }
  return 0;
}

int config_save(int count,char **v,char **e) {
  char **p;
  
  for(p=v;p<e;p++) {
    struct package *pkg=package_find(*p,P_INSTALLED);
    char *tdir;
    char *x;
    if (pkg==NULL) fatal("%s: not installed.",*p);
    tdir=package_setup_binary_directory(pkg);
    ACT(pkg,'F') if (strncmp(x->v1,"etc",3)==0) {
      check_path(catstr(tdir,"/",x->v1,NULL));
      if (shell("cp %s %s/%s",x->v1,tdir,x->v1)) sys_abort(x->v1);
    }
    x=generate_tarball(tdir,"%s/%s-%s-config",cwd,pkg->name,pkg->version);
    info("%s: Configuration Tarball %s generated",pkg->name,x);
    if (!keepdirs) removedir(tdir);
    free(tdir);
    free(x);
  }
  
  return 0;
}

int config_load(int count,char **v,char **e) {
  char **p;
  
  for(p=v;p<e;p++) {
    struct package *pkg=package_find(*p,P_INSTALLED);
    char *tdir;
    if (pkg==NULL) fatal("%s: not installed.",*p);
    tdir=package_setup_binary_directory(pkg);
    unpack_tarball(tdir,"%s/%s-%s-config.tgz",cwd,pkg->name,pkg->version);
    ACT(pkg,'F') if (strncmp(x->v1,"etc",3)==0) {
      if (shell("cp %s/%s /%s",tdir,x->v1,x->v1)) warn("%s: installing %s: %s",pkg->name,strerror(errno),x->v1);
    }
    if (!keepdirs) removedir(tdir);
    free(tdir);
  }
  
  return 0;
}

int config_default(int count,char **v,char **e) {
  char **p;
  
  for(p=v;p<e;p++) {
    struct package *pkg=package_find(*p,P_INSTALLED);
    if (pkg==NULL) fatal("%s: not installed.",*v);
    ACT(pkg,'F') if (strncmp(x->v1,"etc",3)==0) {
      info("%s: Restoring %s",pkg->name,x->v1);
      if (shell("cp " ETC "%s %s",x->v1,x->v1)) sys_abort(x->v1);
    }
  }
  
  return 0;
}

int config_diff(int count,char **v,char **e) {
  char **p;
  
  for(p=v;p<e;p++) {
    struct package *pkg=package_find(*p,P_INSTALLED);
    if (pkg==NULL) fatal("%s: not installed.",*v);
    ACT(pkg,'F') if (strncmp(x->v1,"etc",3)==0) {
      int rc;

      rc=shell("diff -u " ETC "%s %s",x->v1,x->v1);
      if (rc==0) printf("Package %s File %s is in original state\n",pkg->name,x->v1);
      if (rc==1) printf("Package %s file %s was changed\n",pkg->name,x->v1);
      if (rc>1) sys_abort(x->v1);
    }
  }
  
  return 0;
}

int check(int count,char **v,char **e) {
  char **p;
  
  for(p=v;p<e;p++) {
    struct package *pkg=package_find(*p,P_INSTALLED);
    if (pkg==NULL) fatal("%s: not installed.",*p);
    check_package(pkg);
  }
  
  return 0;
}

int repair(int count,char **v,char **e) {
  char **p;
  
  for(p=v;p<e;p++) {
    struct package *pkg=package_find(*p,P_INSTALLED);
    if (pkg==NULL) fatal("%s: not installed.",*p);
    fix_package(pkg);
  }
  
  return 0;
}

int match(char *pattern,const char *s) {
  char patbuf[53];
  char *p=patbuf;
  int n=strlen(pattern);
  
  if (pattern[0]!='^') *p++='*';
  if (n>50) fatal("Search pattern too long:'%s'",pattern);
  memcpy(p,pattern,n);
  p+=n;
  if (pattern[n-1]!='$') *p++='*';
  *p=0;
  return fnmatch(patbuf,s,FNM_CASEFOLD)==0;
}


int list(int count,char **v,char **e) {
  struct stats s= { 0,0,0,0,0,"Summary of all packages installed",""};
  int counter=0;
  int totalnr=0;
  int maxpkgs=256;
  char *x;
  struct package **pkgs=malloc(maxpkgs*sizeof(struct package *));
  
  read_packages(P_INSTALLED);
 
  if (count>1) fatal("A maximum of one parameter is allowed.");

  printf("\nPackage-Version            Size Description\n"
           "----------------------------------------------------------------------\n");
  ALL_PACKAGES(P_INSTALLED) {
    totalnr++;
    if (*v==NULL || match(*v,p->name) || match(*v,pkg_description(p))) {
      int n=0;;
      while (n<counter && strcmp(pkgs[n]->name,p->name)<0) n++;
      counter++;
      if (counter==maxpkgs) { pkgs=realloc(pkgs,2*maxpkgs*sizeof(struct package *)); maxpkgs *=2; }
      if (n+1<counter) memmove(pkgs+n+1,pkgs+n,(counter-n-1)*sizeof(struct package *));
      pkgs[n]=p;
    }
  }
  for(struct package **p=pkgs;p<pkgs+counter;p++) {
    struct stats st;
    calc_stats(*p,&st);
    liststatline((*p)->name,&st);
    s.size+=st.size;
    s.files+=st.files;
    s.dirs+=st.dirs;
    s.links+=st.links;
    s.nodes+=st.nodes;
  };    
  printf("\n");
  asprintf(&x,"%d of %d installed packages listed",counter,totalnr);
  s.title=x;
  liststatline("*** Totals ***",&s);
  free(x);
  free(pkgs);
  return 0;
}

int info_cmd(int count,char **v,char **e) {
  char **p;
  
  for(p=v;p<e;p++) {
    struct package *pkg=package_find(*p,P_INSTALLED);
    if (pkg==NULL) fatal("%s: not installed",*p);
    info_package(pkg);
  }
  
  return 0;
}

int search(int count,char **v,char **e) {
 
  for(enum pmode i=P_INSTALLED;i>=P_RECIPE;i--) {
    read_packages(i);
    ALL_PACKAGES(i) {
      int ismatch=FALSE;
      const char *t=pkg_description(p);
      
      for(char **pa=v;pa<e;pa++) {
        if ((t && match(*pa,t)) || match(*pa,p->name)) ismatch=TRUE;
      }
      if (ismatch) printf(" %-15s: %s\n",p->name,t);
    }
  }
  /* Now try the descriptions */
  catstr("cd ",descriptions,";",NULL);
  for(char **pa=v;pa<e;pa++) {
    if (pa==v) strcat(buffer,"grep ");
    else strcat(buffer,"| grep ");
    strcat(buffer,*pa);
    if (pa==v) strcat(buffer," *");
  }
  shell(buffer);
  return 0;
}

int report(int count,char **v,char **e) {
 
  if (count!=0) fatal("report does not take parameters");
 
  read_packages(P_INSTALLED);
  
  printf("Extraordinary Files and Directories\n");
  printf("-----------------------------------\n");
  /* Show special nodes */
  ALL_PACKAGES(P_INSTALLED) {
    ACT(p,'N') {
      printf("%-20s NODE %o %u %u %llo\n",x->v1,x->mode,x->uid,x->gid,x->dev);
    }
  }
  /* Search for files with suid perms */
  ALL_PACKAGES(P_INSTALLED) {
    ACT(p,'F') if (x->mode > 01000) {
      printf("/%-30s FILE %o %u %u\n",x->v1,x->mode,x->uid,x->gid);
    }
  }
  /* Search for directories with suid perms */
  ALL_PACKAGES(P_INSTALLED) {
    ACT(p,'D') if (x->mode >=01000) {
      printf("/%-30s DIR  %o %u %u\n",x->v1,x->mode,x->uid,x->gid);
    }
  }
  /* Search for links that are dangling or otherwise strange */
  ALL_PACKAGES(P_INSTALLED) {
    ACT(p,'L') { struct stat fbuf;
      if (x->v2[0]!='/') { strcpy(buffer,x->v1); strcpy(basename(buffer),x->v2); } else strcpy(buffer,x->v2);
      if (stat(buffer,&fbuf)) printf("/%-30s link to %s broken\n",x->v1,x->v2);
    }
  }
  printf("\nSystem file verification\n");
  printf("------------------------\n");
  ALL_PACKAGES(P_INSTALLED) {
    ACT(p,'F') check_file(x);
    ACT(p,'D') check_dir(x);
    ACT(p,'L') check_link(x);
    ACT(p,'N') check_node(x);
  }
  printf("Verification complete.\n");
  
  return 0;
}

int update(int count,char **v,char **e) {
  const char *x;
  
  if (count) fatal("update does not take any parameters");
  
  /* If we not supposed to use any external binaries make sure that the build directory is empty */
  if (binaries==B_NEVER || binaries==B_IFLOCAL) shell("rm -f /var/upm/build/*-*");

  /* Compose the list of sections to mirror off */
  strcpy(buffer,"--include=/descr/* --include=/descr/");
  if (binaries!=B_ALWAYS) strcat(buffer," --include=/recipe/** --include=/recipe/");
  if (binaries!=B_NEVER && binaries!=B_IFLOCAL) strcat(buffer," --include=/build/* --include=/build/");
  chdir("/var/upm");
  x=strdupa(buffer);
  if (shell("rsync --safe-links --delete -rl %s --exclude=/*/ %s/* .",x,rsyncloc)) fatal("RSYNC failed");
  return 0;
}

int upgrade(int count,char **v,char **e) {
  int ok=0;
  int missrecipe=0;
  int nr=0;
  int n;
  struct buildlist *b;
  
  if (count) fatal("No parameters to upgrade allowed");
  
  read_packages(P_INSTALLED);
  b=buildlist_new();
  
  ALL_PACKAGES(P_INSTALLED) {
    int upgrade=FALSE;
    struct package *n=package_find(p->name,P_RECIPE);
    nr++;
    if (n) {
      if (strcmp(p->version,n->version)) {
        info("%s: version %s installed %s in recipes",p->name,p->version,n->version);
	if (p->hold) warn("%s: on HOLD. Will not upgrade",p->name); else upgrade=TRUE;
      } 
    } else {
      error("%s: No recipe for available",p->name);
      missrecipe++;
    }
    if (upgrade) buildlist_add(b,p->name); else ok++;
  }
  n=b->elements;
  count=buildlist_process(b,deps);
  info("%d packages, %d upgraded, %d failed %d ok, %d no recipe",nr,count,n-count,ok,missrecipe);
  return 0;
}

int syncbuild(int count,char **v,char **e) {
  int unbuildable=0;
  int ok=0;
  int nr=0;
  int pcount;
  int n;
  struct buildlist *b;
  
  read_packages(P_INSTALLED);
  
  b=buildlist_new();
  ALL_PACKAGES(P_INSTALLED) {
    int rebuild=FALSE;
    nr++;
    ACT(p,'B') {
      if (strncmp(x->v1,"BUILD_",6)==0) {
        char *pkg=x->v1+6;
	for(char **x=v;x<e;x++) if (strcmp(*x,pkg)==0) goto nextB;
        struct package *y=package_find(pkg,P_INSTALLED);
        if (y) {
          if (strcmp(y->version,x->v2)) {
	    info("%s: Build with %s version %s but version %s is now installed.",p->name,pkg,x->v2,y->version);
	    if (p->hold) warn("%s: on HOLD not updating",p->name); else rebuild=TRUE;
	  }
        } else {
	  error("%s: Need %s to build",p->name,pkg);
	  unbuildable++;
	}
      }
      if (strcmp(x->v1,"WARN")==0 || strcmp(x->v1,"ROOT")==0) {
        info("%s: Build in foreign environment",p->name);
	rebuild=TRUE;
      }
     nextB:;
    }
    if (rebuild) buildlist_add(b,p->name); else ok++;
  }
  n=b->elements;
  pcount=buildlist_process(b,deps);
  info("%d packages, %d up to date , %d rebuild, %d failed, %d unbuildable.",nr,ok,pcount,n-pcount,unbuildable);  
  return 0;
}

char *ignoreattr[]={"B","S","VERSION","BUILDDIR","PACKAGE","UPM_VERSION","DOC","MAN","INFO","MAN_HANDLER","DOC_HANDLER","INFO_HANDLER","FINAL_HANDLER",NULL};

/* String comparision ignoring whitespace differences */
#define WSPA " \t"
int stracmp(char *x,char *y) {
 
  /* Skip space at the beginning */
  while (*y && strchr(WSPA,*y)) y++;
  while (*x && strchr(WSPA,*x)) x++;
  
  while (*x) {
    if (*y==0) {
      /* Second string terminates. Its ok if the rest of the other string is blank */
      while (*x && strchr(WSPA,*x)) x++;
      if (*x==0) return 0;
      return 1;
    }
    if (strchr(WSPA,*x) && strchr(WSPA,*y)) {
      y++;x++;
      /* Two white spaces. Ignore sequences of whitespace in both strings */
      while (*y && strchr(WSPA,*y)) y++;
      while (*x && strchr(WSPA,*x)) x++;
    } else {
      /* Both are not spaces and not end of string. So we can actually do the compare */
      if (*x++!=*y++) return 1;
    }
  }
  /* End of X. Skip eventual space at the end of Y */
  while (*y && strchr(WSPA,*y)) y++;
  if (*y==0) return 0;
  return 1;

}

int syncattr(int count,char **v,char **e) {
  int unbuildable=0;
  int ok=0;
  int nr=0;
  int pcount;
  int elements;
  struct buildlist *b;
  
  read_packages(P_INSTALLED);

  b=buildlist_new();
  ALL_PACKAGES(P_INSTALLED) {
    int rebuild=FALSE;
    nr++;
    ACT(p,'B') {
      struct node *y=x;
      const char *z;
      char *s;
      char *t;
    
      /* if its a BUILD_ record then it does not matter for this check */
      if (strncmp(x->v1,"BUILD_",6)==0) goto nextB;

      /* If its one of the UPM provided attributes then continue */
      for(char **q=ignoreattr;*q;q++) if (strcmp(*q,x->v1)==0) goto nextB;
     
      /* Skip all the attributes mentioned on the command line */
      for(char **q=v;q<e;q++) if (strcmp(*q,x->v1)==0) goto nextB;
      
      /* If the origin was the A records then it cannot have changed */
      ACT(p,'A') if (strcmp(x->v1,y->v1)==0) goto nextB;

      /* First check the overrides */
      z=getsetting(p->name,x->v1);
      
      /* If no override then check default attributes */
      if (z==NULL) z=getsetting("attributes",x->v1);
      
      /* No setting means empty */
      if (z==NULL) s=NULL; else s=string_expand(p,z,x->lineno);
	
      if (s==NULL) s="";
      t=x->v2;
      if (t==NULL) t="";
      
      if (stracmp(s,t)) {
	 info("%s: Attribute %s. Was '%s' when it was build it is '%s' now.",p->name,x->v1,t,s);
	 if (p->hold) warn("%s on HOLD. not rebuilding",p->name); else rebuild=TRUE;
      }
      if (s!=NULL && s[0]) free(s);
    nextB:;
    }
    if (rebuild) buildlist_add(b,p->name); else ok++;
  }
  elements=b->elements;
  pcount=buildlist_process(b,deps);
  info("%d packages, %d up to date , %d rebuild, %d failed, %d unbuildable.",nr,ok,pcount,elements-count,unbuildable);  
  return 0;
}

int deprebuild(int count,char **v,char **e) {
  int unbuildable=0;
  int ok=0;
  int nr=0;
  int pcount;
  int elements;
  struct buildlist *b;
  
  read_packages(P_INSTALLED);

  b=buildlist_new();
  ALL_PACKAGES(P_INSTALLED) {
    int rebuild=FALSE;
    nr++;
    ACT(p,'R') if (x->relation==R_BUILD || x->relation==R_DEPEND) {
      for(char **q=v;q<e;q++) if (strcmp(*q,x->v1)==0) rebuild=TRUE;
    }
    if (rebuild) buildlist_add(b,p->name); else ok++;
  }
  elements=b->elements;
  pcount=buildlist_process(b,deps);
  info("%d packages, %d up to date , %d rebuild, %d failed, %d unbuildable.",nr,ok,pcount,elements-count,unbuildable);  
  return 0;
}


int build_cmd(int count,char **v,char **e) {
  char **p;
  
  for(p=v;p<e;p++) {
    char *x=*p;
    struct package *pkg;
    char *y;

    if (!is_file(catstr(cwd,"/",x,NULL))) {
      pkg=package_find(x,P_RECIPE);
      if (pkg==NULL) fatal("Cannot find a recipe for %s",*p);
      x=pkg->location;
      y=package_build(x,cwd,NULL,99);
    } else y=package_build(strdupa(buffer),cwd,NULL,99);
    if (y && save_binaries && uid==0) shell("/usr/upm/scripts/reg_binary %s %s",y,mdirs[P_BUILD]);
  }
  return 0;
}

int extract(int count,char **v,char **e) {
  char **p;
  
  for(p=v;p<e;p++) {
    struct package *pkg=package_find(*p,P_INSTALLED);
    char *tdir;
    char *olddir=getcwd(NULL,0);
    
    if (pkg==NULL) fatal("Package %s not installed.");
    tdir=package_setup_binary_directory(pkg);
    
    ACT(pkg,'Z') warn("%s: %s has been taken over by package %s skipping it.",*p,x->v1,x->v2);

    config_translation=FALSE;
    
    ACT(pkg,'D') install_node(x);
    ACT(pkg,'N') install_node(x);
    ACT(pkg,'L') install_node(x);
    ACT(pkg,'F') {
      char *srcfile;
      if (strncmp(x->v1,"etc",3)==0)
        srcfile=strdup(catstr("/" ETC,x->v1,NULL));
      else
        srcfile=strdup(x->v1);
      if (shell("cp %s/%s %s",olddir,srcfile,x->v1)) sys_abort(x->v1);
      install_node(x);
      free(srcfile);
    }
    config_translation=TRUE;
    free(pkg_save(pkg,cwd,tdir));

    if (!keepdirs) removedir(tdir);
    free(tdir);
    chdir(olddir);
    free(olddir);
  }
  
  return 0;
}

/* Structure to hold searches */
struct ss {
  struct node **n;
  int nr;
  int max;
};

/* Exhaustive search for nodes */
struct ss * search_nodes(enum pmode m,int (*check)(struct node *n,void *x),void *x) {
  struct ss *s=malloc(sizeof(struct ss));
  
  s->nr=0;
  s->max=64;
  s->n=malloc(64*sizeof(char *));
    
  ALL_PACKAGES(m) {
    for(int i=0;i<26;i++) if (*p->r) {
      struct node *n;
      for (n=p->r[i];n;n=n->next) if ((*check)(n,x)) {
        /* Add to the list */
	s->n[s->nr++]=n;
	if (s->nr>=s->max) {
	  s->max=s->max*2;
	  s->n=realloc(s->n,s->max*sizeof(struct node *));
	}
      }
    }
  }
  return s;
}

/* Sort list in case list contains filenames in ->v1 */
void sort_list(struct ss *s) {
  /* bubble sort */
  int i,j;

  for(i=0;i<s->nr;i++) {
    for(j=i+1;j<s->nr;j++) {
      if (strcmp(s->n[i]->v1,s->n[j]->v1)>0) {
        struct node *y=s->n[j];
	s->n[j]=s->n[i];
	s->n[i]=y;
      }
    }
  }
}

void search_free(struct ss *s) {
  free(s->n);
  free(s);
}

int find_match(struct node *n,void *x) {
  if (strchr("TDFLNYX",n->type)==0) return FALSE;
  return match(x,n->v1);
}

void node_found(struct node *n) {
//  printf("%-35s %-15s %c %4o %5d %5d\n",n->v1,n->pkg->name,n->type,n->mode,n->uid,n->gid);
  printf("%15s %c /%s\n",n->pkg->name,n->type,n->v1);

}

/* Check if path is offlimits */
char *offl[] = { "usr/upm/etc","usr/upm/env","usr/upm/installed","proc","dev","tmp","var/tmp",NULL };

int offlimits(char *x) {
  char **p=offl;
  while (*p && strcmp(x,*p)) p++;
  return *p !=NULL;
}

int findfile(int count,char **v,char **e) {
  char **p;
  
  read_packages(P_INSTALLED);
  
  for(p=v;p<e;p++) if (strchr(*v,'*') || strchr(*v,'?') || matching) {
    struct ss *s=search_nodes(P_INSTALLED,find_match,*v);
    if (s->nr) {
      sort_list(s);
      for(int i=0;i<s->nr;i++) node_found(s->n[i]);
     } else
       printf("Cannot match %s to any file installed\n",*v);
    search_free(s);
  } else {
    struct node *n;
    if (*p[0]=='/') strcpy(buffer,*p+1); else catstr(cwd+1,"/",*p,NULL);
    n=file_find(buffer);
    if (n) node_found(n);
    else printf("%s does not belong to any installed package.\n",*p);
  }
  
  return 0;
}

int untrackedfile(struct node *n,void *x) {
  struct stat fbuf;
  if (strchr("DFLN",n->type)==NULL) return FALSE;
  if (strncmp(n->v1,x,strlen(x))==0) {
     if (stat(n->v1,&fbuf)) {
       if (readlink(n->v1,buffer,MAXLLENGTH)<=0) return TRUE;
       error("%s(%d): Symlink pointing to nowhere (/%s)",n->pkg->name,n->lineno,n->v1);
     }
   }
  return FALSE;
}

void track_files(char *path) {
  DIR *dh;
  struct dirent *dire;
  
  dh=opendir(catstr("/",path,NULL));
  if (dh==NULL) sys_abort(buffer);
  while ((dire=readdir(dh))!=NULL) {
    struct node *n;
    char *x;
    
    if (strcmp(dire->d_name,".")==0) continue;
    if (strcmp(dire->d_name,"..")==0) continue;
    x=strdup(catstr(path,"/",dire->d_name,NULL));
    n=file_find(x);
    if (n==NULL) {
      n=xref_bestmatch(x,X_BLACKLIST,P_INSTALLED);
      if (n && strlen(x) != strlen(n->v1)) n=NULL;
      }
    if (n==NULL) {
      n=xref_bestmatch(x,X_PRIORITYLINK,P_INSTALLED);
      if (n && strlen(x) != strlen(n->v1)) n=NULL;
     }
    if (n) {
      if (thorough) {
        /* File found... Check perms and md5sum ? */
	switch (n->type) {
	  case 'D' : check_dir(n);break;
	  case 'F' : check_file(n);break;
	  case 'L' : check_link(n);break;
	  case 'N' : check_node(n);break;
	  default : ; break;
	}
      }
      if (n->type=='D' && !offlimits(x)) {
	debug("*** Entering directory %s\n",x);
	track_files(x);
      }
    } else printf("%s\n",x);
    free(x);
  }
  closedir(dh);
}

int track(int count,char **v,char **e) {
  char **p;
  
  if (count==0) fatal("Need at least one directory name to check.");
  read_packages(P_INSTALLED);
  
  for(p=v;p<e;p++) {
    char *cpath,*path;
    struct ss *s;
    
    if (*p[0]=='/') strcpy(buffer,*p+1); else catstr(cwd,"/",*p,NULL);
 
    if (*p[0]==0) fatal("Cannot do a directory on an empty specification");
    path=strdup(buffer);
    if (buffer[strlen(buffer)-1]!='/') strcat(buffer,"/");
    cpath=strdup(buffer);
    s=search_nodes(P_INSTALLED,untrackedfile,cpath);
    if (s->nr) {
      sort_list(s);
      printf("Files known by UPM in %s but not actually on the system\n",cpath);
      printf("------------------------------------------------------------------\n");
      for(int i=0;i<s->nr;i++) node_found(s->n[i]);
    }
    free(s);
    printf("Searching for files not tracked by UPM in %s\n",path);
    printf("--------------------------------------------------------------------\n");
    track_files(path);
    free(cpath);
    free(path);
  }
  
  return 0;
}

int find_dir(struct node *n,void *x) {
  if (strchr("DFLN",n->type)==0) return FALSE;
  if (strncmp(n->v1,x,strlen(x))==0) {
    return TRUE;
  }
  return FALSE;
}

void display_dir(char *path) {
  DIR *dh;
  struct dirent *dire;
  char *cpath;
  struct ss *list;
 
  if (path[0]=='/') strcpy(buffer,path+1); else catstr(cwd,"/",path,NULL);
 
  if (path[0]==0) fatal("Cannot do a directory on an empty specification");
  if (buffer[strlen(buffer)-1]!='/') strcat(buffer,"/");
  cpath=strdup(buffer);
  printf("List of files and package ownership in /%s\n\n",cpath);
  
  list=search_nodes(P_INSTALLED,find_dir,cpath);
  sort_list(list);
  
  dh=opendir(buffer);
  if (dh==NULL) sys_abort(buffer);
  printf("Filename                       Package      T  Size Perm   UID   GID\n");
  printf("--------------------------------------------------------------------\n");
  while ((dire=readdir(dh))!=NULL) {
    struct node *n;
    struct stat fbuf;
    
    if (strcmp(dire->d_name,".")==0) continue;
    if (strcmp(dire->d_name,"..")==0) continue;
    n=file_find(catstr(cpath,dire->d_name,NULL));
    stat(buffer,&fbuf);
    printf("%-30s ",dire->d_name);
    if (n) {
      printf("%-12s ",n->pkg->name);
      if (n->type=='D') { if (S_ISDIR(fbuf.st_mode)) printf("D "); else printf("@"); } else
      if (n->type=='F') { if (S_ISREG(fbuf.st_mode)) printf("F "); else printf("@"); } else
      if (n->type=='L') { if (readlink(buffer,buffer+200,200)>0) printf("L "); else printf("@"); goto finito; }
      else printf("N ");
      if (n->type=='D') printf("      "); else
      if (n->size==fbuf.st_size) printf("%-6s",sizeformat(n->size)); else printf("@@@@@ ");
      if (n->mode == (fbuf.st_mode & 07777)) printf("%4o ",n->mode); else printf("@@@@ ");
      if (n->uid == fbuf.st_uid) printf("%5d ",n->uid); else printf("@@@@@@ ");
      if (n->gid == fbuf.st_gid) printf("%5d ",n->gid); else printf("@@@@@@ ");
      /* Take this one off the list */
      for(int i=0;i<list->nr;i++) if (list->n[i]==n) { list->n[i]=NULL;break; }
    } else printf("--- File not in any package ---");
 finito:
    printf("\n");
  }
  /* Leftovers not listed in directory */
  for(int i=0;i<list->nr;i++) if (list->n[i]) {
    struct node *n=list->n[i];
    printf("%-30s %-12s %c %-6s%4o %5d %5d FILE NOT PRESENT!\n",basename(n->v1),n->pkg->name,n->type,sizeformat(n->size),n->mode,n->uid,n->gid);
  }
  search_free(list);
  closedir(dh);
}

int directory(int count,char **v,char **e) {
  char **p;
  
  read_packages(P_INSTALLED);
  
  if (count==0) display_dir(""); else
  for(p=v;p<e;p++) {
    display_dir(*p);
  }
  
  return 0;
}

int cleanup(int count,char **v,char **e) {
  
  if (count) fatal("cleanup does not take any parameters");
 
  removedir(temp_dir);
  removedir(FROOT);
  shell("rm -rf usr/upm/staging-*");
  /* May want to consider some kind of expiration for the cache directory and the binary directories */
  read_packages(P_BUILD);
  ALL_PACKAGES(P_BUILD) {
    ACT(p,'C') {
      if (strchr(x->v2,':')==NULL) {
        struct stat fbuf;
	if (stat(x->v2,&fbuf)) {
          info("%s: removing build information since tarball %s does not exist anymore",p->name,x->v2);
	  unlink(p->location);
	}
      }
    }
  }
  return 0;
}

int source(int count,char **v,char **e) {
  int level=45;
  char *x;
 
  if (count==0 || count >2) fatal("upm source <package-description> [<level>]");
  if (count==2) level=atoi(v[1]);
  x=*v;
  if (!is_file(x)) {
    struct package *pkg;
    pkg=package_find(x,P_RECIPE);
    if (pkg==NULL) fatal("Cannot find recipe for package %s",x);
    x=pkg->location;
 }
  if (level>=50) read_packages(P_INSTALLED);
  package_build(x,cwd,cwd,level);
  return 0;
}

int diff(int count,char **v,char **e) {
  int level=45;
  char *x;
  char *origdir;
 
  if (count==0 || count >2) fatal("upm diff <package-description> [<level>]");
  if (count==2) level=atoi(v[1]);
  origdir=strdupa(catstr(cwd,".orig",NULL));
  x=*v;
  if (!is_file(x)) {
    struct package *pkg;
    pkg=package_find(x,P_RECIPE);
    if (pkg==NULL) fatal("Cannot find recipe for package %s",x);
    x=pkg->location;
  }
  if (level>=50) read_packages(P_INSTALLED);
  package_build(x,origdir,origdir,level);
  printf("______________ DIFF _________________\n");
  shell("diff -urN %s/%s %s",origdir,basename(cwd),cwd);
  if (!keepdirs) removedir(origdir);
  return 0;
}

int hold(int count,char **v,char **e) {
  char **p;
  
  if (count==0) {
    int nr=0;
    read_packages(P_INSTALLED);
    ALL_PACKAGES(P_INSTALLED) if (p->hold) { nr++;printf("%s\n",p->name);}
    printf("%d packages on hold\n",nr);
  } else  
  for(p=v;p<e;p++) {
    struct package *pkg=package_find(*p,P_INSTALLED);
    if (pkg==NULL) fatal("%s: not installed.",*p);
    if (pkg->hold) error("%s: already on hold",*p);
    else pkg_hold(pkg->name);
  } 
  return 0;
}


int unhold(int count,char **v,char **e) {
  char **p;
  
  if (count==0) {
    read_packages(P_INSTALLED);
    int nr=0;
    ALL_PACKAGES(P_INSTALLED) if (p->hold) { nr++;pkg_unhold(p); }
    printf("%d packages unheld\n",nr);
  }
  else
  for(p=v;p<e;p++) {
    struct package *pkg=package_find(*p,P_INSTALLED);
    if (pkg==NULL) fatal("%s: not installed.",*p);
    if (!pkg->hold) error("%s: not on hold");
    else pkg_unhold(pkg);
  } 
  return 0;
}

/*********************************************************
   Site Maintenance Tools
*********************************************************/

int updatemirror(int count,char **v,char **e) {
  int counter=0;
  int descr=0;
  char *cv;

  /* Read recipes from path specified */
  if (count!=0) fatal("updatemirror does not have parameters");
  if (uid==0) fatal("updatemirror should not be run as root");
  viewlevel=L_WARN;
  read_packages(P_RECIPE);
  /* Go through all recipes */
  ALL_PACKAGES(P_RECIPE) {
    struct stat fbuf;
    char *dname;
    struct node *h=p->r['H'-'A'];
    
    counter++;
    retrieve_sources(p);
    dname=strdup(catstr(descriptions,"/",p->name,NULL));
    if (h && stat(dname,&fbuf)) {
      if (shell("wget --output-document=- -q %s|unweb >%s/%s",h->v1,descriptions,p->name)) {
        unlink(dname);
	error("%s(%d): H record points to invalid URL %s",p->name,h->lineno,h->v1);
      } else {
        if (stat(dname,&fbuf)) error("%s(%d): No file retrieved from URL %s",p->name,h->lineno,h->v1);
	else if (fbuf.st_size==0) { unlink(dname); error("%s(%d): Zero length file from URL %s",p->name,h->lineno,h->v1); }
	else descr++;
      }
    }
  }
/*  update_metadata(P_RECIPE); */
  printf("Mirrorcheck finished. %d recipes processed. %d descriptions retrieved.\n",counter,descr);
  /* Table of virtuals */
  cv=NULL;
  printf("Table of virtual package names mapping them to real package names:\n");
  ACTINDEX(X_VIRTUAL,P_RECIPE) {
    if (cv==NULL || strcmp(cv,y->v1)) {
      printf("\n%s:%s",y->v1,y->pkg->name);
      cv=y->v1;
    } else printf(" %s",y->pkg->name);
  }
  printf("\n");
  return 0;
}

int rcdsetup(int count,char **v,char **e) {
  struct package *p;
  struct node *n;
  char *iname;
  int inamelen;
  int removed=0;
  
  if (count<=2) fatal("Syntax: upm rcdsetup <script> <parameters>");
  
  iname=*v++;
  inamelen=strlen(iname);
  
  read_packages(P_INSTALLED);
  n=file_find(catstr("etc/init.d/",iname,NULL));
  if (n==NULL) fatal("/etc/init.d/%s does not exist in uPMs database",iname);
  p=n->pkg;
  /* Erase old links */
  ACT(p,'L') {
    int l=strlen(x->v1);
    if (l==12+inamelen && strncmp(x->v1,"etc/rc",6)==0 && strcmp(x->v1+strlen(x->v1)-inamelen,iname)==0) {
       node_remove(x);
       removed++;
    }
  }
  
  if (removed==0) swerr("rcdsetup: No links found to remove");
  /* Generate new links */
  buffer[0]=0;
  while (v<e) {
    strcat(buffer,*v++);
    strcat(buffer," ");
  }

  if (setlinks(iname,strdupa(buffer)))
    package_write(p);
  else
    fatal("%s: Links not changed for /etc/init.d/%s",p->name,iname);
  return 0;
}

int start(int count,char **v,char **e) {
  char *iname;
  struct node *n;

  if (count!=1) fatal("Syntax: upm start <script>");
  iname=*v++;
  read_packages(P_INSTALLED);
  n=file_find(catstr("etc/init.d/",iname,NULL));
  if (n==NULL) fatal("/etc/init.d%s does not exist in uPM's database",iname);
  if (init_script(n->pkg,iname,START)) return 0;
  error("Init script %s of package %s not started",iname,n->pkg->name);
  return 1;
}

int stop(int count,char **v,char **e) {
  char *iname;
  struct node *n;

  if (count!=1) fatal("Syntax: upm stop <script>");
  iname=*v++;
  read_packages(P_INSTALLED);
  n=file_find(catstr("etc/init.d/",iname,NULL));
  if (n==NULL) fatal("/etc/init.d/%s does not exist in uPM's database",iname);
  if (init_script(n->pkg,iname,START)) return 0;
  error("Init script %s of package %s not stopped",iname,n->pkg->name);
  return 1;
}

char *dirname(char *s) {
  int l=strlen(s)-strlen(basename(s))-1;
  strncpy(buffer,s,l);
  buffer[l]=0;
  return buffer;
}

void printloc(FILE *fh,struct node *x,const char *text,const char *loc) {
  char *y=string_expand(x->pkg,x->v1,G_BUILD);

  if (y==NULL) { error("Empty locaton expansion for %s",x->pkg->name);return; }
  /* If @ then use the first mirror entry to compose the URL */
  if (*y=='@') {
    char *p=y+1;
    const char *q;
    
    while (*p && *p!='/') p++;
    q=getsetting("mirror",strndupa(y+1,p-y-1));
    if (q) {
      strcpy(buffer,q);
      for(char *z=buffer;*z;z++) if (*z==' ') { *z=0;break; }
      strcat(buffer,p);
      free(y);
      y=strdup(buffer);
    }
  }
  if (strchr(y,':')==NULL) {
    catstr(loc,"/",y,NULL);
    free(y);
    y=strdup(buffer);
  }
  fprintf(fh,"<B>%s:</B> <A HREF=%s>%s</A><BR>\n",text,dirname(y),y);
  free(y);
}

int indexit(int count,char **v,char **e) {
  FILE *fh;
  int npackages[4];
  struct package **pp[4];
  int to=P_RECIPE;  
  if (count!=1) fatal("Syntax: upm index <file>");
  
  for(int i=P_RECIPE;i<=to;i++) {
    struct package **s;
    int n;
    
    npackages[i]=read_packages(i);
    s=calloc(npackages[i],sizeof(struct package *));
    n=0;
    /* Sort the stuff by location */
    ALL_PACKAGES(i) {
      struct package **q;
      for(q=s;q<s+n && strcmp((*q)->location,p->location)<0;q++) ;
      if (q<s+n) memmove(q+1,q,(n-(q-s))*sizeof(struct package *));
      *q=p;
      n++;
    }
    pp[i]=s;
  }
  fh=fopen(catstr(cwd,"/",*v,NULL),"w");
  if (fh==NULL) sys_abort(*v);
  fprintf(fh,"<HTML>\n<HEAD>\n<TITLE>Package Overview</TITLE>\n</HEAD>\n<BODY>\n");
  fprintf(fh,"<H1>Package Categories on this system</H1><P>\n");
  for(int i=P_RECIPE;i<=to;i++) if (npackages[i]>0) {
    char *oldsect;
    
    fprintf(fh,"<P><H1 ID=%d>%s</H1><P>\n",i,mtexts[i]);
    fprintf(fh,"<TABLE>\n");
    oldsect=strdup("NONE");
    for(struct package **q=pp[i];q<pp[i]+npackages[i];q++) {
      struct package *p=*q;

      dirname(p->location+strlen(mdirs[i])+1);
      if (strcmp(buffer,oldsect)) {
        fprintf(fh,"</TABLE>\n<H1>Section: %s</H1>\n<TABLE BORDER=1>\n",buffer);
	free(oldsect);
	oldsect=strdup(buffer);
      } 
      
      fprintf(fh,"<TR><TD><A HREF=\"#%d%s\">%s</A></TD><TD>%s</TD><TD>%s</TD></TR>",i,p->name,p->name,pkg_version(p),pkg_description(p));
    }
    fprintf(fh,"</TABLE>\n");
  }
  for(int i=P_RECIPE;i<=to;i++) if (npackages[i]>0) {
    fprintf(fh,"<P><H1 ID=%d>%s</H1><P>\n",i,mtexts[i]);
    for(struct package **q=pp[i];q<pp[i]+npackages[i];q++) {
      struct package *p=*q;

      fprintf(fh,"<P><H2 ID=\"%d%s\">%s</H2><BR><B>Text:</B> %s<BR>",i,p->name,p->name,pkg_description(p));
      fprintf(fh,"<B>Version:</B> %s<BR>\n",pkg_version(p));
      // if (pkg_delta(p)) fprintf(fh,"<BR><B>Delta:</B> %s\n",pkg_delta(p));
      ACT(p,'H') {
        char *y=string_expand(p,x->v1,G_BUILD);
        fprintf(fh,"<B>Information at:</B> <A HREF=%s>%s</A><BR>\n",y,y);
	free(y);
      }
      ACT(p,'S') printloc(fh,x,"Source",source_loc);
      ACT(p,'P') printloc(fh,x,"Patch",patch_loc);
      ACT(p,'R') switch(x->relation) {
        case R_DEPEND  : fprintf(fh,"Runtime Dependency on <A HREF=\"#%d%s\">%s %s</A><BR>",i,x->v1,x->v1,x->v2 ? x->v2:"");break;
	case R_BUILD   : fprintf(fh,"Build Dependency on <A HREF=\"#%d%s\">%s %s</A><BR>",i,x->v1,x->v1,x->v2 ? x->v2:"");break;
	case R_PROVIDE : fprintf(fh,"Provides %s<BR>",x->v1);break;
	case R_CONFLICT: fprintf(fh,"Conflicts with <A HREF=\"#%d%s\">%s %s</a><BR>",i,x->v1,x->v1,x->v2 ? x->v2:"");break;
	default: break;
      }
      ACT(p,'O') fprintf(fh,"Option: %s<BR>",x->v1);
      fprintf(fh,"<P>\n");
    }
  }
  
  fprintf(fh,"\n</BODY>\n</HTML>\n");
  fclose(fh);
  return 0;
}

/*********************************************************
    Command line processing related routines
*********************************************************/

void printversion(void) {
  printf("uPM " VERSION " (C) 2002 Christoph Lameter <christoph@lameter.com>\n");
}

void usage(void) {
  printf("uPM micro Package Manager Version " VERSION " http://u-OS.org\n"
         "--------------------------------------------------------------------\n"
	 "(C) 2002 Christoph Lameter, <christoph@u-OS.org>\n\n");
  printf("Usage: upm [<options>] <command> <list-of-packages>\n\n"
"Options are:\n"
"  -v, --version		Print version of uPM.\n"
"  -h, --help		Show these instructions.\n"
"  -k, --keepreal	Do not change dirs/files. Adjust metadata to real filedata.\n"
"  -d, --deps		If dependencies are missing install the software needed.\n"
"  -c type, --config	Special config file handling on conflicts O=Overwrite, K=Keep R=Rename orig.\n"
"  -f, --fetchonly	Do not build but fetch the files needed for building.\n"
"  -a var=val		Override/Define attribute for this session of uPM.\n"
"  -r dir, --root dir	Use the given directory as the root directory instead of /.\n"
"  -v, --verbose	Increase verbosity (9 levels).\n"
"  -q, --quiet		Reduce verbosity (9 levels).\n"
"  -g, --generate	Generate package descriptions on the fly if they are missing.\n"
"  -D, --no-depends	Show warnings instead of aborting on dependency problems.\n"
"  -P, --no-protect	Allow overwriting of files from installed packages.\n"
"  -n, --nice		Package will simply omit files that are already installed.\n"
"  -L, --log		Log build output.\n"
"  -F, --fakeroot	Do not use fakeroot for the build process.\n"
"  -A, --keepdirs	Do not automatically remove build and binary directories.\n"
"  -B, --keeplogs	Do not automatically remove build logs.\n"
"  -m, --match		Do pattern matching on findfile etc instead of assuming exact path+name\n"
"  -t, --thorough	Be more throurough (check perms and md5sums) during track commands.\n"
"  -s, --source	        Build from source even if binaries exist.\n"
"  -b, --binary		Only install if binary exists.\n"
"  -I, --noninitscript	Do not run any init scripts.\n"
"Available commands:\n"
"  install, i		Install new software from URL, file or recipe.\n"
"  remove, rem		Remove software from the system.\n"
"  list, l		list packages installed. Parameter is a pattern to match.\n"
"  search, s		Search available packages by keyword.\n"
"  report,rep		Comprehensive report on all files on the system.\n"
"  build, b		Build binary tarball from source without installing.\n"
"  update, u		Update list of available packages.\n"
"  upgrade, upg		Upgrade all software to the newest releases.\n"
"  check, c		Verify package integrity.\n"
"  repair, rep		Repair package metadata.\n"
"  info, in		Show package data in detail.\n"
"  config-save		Save configuration data of a package.\n"
"  config-load		Install configuraton files for a package.\n"
"  config-default	Reset configuration files to the defaults.\n"
"  config-diff		Show the changes made from the defaults.\n"
"  extract, ex		Generate binary tarball from installed files.\n"
"  findfile, fi		Find files specified and display information about then.\n"
"  track, tr 		Search for files not present or not in upms registry.\n"
"  directory, dir	List directory of files.\n"
"  cleanup, cle		Erase accumulated logs source and binary directories.\n"
"  syncbuild		Rebuild all packages that have been built with older tools.\n"
"  syncattr		Rebuild packages where the default attributes mismatch.\n"
"  deprebuild		Rebuild all packages depending on the packages listed.\n"
"  source		Retrieve sourcecode.\n"
"  diff			Build diff to current source.\n"
"  updatemirror		Mirror maintenance.\n"
"  index		Build browsable index.html from all available packages.\n"
"  hold			Mark package(s) to be on hold.\n"
"  unhold		Clear hold status of packages.\n"
"  rcdsetup script rcdparam Modify startup parameters for an init.d script.\n"
"  start script		Start /etc/init.d/ script if service should run in current runlevel.\n"
"  stop script		Stop /etc/init.d/ script if service should run in current runlevel.\n"
);
exit(0);
}

struct option long_options[] = {
 { "version", 0, 0, 'V' },
 { "help", 0, 0, 'h' },
 { "keepreal", 0, 0, 'k' },
 { "deps", 0, 0, 'd' },
 { "attribute", 1, 0, 'a' },
 { "nice", 0, 0,'n' },
 { "no-depends", 0, 0, 'D' },
 { "no-protect", 0, 0, 'P' },
 { "keepdirs", 0, 0, 'A' },
 { "keeplogs", 0, 0, 'B' },
 { "log", 0, 0, 'L' },
 { "root", 1, 0, 'r' },
 { "verbose", 0, 0, 'v' },
 { "quiet", 0, 0, 'q' },
 { "fakeroot", 0, 0, 'F' },
 { "generate",0,0,'g' },
 { "match",0,0,'m' },
 { "thorough",0,0,'t' },
 { "binary",0,0,'b' },
 { "source",0,0,'s' },
 { "fetchonly",0,0,'f' },
 { "config",1,0,'c' },
 { "noinitscript",0,0,'I' },
 { 0, 0, 0, 0 }
};

struct cmd {
  char *name;
  int minmatch;
  int mustberoot;
  int (*ex)(int,char **,char **);
} commands[]= {
{ "info",3,FALSE,info_cmd },
{ "install",1,TRUE,install },
{ "remove",3,TRUE,remove_cmd },
{ "config-save",10,FALSE,config_save },
{ "config-load",10,TRUE,config_load },
{ "config-default",10,TRUE,config_default },
{ "config-diff",10,FALSE,config_diff },
{ "check",2,FALSE,check },
{ "repair",3,TRUE,repair },
{ "list",1,FALSE,list },
{ "source",2,FALSE,source },
{ "diff",3,FALSE,diff },
{ "search",1,FALSE,search },
{ "report",3,FALSE,report },
{ "track",2,FALSE,track },
{ "update",3,TRUE,update },
{ "upgrade",1,TRUE,upgrade },
{ "syncbuild",5,TRUE,syncbuild },
{ "syncattr",5,TRUE,syncattr },
{ "build",1,FALSE,build_cmd },
{ "extract",2,FALSE,extract },
{ "findfile",2,FALSE,findfile },
{ "directory",2,FALSE,directory },
{ "cleanup",3,TRUE,cleanup },
{ "updatemirror" ,8, FALSE, updatemirror },
{ "hold",4,TRUE,hold },
{ "unhold",6,TRUE,unhold },
{ "rcdsetup",3,TRUE,rcdsetup },
{ "start",5,TRUE,start },
{ "stop",4,TRUE,stop },
{ "index",5,FALSE,indexit },
{ "deprebuild",4,TRUE,deprebuild },
{ "version",1,FALSE,(void *)printversion },
{ "help",1,FALSE,(void *)usage },
{ NULL,0,FALSE,NULL } };

int main(int argc, char *argv[]) {
  int opt;
    
  if (argc<=1) { usage();exit(1); }
  cwd=getcwd(NULL,0);
  uid=getuid();
  readconfig();
  
  while ((opt=getopt_long(argc, argv, "hkda:r:c:viInfqgVDPABLFtmsb", long_options, NULL))>0) {
    switch (opt) {
      case 'V' : printversion();return 0;
      case 'h' : usage();break;
      case 'k' : keepreal=TRUE;break;
      case 'd' : deps=TRUE;break;
      case 'a' : 
        { /* Next argument is attribute override of the form var=value */
	  char*p=optarg;
	  while (*p && *p!='=') p++;
          if (*p==0) { fprintf(stderr,"Need to have = for attribute assignment\n");exit(1); }
          *p++=0;
          putsetting("attributes",optarg,p);
	}
        break;
      case 'D' : no_depends=TRUE;break;
      case 'P' : no_protect=TRUE;break;
      case 'A' : keepdirs=TRUE;break;
      case 'B' : keeplogs=TRUE;break;
      case 'L' : no_logs=FALSE;break;
      case 'r' : root=strdup(optarg);break;
      case 'c' : switch (*optarg) {
                   case 'K' : case 'k' : configmode=C_KEEP;break;
		   case 'O' : case 'o' : configmode=C_OVERWRITE;break;
		   case 'R' : case 'r' : configmode=C_RENAME;break;
		   default: { fprintf(stderr,"Unknown config mode\n");exit(1); }
                 };
		 break;
      case 'v' : viewlevel++;break;
      case 'q' : viewlevel--;break;
      case 'F' : fakeroot=FALSE;break;
      case 'g' : generate=TRUE;break;
      case 'n' : nice_pkg=TRUE;break;
      case 'm' : matching=TRUE;break;
      case 't' : thorough=TRUE;break;
      case 'b' : binaries=B_ALWAYS;break;
      case 's' : binaries=B_NEVER;break;
      case 'f' : fetchonly=TRUE;deps=TRUE;break;
      case 'I' : noinitscript=TRUE;break;
      default : exit(3);break;
    }
  }

  if (root==NULL || root[0]==0) {
    if (chdir("/")) sys_abort("/");
  } else {
    if (chdir(root)) sys_abort(root);
  };
  
  if (optind==argc) { usage();exit(1); }

  for(struct cmd *p=commands;p->name;p++)
    if (strncmp(p->name,argv[optind],strlen(argv[optind]))==0 && strlen(argv[optind]) >=p->minmatch) {
      int rc;
      if (p->mustberoot && uid) fatal("Command '%s' can only be given as root",p->name);
      atexit(fakeroot_atexit);
      rc=(*p->ex)(argc-optind-1,argv+optind+1,argv+argc);
      if (viewlevel>=L_DEBUG) {
        phash_stat();
        file_hash_stat();
      }
      return rc;
  }
  
  fatal("Command '%s' not recognized by UPM.",argv[optind]);
}
